@@ -26,13 +26,21 @@ static inline char MakeUpperCase(char ch) {
 		return static_cast<char>(ch - 'a' + 'A');
 }
 
+static inline bool IsLetter(char ch) {
+	return ((ch >= 'a' && ch <= 'z') || (ch >= 'A' && ch <= 'Z'));
+}
+
 int CompareCaseInsensitive(const char *a, const char *b) {
 	while (*a && *b) {
 		if (*a != *b) {
-			char upperA = MakeUpperCase(*a);
-			char upperB = MakeUpperCase(*b);
-			if (upperA != upperB)
-				return upperA - upperB;
+			if (IsLetter(*a) && IsLetter(*b)) {
+				char upperA = MakeUpperCase(*a);
+				char upperB = MakeUpperCase(*b);
+				if (upperA != upperB)
+					return upperA - upperB;
+			} else {
+				return *a - *b;
+			}
 		}
 		a++;
 		b++;
@@ -44,10 +52,14 @@ int CompareCaseInsensitive(const char *a, const char *b) {
 int CompareNCaseInsensitive(const char *a, const char *b, int len) {
 	while (*a && *b && len) {
 		if (*a != *b) {
-			char upperA = MakeUpperCase(*a);
-			char upperB = MakeUpperCase(*b);
-			if (upperA != upperB)
-				return upperA - upperB;
+			if (IsLetter(*a) && IsLetter(*b)) {
+				char upperA = MakeUpperCase(*a);
+				char upperB = MakeUpperCase(*b);
+				if (upperA != upperB)
+					return upperA - upperB;
+			} else {
+				return *a - *b;
+			}
 		}
 		a++;
 		b++;
@@ -532,6 +544,20 @@ bool WordList::InList(const char *s) {
 			j++;
 		}
 	}
+	j = starts['^'];
+	if (j >= 0) {
+		while (words[j][0] == '^') {
+			const char *a = words[j] + 1;
+			const char *b = s;
+			while (*a && *a == *b) {
+				a++;
+				b++;
+			}
+			if (!*a)
+				return true;
+			j++;
+		}
+	}
 	return false;
 }
 
@@ -632,8 +658,6 @@ char *WordList::GetNearestWords(
 	int end = len - 1; // upper bound of the api array block to search
 	int pivot; // index of api array element just being compared
 	int cond; // comparison result (in the sense of strcmp() result)
-	int oldpivot; // pivot storage to be able to browse the api array upwards and then downwards
-	const char *word; // api array element just being compared
 
 	if (0 == words)
 		return NULL;
@@ -642,66 +666,56 @@ char *WordList::GetNearestWords(
 		SortWordList(words, wordsNoCase, len);
 	}
 	if (ignoreCase) {
-		while (start <= end) { // binary searching loop
-			pivot = (start + end) >> 1;
-			word = wordsNoCase[pivot];
-			cond = CompareNCaseInsensitive(wordStart, word, searchLen);
+		while (start <= end) { // Binary searching loop
+			pivot = (start + end) / 2;
+			cond = CompareNCaseInsensitive(wordStart, wordsNoCase[pivot], searchLen);
 			if (!cond) {
-				oldpivot = pivot;
-				do { // browse sequentially the rest after the hit
-					wordlen = LengthWord(word, otherSeparator) + 1;
-					wordsNear.append(word, wordlen, ' ');
-					if (++pivot > end)
-						break;
-					word = wordsNoCase[pivot];
-				} while (!CompareNCaseInsensitive(wordStart, word, searchLen));
-
-				pivot = oldpivot;
-				for (;;) { // browse sequentially the rest before the hit
-					if (--pivot < start)
-						break;
-					word = wordsNoCase[pivot];
-					if (CompareNCaseInsensitive(wordStart, word, searchLen))
-						break;
-					wordlen = LengthWord(word, otherSeparator) + 1;
-					wordsNear.append(word, wordlen, ' ');
+				// Find first match
+				while ((pivot > start) &&
+					(0 == CompareNCaseInsensitive(wordStart, 
+						wordsNoCase[pivot-1], searchLen))) {
+					--pivot;
+				}
+				// Grab each match
+				while ((pivot <= end) &&
+					(0 == CompareNCaseInsensitive(wordStart, 
+						wordsNoCase[pivot], searchLen))) {
+					wordlen = LengthWord(wordsNoCase[pivot], otherSeparator) + 1;
+					wordsNear.append(wordsNoCase[pivot], wordlen, ' ');
+					++pivot;
 				}
 				return wordsNear.detach();
-			} else if (cond < 0)
+			} else if (cond < 0) {
 				end = pivot - 1;
-			else if (cond > 0)
+			} else if (cond > 0) {
 				start = pivot + 1;
+			}
 		}
-	} else {	// preserve the letter case
-		while (start <= end) { // binary searching loop
-			pivot = (start + end) >> 1;
-			word = words[pivot];
-			cond = strncmp(wordStart, word, searchLen);
+	} else {	// Preserve the letter case
+		while (start <= end) { // Binary searching loop
+			pivot = (start + end) / 2;
+			cond = strncmp(wordStart, words[pivot], searchLen);
 			if (!cond) {
-				oldpivot = pivot;
-				do { // browse sequentially the rest after the hit
-					wordlen = LengthWord(word, otherSeparator) + 1;
-					wordsNear.append(word, wordlen, ' ');
-					if (++pivot > end)
-						break;
-					word = words[pivot];
-				} while (!strncmp(wordStart, word, searchLen));
-
-				pivot = oldpivot;
-				for (;;) { // browse sequentially the rest before the hit
-					if (--pivot < start)
-						break;
-					word = words[pivot];
-					if (strncmp(wordStart, word, searchLen))
-						break;
-					wordlen = LengthWord(word, otherSeparator) + 1;
-					wordsNear.append(word, wordlen, ' ');
+				// Find first match
+				while ((pivot > start) &&
+					(0 == strncmp(wordStart, 
+						words[pivot-1], searchLen))) { 
+					--pivot;
+				}
+				// Grab each match
+				while ((pivot <= end) &&
+					(0 == strncmp(wordStart, 
+						words[pivot], searchLen))) { 
+					wordlen = LengthWord(words[pivot], otherSeparator) + 1;
+					wordsNear.append(words[pivot], wordlen, ' ');
+					++pivot;
 				}
 				return wordsNear.detach();
-			} else if (cond < 0)
+			} else if (cond < 0) {
 				end = pivot - 1;
-			else if (cond > 0)
+			} else if (cond > 0) {
 				start = pivot + 1;
+			}
 		}
 	}
 	return NULL;
