@@ -52,6 +52,10 @@ create_about_gui ()
 		"Yannick Koehler <yannick.koehler@colubris.com>", 
 		"Giovanni Corriga <valkadesh@libero.it>",
 		"Dan Elphick <dre00r@ecs.soton.ac.uk>",
+		"Jens Georg <mail@jensgeorg.de>",
+		"Biswapesh Chattopadhyay <biswapesh_chatterjee@tcscal.co.in>",
+		"Dick Knol <dknol@gmx.net>",
+		"Jason Williams <jason_williams@suth.com>",
 		NULL
 	};
 	GtkWidget *about_gui;
@@ -61,9 +65,9 @@ create_about_gui ()
 
 	about_imgfile = anjuta_res_get_pixmap_file (ANJUTA_PIXMAP_LOGO);
 	about_gui = gnome_about_new ("Anjuta", VERSION,
-		_("Copyright (c) 1999-2001 Naba Kumar"),
+		_("Copyright (c) 1999-2002 Naba Kumar"),
 		authors,
-		NULL, about_imgfile);
+		"An Integrated Development Environment for GNOME", about_imgfile);
 	if(about_imgfile)
 		g_free (about_imgfile);
 	gtk_window_set_modal (GTK_WINDOW (about_gui), FALSE);
@@ -72,7 +76,7 @@ create_about_gui ()
 	
 	vbox1 = GNOME_DIALOG (about_gui)->vbox;
 
-	href1 = gnome_href_new ("http://anjuta.sourceforge.net/", _("Anjuta Home Site"));
+	href1 = gnome_href_new ("http://anjuta.sourceforge.net/", _("Anjuta Home Page"));
 	gtk_widget_show (href1);
 	gtk_box_pack_start (GTK_BOX (vbox1), href1, FALSE, FALSE, 0);
 	gtk_box_reorder_child (GTK_BOX (vbox1), href1, 1);
