@@ -54,6 +54,8 @@
 
 #include "tm_tagmanager.h"
 
+// #define DEBUG
+
 #define ANE_MARKER_BOOKMARK 0
 #define MAX_PATH 260
 #define MAXIMUM(x, y)	((x>y)?x:y)
@@ -272,7 +274,7 @@ static void lowerCaseString(char *s);
 static const char *extList[] = {
     "", "x", "x.cpp", "x.cpp", "x.html", "x.xml", "x.js", "x.vbs", "x.mak", "x.java",
     "x.lua", "x.py", "x.pl", "x.sql", "x.spec", "x.php3", "x.tex", "x.diff", "x.pas",
-    "x.cs", "x.properties", "x.conf"
+    "x.cs", "x.properties", "x.conf", "x.bc", "x.adb"
 };
 
 AnEditor::AnEditor(PropSetFile* p) {
@@ -346,10 +348,12 @@ AnEditor::AnEditor(PropSetFile* p) {
 		GtkSignalFunc(NotifySignal), this);
 
 	/* We will handle all accels ourself */
-/*	SendEditor(SCI_CLEARALLCMDKEYS);*/
+	/* SendEditor(SCI_CLEARALLCMDKEYS); */
 
 	/*We have got our own popup menu */
 	SendEditor(SCI_USEPOPUP, false);
+	/* Set default editor mode */
+	SendEditor(SCI_SETEOLMODE, SC_EOL_LF);
 }
 
 void
@@ -822,21 +826,75 @@ bool AnEditor::StartAutoCompleteWord() {
 	linebuf[current] = '\0';
 	const char *root = linebuf + startword;
 	int rootlen = current - startword;
+
+	/* Added word-completion feature back - Biswa */
+	int doclen = LengthDocument();
+	TextToFind ft = {{0, 0}, 0, {0, 0}};
+	ft.lpstrText = const_cast<char*>(root);
+	ft.chrg.cpMin = 0;
+	ft.chrgText.cpMin = 0;
+	ft.chrgText.cpMax = 0;
+	int flags = SCFIND_WORDSTART | (autoCompleteIgnoreCase ? 0 : SCFIND_MATCHCASE);
+	int posCurrentWord = SendEditor (SCI_GETCURRENTPOS) - rootlen;
+	GString *words = g_string_sized_new(100);
+	char wordstart[100];
+	char *wordend, *wordbreak, *wordpos;
+	int wordlen;
+	for (;;)
+	{
+		ft.chrg.cpMax = doclen;
+		int posFind = SendEditor(SCI_FINDTEXT, flags
+		  , reinterpret_cast<long>(&ft));
+		if (posFind == -1 || posFind >= doclen)
+			break;
+		if (posFind == posCurrentWord)
+		{
+			ft.chrg.cpMin = posFind + rootlen;
+			continue;
+		}
+		GetRange(wEditor, posFind, Platform::Minimum(posFind+99, doclen)
+		  , wordstart);
+		wordend = wordstart + rootlen;
+		while (iswordcharforsel(*wordend))
+			wordend++;
+		*wordend = '\0';
+		wordlen = wordend - wordstart;
+		wordbreak = words->str;
+		for (;;)
+		{
+			wordpos = strstr (wordbreak, wordstart);
+			if (!wordpos)
+				break;
+			if (wordpos > words->str && wordpos[ -1] != ' ' ||
+			  wordpos[wordlen] && wordpos[wordlen] != ' ')
+				wordbreak = wordpos + wordlen;
+			else
+				break;
+		}
+		if (!wordpos)
+		{
+			if (words->len > 0)
+				g_string_append_c(words, ' ');
+			g_string_append(words, wordstart);
+		}
+		ft.chrg.cpMin = posFind + wordlen;
+	}
+	/* Now for the TM based autocompletion */
 	const GPtrArray *tags = tm_workspace_find(root, tm_tag_max_t, NULL, TRUE);
 	if ((tags) && (tags->len > 0))
 	{
-		GString *words = g_string_sized_new(100);
 		TMTag *tag;
 		for (guint i=0; ((i < tags->len) && (i < MAX_AUTOCOMPLETE_WORDS)); ++i)
 		{
 			tag = (TMTag *) tags->pdata[i];
-			if (i > 0)
+			if (words->len > 0)
 				g_string_append_c(words, ' ');
 			g_string_append(words, tag->name);
 		}
-		SendEditorString(SCI_AUTOCSHOW, rootlen, words->str);
-		g_string_free(words, TRUE);
 	}
+	if (words->len > 0)
+		SendEditorString(SCI_AUTOCSHOW, rootlen, words->str);
+	g_string_free(words, TRUE);
 	return true;
 }
 
@@ -1252,7 +1310,23 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 		break;
 
 	case ANE_EOL_CONVERT:
-		SendEditor(SCI_CONVERTEOLS, SendEditor(SCI_GETEOLMODE));
+		switch (wParam) {
+			case ANE_EOL_CRLF:
+				SendEditor(SCI_SETEOLMODE, SC_EOL_CRLF);
+				SendEditor(SCI_CONVERTEOLS, SC_EOL_CRLF);
+				break;
+			case ANE_EOL_LF:
+				SendEditor(SCI_SETEOLMODE, SC_EOL_LF);
+				SendEditor(SCI_CONVERTEOLS, SC_EOL_LF);
+				break;
+			case ANE_EOL_CR:
+				SendEditor(SCI_SETEOLMODE, SC_EOL_CR);
+				SendEditor(SCI_CONVERTEOLS, SC_EOL_CR);
+				break;
+			default:
+				SendEditor(SCI_CONVERTEOLS, SendEditor(SCI_GETEOLMODE));
+				break;
+		}
 		break;
 
 	case ANE_WORDPARTLEFT:
@@ -1338,6 +1412,9 @@ long AnEditor::Command(int cmdID, long wParam, long lParam) {
 	case ANE_GETLENGTH:
 		return SendEditor(SCI_GETLENGTH);
 
+	case ANE_GET_LINENO:
+		return GetCurrentLineNumber();
+
 	default:
 		break;
 	}
@@ -1643,6 +1720,7 @@ void AnEditor::SetStyleFor(Window &win, const char *lang) {
 			char key[200];
 			sprintf(key, "style.%s.%0d", lang, style);
 			SString sval = props->GetExpanded(key);
+			// g_print ("Style for %s:%0d == %s\n", lang, style, sval.c_str());
 			SetOneStyle(win, style, sval.c_str());
 		}
 	}
@@ -1711,10 +1789,14 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 		lexLanguage = SCLEX_DIFF;
 	} else if (language == "container") {
 		lexLanguage = SCLEX_CONTAINER;
-	} else if(language == "conf") {
+	} else if (language == "conf") {
 		lexLanguage = SCLEX_CONF;
-	} else if(language == "pascal") {
+	} else if (language == "pascal") {
 		lexLanguage = SCLEX_PASCAL;
+	} else if (language == "baan") {
+		lexLanguage = SCLEX_BAAN;
+	} else if (language == "ada") {
+		lexLanguage = SCLEX_ADA;
 	} else {
 		lexLanguage = SCLEX_NULL;
 	}
@@ -1725,7 +1807,7 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 		SendEditor(SCI_SETSTYLEBITS, 5);
 
 	SendEditor(SCI_SETLEXER, lexLanguage);
-
+	
 	SString kw0 = props->GetNewExpand("keywords.", fileNameForExtension.c_str());
 	SendEditorString(SCI_SETKEYWORDS, 0, kw0.c_str());
 	/* For C/C++ projects, get list of typedefs for colorizing */
@@ -1784,14 +1866,14 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 	}
 	else
 	{
-	SString kw1 = props->GetNewExpand("keywords2.", fileNameForExtension.c_str());
-	SendEditorString(SCI_SETKEYWORDS, 1, kw1.c_str());
-	SString kw2 = props->GetNewExpand("keywords3.", fileNameForExtension.c_str());
-	SendEditorString(SCI_SETKEYWORDS, 2, kw2.c_str());
-	SString kw3 = props->GetNewExpand("keywords4.", fileNameForExtension.c_str());
-	SendEditorString(SCI_SETKEYWORDS, 3, kw3.c_str());
-	SString kw4 = props->GetNewExpand("keywords5.", fileNameForExtension.c_str());
-	SendEditorString(SCI_SETKEYWORDS, 4, kw4.c_str());
+		SString kw1 = props->GetNewExpand("keywords2.", fileNameForExtension.c_str());
+		SendEditorString(SCI_SETKEYWORDS, 1, kw1.c_str());
+		SString kw2 = props->GetNewExpand("keywords3.", fileNameForExtension.c_str());
+		SendEditorString(SCI_SETKEYWORDS, 2, kw2.c_str());
+		SString kw3 = props->GetNewExpand("keywords4.", fileNameForExtension.c_str());
+		SendEditorString(SCI_SETKEYWORDS, 3, kw3.c_str());
+		SString kw4 = props->GetNewExpand("keywords5.", fileNameForExtension.c_str());
+		SendEditorString(SCI_SETKEYWORDS, 4, kw4.c_str());
 	}
 
 	SString fold = props->Get("fold");
@@ -1826,8 +1908,6 @@ void AnEditor::ReadProperties(const char *fileForExt) {
 	SendEditorString(SCI_SETPROPERTY, reinterpret_cast<unsigned long>("tab.timmy.whinge.level"),
 	                 ttwl.c_str());
 
-	SendEditor(SCI_SETEOLMODE, SC_EOL_LF);
-
 	characterSet = props->GetInt("character.set");
 
 	SString colour;
