@@ -40,6 +40,8 @@
 #include "project_dbase.h"
 #include "anjuta_info.h"
 
+#include "file_history.h"
+
 #define GTK
 #undef PLAT_GTK
 #define PLAT_GTK 1
@@ -56,6 +58,7 @@ static GdkCursor *app_cursor;
 void anjuta_child_terminated (int t);
 static void on_anjuta_window_selected (GtkMenuItem * menuitem,
 				       gpointer user_data);
+static void on_message_clicked(GtkObject* obj, char* message);					  
 static void anjuta_show_text_editor (TextEditor * te);
 static void plugins_foreach_delete( gpointer data, gpointer user_data );
 static void free_plug_ins( GList * pList );
@@ -99,7 +102,8 @@ anjuta_connect_kernel_signals ()
 void
 anjuta_new ()
 {
-	app = (AnjutaApp *) g_malloc (sizeof (AnjutaApp));
+	char wd[PATH_MAX];
+	app = (AnjutaApp *) g_malloc0(sizeof (AnjutaApp));
 	if (app)
 	{
 		/* Must declare static, because it will be used forever */
@@ -120,7 +124,6 @@ anjuta_new ()
 		};
 		app->size = sizeof(AnjutaApp);
 		app->addIns_list	= NULL ;
-		app->szDirPlugInDir	= PACKAGE_DATA_DIR "/plugins" ;
 		app->bUseComponentUI	= FALSE ;
 		app->shutdown_in_progress = FALSE;
 		app->registered_windows = NULL;
@@ -148,22 +151,24 @@ anjuta_new ()
 		app->fileselection = create_fileselection_gui (&fsd1);
 		
 		/* Set to the current dir */
-		fileselection_set_dir (app->fileselection, (gchar *)get_current_dir_name());
+		getcwd(wd, PATH_MAX);
+		fileselection_set_dir (app->fileselection, wd);
 		
+		app->preferences = preferences_new ();
 		app->save_as_fileselection = create_fileselection_gui (&fsd2);
 		app->save_as_build_msg_sel = create_fileselection_gui (&fsd3);
 		app->find_replace = find_replace_new ();
 		app->find_in_files = find_in_files_new ();
-		app->preferences = preferences_new ();
 		app->compiler_options = compiler_options_new (app->preferences->props);
 		app->src_paths = src_paths_new ();
-		app->messages = messages_new ();
+		app->messages = ANJUTA_MESSAGE_MANAGER(anjuta_message_manager_new ());
+		create_default_types(app->messages);
+		gtk_signal_connect(GTK_OBJECT(app->messages), "message_clicked", GTK_SIGNAL_FUNC(on_message_clicked), NULL);
 		app->project_dbase = project_dbase_new (app->preferences->props);
 		app->configurer = configurer_new (app->project_dbase->props);
 		app->executer = executer_new (app->project_dbase->props);
 		app->command_editor = command_editor_new (app->preferences->props_global,
 					app->preferences->props_local, app->project_dbase->props);
-		app->tags_manager = tags_manager_new ();
 		app->tm_workspace = tm_get_workspace();
 		if (TRUE != tm_workspace_load_global_tags(PACKAGE_DATA_DIR "/system.tags"))
 			g_warning("Unable to load global tag file");
@@ -176,15 +181,14 @@ anjuta_new ()
 		gtk_notebook_popup_enable (GTK_NOTEBOOK
 					   (app->widgets.notebook));
 		gtk_box_pack_start (GTK_BOX (app->widgets.mesg_win_container),
-				    app->messages->client, TRUE, TRUE, 0);
+				    GTK_WIDGET(app->messages), TRUE, TRUE, 0);
 		gtk_box_pack_start (GTK_BOX
 				    (app->widgets.
 				     project_dbase_win_container),
 				    app->project_dbase->widgets.client, TRUE,
 				    TRUE, 0);
 		project_dbase_hide (app->project_dbase);
-		messages_hide (app->messages);
-
+		gtk_widget_hide(GTK_WIDGET(app->messages));
 		gtk_paned_set_position (GTK_PANED (app->widgets.vpaned),
 					app->vpaned_height);
 		gtk_paned_set_position (GTK_PANED (app->widgets.hpaned),
@@ -192,7 +196,7 @@ anjuta_new ()
 		anjuta_update_title ();
 		launcher_init ();
 		debugger_init ();
-		app->addIns_list = scan_AddIns_in_directory( app, app->szDirPlugInDir, NULL );
+		app->addIns_list = scan_AddIns_in_directory( app, PACKAGE_PLUGIN_DIR, NULL );
 		{		
 			gchar *plugin_dir;
 			char const * const home_dir = getenv ("HOME");
@@ -219,7 +223,7 @@ anjuta_new ()
 	else
 	{
 		app = NULL;
-		g_error (_("Cannot create application...exiting\n"));
+		g_error (_("Cannot create application... exiting\n"));
 	}
 }
 
@@ -232,7 +236,7 @@ anjuta_session_restore (GnomeClient* client)
 TextEditor *
 anjuta_append_text_editor (gchar * filename)
 {
-	GtkWidget *label, *eventbox;
+	GtkWidget *tab_widget, *eventbox;
 	TextEditor *te, *cur_page;
 	gchar *buff;
 
@@ -250,21 +254,24 @@ anjuta_append_text_editor (gchar * filename)
 	switch (te->mode)
 	{
 	case TEXT_EDITOR_PAGED:
-		label = gtk_label_new (te->filename);
-		te->widgets.tab_label = label;
-		gtk_widget_show (label);
+		tab_widget = text_editor_tab_widget_new(te);
+	
 		eventbox = gtk_event_box_new ();
 		gtk_widget_show (eventbox);
 		gtk_notebook_prepend_page (GTK_NOTEBOOK
 					   (app->widgets.notebook), eventbox,
-					   label);
+					   tab_widget);
+		gtk_notebook_set_menu_label_text(GTK_NOTEBOOK
+						(app->widgets.notebook), eventbox,
+						te->filename);
+
 		gtk_container_add (GTK_CONTAINER (eventbox),
 				   te->widgets.client);
 	
 		/* For your kind info, this same data is also set in */
 		/* the function on_text_editor_dock_activated() */
 		gtk_object_set_data (GTK_OBJECT (eventbox), "TextEditor", te);
-
+		
 		if (te->full_filename)
 			buff =
 				g_strdup_printf (_("Anjuta: %s"),
@@ -373,12 +380,6 @@ anjuta_remove_text_editor (TextEditor* te)
 			g_list_remove (app->text_editor_list, te);
 		break;
 	}
-	if (te->full_filename)
-	{
-		if (app->project_dbase->project_is_open == FALSE)
-			tags_manager_remove (app->tags_manager,
-					     te->full_filename);
-	}
 	anjuta_fill_windows_menu ();
 	text_editor_destroy (te);
 	gtk_signal_connect (GTK_OBJECT (app->widgets.notebook), "switch_page",
@@ -394,8 +395,18 @@ anjuta_get_current_text_editor ()
 
 void
 anjuta_set_current_text_editor (TextEditor * te)
-{
+{	
+	TextEditor *ote = app->current_text_editor;
+	
+	if (ote != NULL && ote->buttons.close != NULL) {
+		gtk_widget_hide(ote->buttons.close);
+		gtk_widget_show(ote->widgets.close_pixmap);
+	}
 	app->current_text_editor = te;
+	if (te != NULL && te->buttons.close != NULL) {
+		gtk_widget_show(te->buttons.close);
+		gtk_widget_hide(te->widgets.close_pixmap);
+	}
 	main_toolbar_update ();
 	extended_toolbar_update ();
 	format_toolbar_update ();
@@ -455,21 +466,23 @@ anjuta_get_current_selection ()
 }
 
 TextEditor *
-anjuta_goto_file_line (gchar * fname, guint lineno)
+anjuta_goto_file_line (gchar * fname, glong lineno)
 {
 	return anjuta_goto_file_line_mark (fname, lineno, TRUE);
 }
 
 TextEditor *
-anjuta_goto_file_line_mark (gchar * fname, guint lineno, gboolean mark)
+anjuta_goto_file_line_mark (gchar * fname, glong lineno, gboolean mark)
 {
-	gchar *fn;
+	gchar *fn, *dummy;
 	GList *node;
 
 	TextEditor *te;
 
 	g_return_val_if_fail (fname != NULL, NULL);
-	fn = anjuta_get_full_filename (fname);
+	dummy = anjuta_get_full_filename (fname);
+	fn = resolved_file_name(dummy);
+	g_free(dummy);
 	g_return_val_if_fail (fname != NULL, NULL);
 	node = app->text_editor_list;
 	while (node)
@@ -487,17 +500,243 @@ anjuta_goto_file_line_mark (gchar * fname, guint lineno, gboolean mark)
 			anjuta_show_text_editor (te);
 			anjuta_grab_text_focus ();
 			g_free (fn);
+			an_file_history_push(te->full_filename, lineno);
 			return te ;
 		}
 		node = g_list_next (node);
 	}
 	te = anjuta_append_text_editor (fn);
-	if (lineno >= 0 && te)
-		text_editor_goto_line (te, lineno, mark);
+	if (te)
+	{
+		an_file_history_push(te->full_filename, lineno);
+		if (lineno >= 0)
+			text_editor_goto_line (te, lineno, mark);
+	}
 	g_free (fn);
 	return te ;
 }
 
+static const GString *get_qualified_tag_name(const TMTag *tag)
+{
+	static GString *s = NULL;
+
+	g_return_val_if_fail((tag && tag->name), NULL);
+	if (!s)
+		s = g_string_sized_new(255);
+	g_string_assign(s, "");
+	if (tag->atts.entry.scope)
+		g_string_sprintfa(s, "%s.", tag->atts.entry.scope);
+	g_string_sprintfa(s, "%s", tag->name);
+	return s;
+}
+
+const GList *anjuta_get_tag_list(TextEditor *te, guint tag_types)
+{
+	static GList *tag_names = NULL;
+
+	if (!te)
+		te = anjuta_get_current_text_editor();
+	if (te && (te->tm_file) && (te->tm_file->tags_array) &&
+		(te->tm_file->tags_array->len > 0))
+	{
+		TMTag *tag;
+		guint i;
+
+		if (tag_names)
+		{
+			GList *tmp;
+			for (tmp = tag_names; tmp; tmp = g_list_next(tmp))
+				g_free(tmp->data);
+			g_list_free(tag_names);
+			tag_names = NULL;
+		}
+
+		for (i=0; i < te->tm_file->tags_array->len; ++i)
+		{
+			tag = TM_TAG(te->tm_file->tags_array->pdata[i]);
+			if (tag->type & tag_types)
+				tag_names = g_list_prepend(tag_names, g_strdup(get_qualified_tag_name(tag)->str));
+		}
+		tag_names = g_list_sort(tag_names, (GCompareFunc) strcmp);
+		return tag_names;
+	}
+	else
+		return NULL;
+}
+
+GList *anjuta_get_file_list(void)
+{
+	const TMWorkspace *ws = tm_get_workspace();
+	TMWorkObject *wo;
+	static GList *files = NULL;
+	int i, j;
+
+	g_return_val_if_fail(ws && ws->work_objects, NULL);
+
+	if (files)
+	{
+		g_list_free(files);
+		files = NULL;
+	}
+
+	for (i=0; i < ws->work_objects->len; ++i)
+	{
+		wo = TM_WORK_OBJECT(ws->work_objects->pdata[i]);
+		if (IS_TM_SOURCE_FILE(wo))
+			files = g_list_append(files, wo->file_name);
+		else if (IS_TM_PROJECT(wo) && (TM_PROJECT(wo)->file_list))
+		{
+			for (j = 0; j < TM_PROJECT(wo)->file_list->len; ++j)
+				files = g_list_append(files
+				  , TM_WORK_OBJECT(TM_PROJECT(wo)->file_list->pdata[j])->file_name);
+		}
+	}
+	return files;
+}
+
+gboolean anjuta_goto_local_tag(TextEditor *te, const char *qual_name)
+{
+	char *name;
+	char *scope;
+	guint i;
+	int cmp;
+	TMTag *tag;
+
+	if (!qual_name || !te || !te->tm_file || !te->tm_file->tags_array
+	  || (0 == te->tm_file->tags_array->len))
+		return FALSE;
+	scope = g_strdup(qual_name);
+	name = strrchr(scope, '.');
+	if (name)
+	{
+		*name = '\0';
+		++ name;
+		
+	}
+	else
+	{
+		name = scope;
+		scope = NULL;
+	}
+
+	for (i = 0; i < te->tm_file->tags_array->len; ++i)
+	{
+		tag = TM_TAG(te->tm_file->tags_array->pdata[i]);
+		cmp = strcmp(name, tag->name);
+		if (0 == cmp)
+		{
+			if ((!scope || !tag->atts.entry.scope) || (0 == strcmp(scope, tag->atts.entry.scope)))
+			{
+				text_editor_goto_line(te, tag->atts.entry.line, TRUE);
+				g_free(scope?scope:name);
+				return TRUE;
+			}
+		}
+		else if (cmp < 0)
+		{
+			g_free(scope?scope:name);
+			return FALSE;
+		}
+	}
+	g_free(scope?scope:name);
+	return FALSE;
+}
+
+#define IS_DECLARATION(T) ((tm_tag_prototype_t == (T)) || (tm_tag_externvar_t == (T)) \
+  || (tm_tag_typedef_t == (T)))
+
+void anjuta_goto_tag(const char *symbol, TextEditor *te, gboolean prefer_definition)
+{
+	GPtrArray *tags;
+	TMTag *tag = NULL, *local_tag = NULL, *global_tag = NULL;
+	TMTag *local_proto = NULL, *global_proto = NULL;
+	guint i;
+	int cmp;
+
+	g_return_if_fail(symbol);
+
+	if (!te)
+		te = anjuta_get_current_text_editor();
+
+	/* Get the matching definition and declaration in the local file */
+	if (te && (te->tm_file) && (te->tm_file->tags_array) &&
+		(te->tm_file->tags_array->len > 0))
+	{
+		for (i=0; i < te->tm_file->tags_array->len; ++i)
+		{
+			tag = TM_TAG(te->tm_file->tags_array->pdata[i]);
+			cmp =  strcmp(symbol, tag->name);
+			if (0 == cmp)
+			{
+				if (IS_DECLARATION(tag->type))
+					local_proto = tag;
+				else
+					local_tag = tag;
+			}
+			else if (cmp < 0)
+				break;
+		}
+	}
+	if (!(((prefer_definition) && (local_tag)) || ((!prefer_definition) && (local_proto))))
+	{
+		/* Get the matching definition and declaration in the workspace */
+		tags =  TM_WORK_OBJECT(tm_get_workspace())->tags_array;
+		if (tags && (tags->len > 0))
+		{
+			for (i=0; i < tags->len; ++i)
+			{
+				tag = TM_TAG(tags->pdata[i]);
+				if (tag->atts.entry.file)
+				{
+					cmp = strcmp(symbol, tag->name);
+					if (cmp == 0)
+					{
+						if (IS_DECLARATION(tag->type))
+							global_proto = tag;
+						else
+							global_tag = tag;
+					}
+					else if (cmp < 0)
+						break;
+				}
+			}
+		}
+	}
+	if (prefer_definition)
+	{
+		if (local_tag)
+			tag = local_tag;
+		else if (global_tag)
+			tag = global_tag;
+		else if (local_proto)
+			tag = local_proto;
+		else
+			tag = global_proto;
+	}
+	else
+	{
+		if (local_proto)
+			tag = local_proto;
+		else if (global_proto)
+			tag = global_proto;
+		else if (local_tag)
+			tag = local_tag;
+		else
+			tag = global_tag;
+	}
+
+	if (te)
+	{
+		an_file_history_push(te->full_filename
+		  , aneditor_command(te->editor_id, ANE_GET_LINENO, (long) NULL, (long) NULL));
+	}
+	if (tag)
+	{
+		anjuta_goto_file_line_mark(tag->atts.entry.file->work_object.file_name
+		  , tag->atts.entry.line, TRUE);
+	}
+}
+
 static void
 anjuta_show_text_editor (TextEditor * te)
 {
@@ -591,7 +830,6 @@ anjuta_show ()
 	/* We do not resize or set the change in props */
 	anjuta_toolbar_set_view (ANJUTA_MAIN_TOOLBAR, FALSE, FALSE, FALSE);
 	anjuta_toolbar_set_view (ANJUTA_EXTENDED_TOOLBAR, FALSE, FALSE, FALSE);
-	anjuta_toolbar_set_view (ANJUTA_TAGS_TOOLBAR, FALSE, FALSE, FALSE);
 	anjuta_toolbar_set_view (ANJUTA_DEBUG_TOOLBAR, FALSE, FALSE, FALSE);
 	anjuta_toolbar_set_view (ANJUTA_BROWSER_TOOLBAR, FALSE, FALSE, FALSE);
 	anjuta_toolbar_set_view (ANJUTA_FORMAT_TOOLBAR, FALSE, FALSE, FALSE);
@@ -610,12 +848,6 @@ anjuta_show ()
 			prop_get_int (pr, key, 1));
 	g_free (key);
 
-	key = g_strconcat (ANJUTA_TAGS_TOOLBAR, ".visible", NULL);
-	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
-			(app->widgets.menubar. view.tags_toolbar),
-			prop_get_int (pr, key, 1));
-	g_free (key);
-
 	key = g_strconcat (ANJUTA_DEBUG_TOOLBAR, ".visible", NULL);
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM
 			(app->widgets.menubar. view.debug_toolbar),
@@ -635,8 +867,11 @@ anjuta_show ()
 	g_free (key);
 	
 	update_gtk ();
-	messages_append (app->messages,
+	
+	/*
+	anjuta_message_manager_append (app->messages,
 			 _("CVS is not yet implemented. :-(\n"), MESSAGE_CVS);
+	*/
 	
 	if (app->dirs->first_time)
 	{
@@ -710,10 +945,6 @@ gboolean anjuta_save_yourself (FILE * stream)
 	fprintf (stream, "%s=%d\n", key, prop_get_int (app->preferences->props, key, 1));
 	g_free (key);
 
-	key = g_strconcat (ANJUTA_TAGS_TOOLBAR, ".visible", NULL);
-	fprintf (stream, "%s=%d\n", key, prop_get_int (app->preferences->props, key, 1));
-	g_free (key);
-
 	key = g_strconcat (ANJUTA_BROWSER_TOOLBAR, ".visible", NULL);
 	fprintf (stream, "%s=%d\n", key, prop_get_int (app->preferences->props, key, 1));
 	g_free (key);
@@ -755,7 +986,7 @@ gboolean anjuta_save_yourself (FILE * stream)
 #endif
 
 	fprintf (stream, "\n\n");
-	messages_save_yourself (app->messages, stream);
+	anjuta_message_manager_save_yourself (app->messages, stream);
 	project_dbase_save_yourself (app->project_dbase, stream);
 
 	compiler_options_save_yourself (app->compiler_options, stream);
@@ -779,6 +1010,8 @@ gboolean anjuta_load_yourself (PropsID pr)
 {
 	gint length;
 
+	preferences_load_yourself (app->preferences, pr);
+	
 	app->win_pos_x = prop_get_int (pr, "anjuta.win.pos.x", 10);
 	app->win_pos_y = prop_get_int (pr, "anjuta.win.pos.y", 10);
 	app->win_width =
@@ -806,9 +1039,8 @@ gboolean anjuta_load_yourself (PropsID pr)
 #else
 	app->recent_projects = anjuta_session_load_strings( SECSTR(SECTION_RECENTPROJECTS), NULL );
 #endif
-	messages_load_yourself (app->messages, pr);
+	anjuta_message_manager_load_yourself (app->messages, pr);
 	project_dbase_load_yourself (app->project_dbase, pr);
-	preferences_load_yourself (app->preferences, pr);
 	compiler_options_load_yourself (app->compiler_options, pr);
 	compiler_options_load (app->compiler_options, pr);
 	src_paths_load_yourself (app->src_paths, pr);
@@ -818,6 +1050,20 @@ gboolean anjuta_load_yourself (PropsID pr)
 	return TRUE;
 }
 
+void
+anjuta_save_all_files()
+{
+	TextEditor *te;
+	int i;
+	for (i = 0; i < g_list_length (app->text_editor_list); i++)
+	{
+		te = g_list_nth_data (app->text_editor_list, i);
+		if (te->full_filename && !text_editor_is_saved (te))
+			text_editor_save_file (te);
+	}
+	anjuta_status (_("All files saved ..."));
+}
+
 void
 anjuta_update_title ()
 {
@@ -843,7 +1089,7 @@ anjuta_update_title ()
 			if (te->full_filename)
 			{
 				buff1 =
-					g_strdup_printf (_("Anjuta: %s(Saved)"),
+					g_strdup_printf (_("Anjuta: %s (Saved)"),
 							 te->full_filename);
 			} else
 			{
@@ -858,7 +1104,7 @@ anjuta_update_title ()
 			if (te->full_filename)
 			{
 				buff1 =
-					g_strdup_printf (_("Anjuta: %s(Unsaved)"),
+					g_strdup_printf (_("Anjuta: %s (Unsaved)"),
 							 te->full_filename);
 			}
 			else
@@ -872,8 +1118,6 @@ anjuta_update_title ()
 		if (te->full_filename)
 		{
 			gtk_window_set_title (GTK_WINDOW (window), buff1);
-			tags_manager_set_filename (app->tags_manager,
-						   te->full_filename);
 		}
 		else
 		{
@@ -966,7 +1210,7 @@ anjuta_apply_preferences (void)
 		gtk_notebook_set_show_tabs (GTK_NOTEBOOK
 					    (app->widgets.notebook), TRUE);
 	}
-	messages_update (app->messages);
+	anjuta_message_manager_update(app->messages);
 	for (i = 0; i < g_list_length (app->text_editor_list); i++)
 	{
 		te =	(TextEditor*) (g_list_nth (app->text_editor_list, i)->data);
@@ -991,7 +1235,6 @@ anjuta_application_exit(void)
 	{
 		project_dbase_close_project(app->project_dbase) ;
 	}
-	tm_workspace_free(tm_get_workspace());
 	free_plug_ins( app->addIns_list );
 	app->addIns_list	= NULL ;
 }
@@ -1009,6 +1252,11 @@ anjuta_clean_exit ()
 		g_strdup_printf ("rm -f %s/anjuta_*.%ld",
 				 app->dirs->tmp, (long) getpid ());
 	pid = gnome_execute_shell (app->dirs->home, tmp);
+	if (-1 == pid)
+	{
+		perror("Cleanup failed");
+		exit(1);
+	}
 	waitpid (pid, NULL, 0);
 
 /* Is it necessary to free up all the memos on exit? */
@@ -1068,7 +1316,7 @@ anjuta_clean_exit ()
 	if (app->src_paths)
 		src_paths_destroy (app->src_paths);
 	if (app->messages)
-		messages_destroy (app->messages);
+		gtk_widget_destroy(GTK_WIDGET(app->messages));
 	if (app->project_dbase)
 		project_dbase_destroy (app->project_dbase);
 	if (app->command_editor)
@@ -1083,8 +1331,6 @@ anjuta_clean_exit ()
 		executer_destroy (app->executer);
 	if (app->configurer)
 		configurer_destroy (app->configurer);
-	if (app->tags_manager)
-		tags_manager_destroy (app->tags_manager);
 	if (app->execution_dir)
 		g_free (app->execution_dir);
 	debugger_shutdown ();
@@ -1102,8 +1348,6 @@ anjuta_clean_exit ()
 	gtk_main_quit ();
 }
 
-
-
 void
 anjuta_status (gchar * mesg, ...)
 {
@@ -1210,7 +1454,7 @@ anjuta_open_file (gchar* fname)
 	g_free (cmd);
 	if(list == NULL)
 	{
-		anjuta_goto_file_line (fname, -1);
+		anjuta_goto_file_line_mark (fname, -1, FALSE);
 		return;
 	}
 	if (anjuta_is_installed ((gchar*)list->data, TRUE))
@@ -1301,6 +1545,7 @@ anjuta_get_full_filename (gchar * fn)
 	{
 		gchar *src_dir;
 
+		/* See if it on of the source files */
 		src_dir = project_dbase_get_module_dir (app->project_dbase, MODULE_SOURCE);
 		dummy = g_strconcat (src_dir, "/", fn, NULL);
 		g_free (src_dir);
@@ -1310,6 +1555,18 @@ anjuta_get_full_filename (gchar * fn)
 			return dummy;
 		}
 		g_free (dummy);
+		
+		/* See if the file is relative to the top project dir */
+		src_dir = app->project_dbase->top_proj_dir;
+		if (src_dir) {
+			dummy = g_strconcat (src_dir, "/", fn, NULL);
+			if (file_is_regular (dummy) == TRUE)
+			{
+				g_free (cur_dir);
+				return dummy;
+			}
+			g_free (dummy);
+		}
 	}
 	else
 	{
@@ -1619,7 +1876,7 @@ anjuta_fill_windows_menu ()
 	if (count > 0)
 	{
 		gnome_app_insert_menus (GNOME_APP (app->widgets.window),
-					"_Windows/Cl_ose Current window",
+					"_Windows/Cl_ose current window",
 					sep);
 		for (i = (count - 1); i >= 0; i--)
 		{
@@ -1653,7 +1910,7 @@ gboolean anjuta_is_installed (gchar * prog, gboolean show)
 	if (show)
 	{
 		anjuta_error (_
-					 ("You do not have \"%s\" installed in your box.\n"
+					 ("The \"%s\" utility is not installed.\n"
 					  "Install it and then restart Anjuta."), prog);
 	}
 	return FALSE;
@@ -1662,7 +1919,7 @@ gboolean anjuta_is_installed (gchar * prog, gboolean show)
 void
 anjuta_update_app_status (gboolean set_job, gchar* job_name)
 {
-	gchar *prj, *edit, *job;
+	gchar *prj, *edit, *job, *mode;
 	guint line, col, caret_pos;
 	gchar *str;
 	gint zoom;
@@ -1683,6 +1940,25 @@ anjuta_update_app_status (gboolean set_job, gchar* job_name)
 	zoom = prop_get_int (app->preferences->props, "text.zoom.factor", 0);
 	if (sci)
 	{
+		gint editor_mode;
+		
+		editor_mode =  scintilla_send_message (SCINTILLA (te->widgets.editor),
+			SCI_GETEOLMODE, 0, 0);
+		switch (editor_mode) {
+			case SC_EOL_CRLF:
+				mode = g_strdup(_("DOS (CRLF)"));
+				break;
+			case SC_EOL_LF:
+				mode = g_strdup(_("Unix (LF)"));
+				break;
+			case SC_EOL_CR:
+				mode = g_strdup(_("Mac (CR)"));
+				break;
+			default:
+				mode = g_strdup(_("Unknown"));
+				break;
+		}
+
 		caret_pos =
 			scintilla_send_message (SCINTILLA (sci),
 						SCI_GETCURRENTPOS, 0, 0);
@@ -1707,6 +1983,7 @@ anjuta_update_app_status (gboolean set_job, gchar* job_name)
 	{
 		line = col = 0;
 		edit = g_strdup (_("INS"));
+		mode = g_strdup(_("Unix (LF)"));
 	}
 	if (set_job)
 		string_assign (&app->cur_job, job_name);
@@ -1717,13 +1994,14 @@ anjuta_update_app_status (gboolean set_job, gchar* job_name)
 		job = g_strdup (_("None"));
 	str =
 		g_strdup_printf(
-		_("  Project: %s       Zoom: %d       Line: %04d       Col: %03d       %s       Job: %s"),
-		 prj, zoom, line+1, col, edit, job);
+		_("  Project: %s       Zoom: %d       Line: %04d       Col: %03d       %s       Job: %s       Mode: %s"),
+		 prj, zoom, line+1, col, edit, job, mode);
 	gnome_appbar_set_default (GNOME_APPBAR (app->widgets.appbar), str);
 	g_free (str);
 	g_free (prj);
 	g_free (edit);
 	g_free (job);
+	g_free (mode);
 }
 
 void
@@ -1929,19 +2207,19 @@ Load_plugIn( AnjutaAddInPtr self, const gchar *szModName )
 	switch( lErr )
 	{
 	default:
-		syslog( LOG_WARNING|LOG_USER, _("Unable to Load Plug in Module %s. Err: %s"), szModName, pErr );
+		syslog( LOG_WARNING|LOG_USER, _("Unable to load plugin %s. Error: %s"), szModName, pErr );
 		break;
 	case PIE_NOTLOADED:
-		syslog( LOG_WARNING|LOG_USER, _("Unable to Load Plug in Module %s. Err: %s"), szModName, pErr );
+		syslog( LOG_WARNING|LOG_USER, _("Unable to load plugin %s. Error: %s"), szModName, pErr );
 		break;
 	case PIE_SYMBOLSNOTFOUND:
-		syslog( LOG_WARNING|LOG_USER, _("Plug in Module protocol unknown %s Err:%s"), szModName, pErr );
+		syslog( LOG_WARNING|LOG_USER, _("Plugin protocol %s unknown Error:%s"), szModName, pErr );
 		break;
 	case PIE_INITFAILED:
-		syslog( LOG_WARNING|LOG_USER, _("Unable to Start Plug in Module %s"), szModName );
+		syslog( LOG_WARNING|LOG_USER, _("Unable to start plugin %s"), szModName );
 		break;
 	case PIE_BADPARMS:
-		syslog( LOG_WARNING|LOG_USER, _("Bad Parameters to Plug in %s. Err: %s"), szModName, pErr );
+		syslog( LOG_WARNING|LOG_USER, _("Bad parameters to plugin %s. Error: %s"), szModName, pErr );
 		break;
 	case PIE_OK:
 		bOK = TRUE ;
@@ -1949,7 +2227,7 @@ Load_plugIn( AnjutaAddInPtr self, const gchar *szModName )
 	}
 		
 	if( ! bOK )
-		anjuta_error ( _("Unable to load plugin %s.\nError %s"), szModName, pErr  );
+		anjuta_error ( _("Unable to load plugin %s.\nError: %s"), szModName, pErr  );
 	return bOK ;
 }
 
@@ -2004,8 +2282,9 @@ scan_AddIns_in_directory (AnjutaApp* pApp, const gchar *szDirName, GList *pList)
 			
 		entry_name = (const char*) node->data;
 		node = g_list_next (node);
-			
-		if ((NULL != entry_name) && strlen (entry_name) > 3 && (NULL != strstr (entry_name, ".so")))
+
+		if ((NULL != entry_name) && strlen (entry_name) > 3
+			&& (0 == strcmp (&entry_name[strlen(entry_name)-3], ".so")))
 		{
 			/* FIXME: e questo ? bah library_file = g_module_build_path (module_dir, module_file); */
 			gchar *pPIPath = g_strdup_printf ("%s/%s", szDirName, entry_name);
@@ -2019,7 +2298,7 @@ scan_AddIns_in_directory (AnjutaApp* pApp, const gchar *szDirName, GList *pList)
 					bOK = TRUE ;
 				}
 			} else
-				anjuta_error (_("Out of Memory scanning for plugins."));
+				anjuta_error (_("Out of memory scanning for plugins."));
 
 			g_free (pPIPath);
 
@@ -2033,3 +2312,13 @@ scan_AddIns_in_directory (AnjutaApp* pApp, const gchar *szDirName, GList *pList)
 	return pList;
 }
 
+static void on_message_clicked(GtkObject* obj, char* message)
+{
+	char* fn;
+	int ln;
+	if (parse_error_line (message, &fn, &ln))
+	{
+		anjuta_goto_file_line (fn, ln);
+		g_free (fn);
+	}
+}
