@@ -28,7 +28,6 @@
 #include "anjuta.h"
 #include "resources.h"
 #include "main_menubar.h"
-#include "notebook.h"
 #include "dnd.h"
 
 
@@ -43,7 +42,6 @@ create_anjuta_gui (AnjutaApp * appl)
 	GtkWidget *toolbar3;
 	GtkWidget *toolbar4;
 	GtkWidget *toolbar5;
-	GtkWidget *toolbar6;
 	GtkWidget *vpaned1;
 	GtkWidget *hpaned1;
 	GtkWidget *vbox1;
@@ -102,15 +100,16 @@ create_anjuta_gui (AnjutaApp * appl)
 				     GTK_TOOLBAR_SPACE_LINE);
 	gtk_toolbar_set_button_relief (GTK_TOOLBAR (toolbar1),
 				       GTK_RELIEF_NONE);
-
+	
 	toolbar2 =
-		create_extended_toolbar (anjuta_gui,
-					 &(appl->widgets.toolbar.
-					   extended_toolbar));
+		create_browser_toolbar (anjuta_gui,
+					&(appl->widgets.toolbar.
+					  browser_toolbar));
 	gnome_app_add_toolbar (GNOME_APP (anjuta_gui), GTK_TOOLBAR (toolbar2),
-			       ANJUTA_EXTENDED_TOOLBAR,
-			       GNOME_DOCK_ITEM_BEH_NORMAL,
-			       GNOME_DOCK_TOP, 3, 0, 0);
+			       ANJUTA_BROWSER_TOOLBAR,
+			       GNOME_DOCK_ITEM_BEH_EXCLUSIVE |
+			       GNOME_DOCK_ITEM_BEH_NEVER_VERTICAL,
+			       GNOME_DOCK_TOP, 2, 0, 0);
 	gtk_toolbar_set_space_size (GTK_TOOLBAR (toolbar2), 5);
 	gtk_toolbar_set_space_style (GTK_TOOLBAR (toolbar2),
 				     GTK_TOOLBAR_SPACE_LINE);
@@ -118,13 +117,13 @@ create_anjuta_gui (AnjutaApp * appl)
 				       GTK_RELIEF_NONE);
 
 	toolbar3 =
-		create_tags_toolbar (anjuta_gui,
-				     &(appl->widgets.toolbar.tags_toolbar));
+		create_debug_toolbar (anjuta_gui,
+					 &(appl->widgets.toolbar.
+					   debug_toolbar));
 	gnome_app_add_toolbar (GNOME_APP (anjuta_gui), GTK_TOOLBAR (toolbar3),
-			       ANJUTA_TAGS_TOOLBAR,
-			       GNOME_DOCK_ITEM_BEH_EXCLUSIVE |
-			       GNOME_DOCK_ITEM_BEH_NEVER_VERTICAL,
-			       GNOME_DOCK_TOP, 2, 0, 0);
+			       ANJUTA_DEBUG_TOOLBAR,
+			       GNOME_DOCK_ITEM_BEH_NORMAL,
+			       GNOME_DOCK_TOP, 3, 0, 0);
 	gtk_toolbar_set_space_size (GTK_TOOLBAR (toolbar3), 5);
 	gtk_toolbar_set_space_style (GTK_TOOLBAR (toolbar3),
 				     GTK_TOOLBAR_SPACE_LINE);
@@ -132,10 +131,10 @@ create_anjuta_gui (AnjutaApp * appl)
 				       GTK_RELIEF_NONE);
 
 	toolbar4 =
-		create_debug_toolbar (anjuta_gui,
-				      &(appl->widgets.toolbar.debug_toolbar));
+		create_format_toolbar (anjuta_gui,
+				      &(appl->widgets.toolbar.format_toolbar));
 	gnome_app_add_toolbar (GNOME_APP (anjuta_gui), GTK_TOOLBAR (toolbar4),
-			       ANJUTA_DEBUG_TOOLBAR,
+			       ANJUTA_FORMAT_TOOLBAR,
 			       GNOME_DOCK_ITEM_BEH_NORMAL,
 			       GNOME_DOCK_TOP, 3, 1, 0);
 	gtk_toolbar_set_space_size (GTK_TOOLBAR (toolbar4), 5);
@@ -145,11 +144,11 @@ create_anjuta_gui (AnjutaApp * appl)
 				       GTK_RELIEF_NONE);
 
 	toolbar5 =
-		create_browser_toolbar (anjuta_gui,
-					&(appl->widgets.toolbar.
-					  browser_toolbar));
+		create_extended_toolbar (anjuta_gui,
+				       &(appl->widgets.toolbar.
+					 extended_toolbar));
 	gnome_app_add_toolbar (GNOME_APP (anjuta_gui), GTK_TOOLBAR (toolbar5),
-			       ANJUTA_BROWSER_TOOLBAR,
+			       ANJUTA_EXTENDED_TOOLBAR,
 			       GNOME_DOCK_ITEM_BEH_NORMAL,
 			       GNOME_DOCK_TOP, 4, 0, 0);
 	gtk_toolbar_set_space_size (GTK_TOOLBAR (toolbar5), 5);
@@ -158,20 +157,6 @@ create_anjuta_gui (AnjutaApp * appl)
 	gtk_toolbar_set_button_relief (GTK_TOOLBAR (toolbar5),
 				       GTK_RELIEF_NONE);
 
-	toolbar6 =
-		create_format_toolbar (anjuta_gui,
-				       &(appl->widgets.toolbar.
-					 format_toolbar));
-	gnome_app_add_toolbar (GNOME_APP (anjuta_gui), GTK_TOOLBAR (toolbar6),
-			       ANJUTA_FORMAT_TOOLBAR,
-			       GNOME_DOCK_ITEM_BEH_NORMAL,
-			       GNOME_DOCK_TOP, 4, 1, 0);
-	gtk_toolbar_set_space_size (GTK_TOOLBAR (toolbar6), 5);
-	gtk_toolbar_set_space_style (GTK_TOOLBAR (toolbar6),
-				     GTK_TOOLBAR_SPACE_LINE);
-	gtk_toolbar_set_button_relief (GTK_TOOLBAR (toolbar6),
-				       GTK_RELIEF_NONE);
-
 	eventbox1 = gtk_event_box_new ();
 	gtk_widget_ref (eventbox1);
 	gtk_widget_show (eventbox1);
@@ -301,7 +286,7 @@ create_anjuta_gui (AnjutaApp * appl)
 	gtk_widget_show (pixmap);
 	gtk_container_add (GTK_CONTAINER (button2), pixmap);
 
-	anjuta_notebook = notebook_new ();
+	anjuta_notebook = gtk_notebook_new ();
 	gtk_widget_ref (anjuta_notebook);
 	gtk_widget_show (anjuta_notebook);
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (anjuta_notebook), TRUE);
@@ -316,7 +301,9 @@ create_anjuta_gui (AnjutaApp * appl)
 	gtk_signal_connect (GTK_OBJECT (anjuta_gui), "focus_in_event",
 			    GTK_SIGNAL_FUNC (on_anjuta_window_focus_in_event),
 			    NULL);
-
+	gtk_signal_connect (GTK_OBJECT (anjuta_gui), "key_press_event",
+			    GTK_SIGNAL_FUNC (on_anjuta_window_key_press_event),
+			    NULL);
 	gtk_signal_connect (GTK_OBJECT (anjuta_gui), "delete_event",
 			    GTK_SIGNAL_FUNC (on_anjuta_delete), NULL);
 	gtk_signal_connect (GTK_OBJECT (anjuta_gui), "destroy",
