@@ -27,7 +27,7 @@
 
 #include <gnome.h>
 
-#include "support.h"
+#include "resources.h"
 #include "utilities.h"
 #include "anjuta_info.h"
 
@@ -40,7 +40,7 @@ create_anjuta_info_dialog_with_less (gint height, gint width)
   GtkWidget *dialog_action_area1;
   GtkWidget *button1;
 
-  dialog1 = gnome_dialog_new (_("Anjuta: Information"), NULL);
+  dialog1 = gnome_dialog_new (_("Information"), NULL);
   gtk_widget_set_usize (dialog1, 400, 250);
   gnome_dialog_set_close (GNOME_DIALOG (dialog1), TRUE);
   gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, TRUE, FALSE);
@@ -49,6 +49,7 @@ create_anjuta_info_dialog_with_less (gint height, gint width)
   if (width < 400)
     width = 400;
   gtk_window_set_default_size (GTK_WINDOW (dialog1), width, height);
+  gtk_window_set_wmclass (GTK_WINDOW (dialog1), "infoless", "Anjuta");
   dialog_vbox1 = GNOME_DIALOG (dialog1)->vbox;
   gtk_widget_show (dialog_vbox1);
 
@@ -85,7 +86,7 @@ create_anjuta_info_dialog_with_clist (gint height, gint width)
   GtkWidget *button1;
   GdkFont   *font;
 
-  dialog1 = gnome_dialog_new (_("Anjuta: Information"), NULL);
+  dialog1 = gnome_dialog_new (_("Information"), NULL);
   gtk_widget_set_usize (dialog1, 400, 250);
   gnome_dialog_set_close (GNOME_DIALOG (dialog1), TRUE);
   gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, TRUE, FALSE);
@@ -94,6 +95,7 @@ create_anjuta_info_dialog_with_clist (gint height, gint width)
   if (width < 400)
     width = 400;
   gtk_window_set_default_size (GTK_WINDOW (dialog1), width, height);
+  gtk_window_set_wmclass (GTK_WINDOW (dialog1), "infoclist", "Anjuta");
   dialog_vbox1 = GNOME_DIALOG (dialog1)->vbox;
   gtk_widget_show (dialog_vbox1);
 
