@@ -28,7 +28,7 @@
 #include <string.h>
 
 #include <gnome.h>
-#include "support.h"
+#include "resources.h"
 #include "attach_process.h"
 #include "global.h"
 #include "anjuta.h"
