@@ -30,7 +30,7 @@
 #include <gnome.h>
 #include "anjuta.h"
 #include "launcher.h"
-#include "messages.h"
+#include "message-manager.h"
 #include "compile.h"
 #include "build_file.h"
 
@@ -48,7 +48,7 @@ build_file ()
 		return;
 	if (te->full_filename == NULL)
 	{
-		anjuta_warning (_("File is not saved. Save it and build."));
+		anjuta_warning (_("This file has not been saved. Save it first and then build."));
 		return;
 	}
 	if (text_editor_is_saved (te) == FALSE)
@@ -73,7 +73,7 @@ build_file ()
 		if ((flg == 0) && (st2.st_mtime > st1.st_mtime))
 		{
 			anjuta_warning (_
-					("The executable is up-to-date. No need to build again."));
+					("The executable is up-to-date, there is no need to build it again."));
 			g_free (filename);
 			return;
 		}
@@ -89,7 +89,7 @@ build_file ()
 	if (cmd == NULL)
 	{
 		anjuta_warning (_
-				("I do not really know how to build this file."));
+				("No build command has been specified for this type of file."));
 		return;
 	}
 	dirname = g_dirname (te->full_filename);
@@ -105,12 +105,12 @@ build_file ()
 		return;
 	}
 	anjuta_update_app_status (TRUE, _("Build"));
-	messages_clear (app->messages, MESSAGE_BUILD);
+	anjuta_message_manager_clear (app->messages, MESSAGE_BUILD);
 	buff = g_strdup_printf (_("Building file: %s ...\n"), te->filename);
-	messages_append (app->messages, buff, MESSAGE_BUILD);
-	messages_append (app->messages, cmd, MESSAGE_BUILD);
-	messages_append (app->messages, "\n", MESSAGE_BUILD);
-	messages_show (app->messages, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, buff, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, cmd, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, "\n", MESSAGE_BUILD);
+	anjuta_message_manager_show (app->messages, MESSAGE_BUILD);
 	g_free (cmd);
 	g_free (buff);
 }
@@ -118,7 +118,7 @@ build_file ()
 static void
 build_file_mesg_arrived (gchar * mesg)
 {
-	messages_append (app->messages, mesg, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, mesg, MESSAGE_BUILD);
 }
 
 static void
@@ -131,19 +131,19 @@ build_file_terminated (int status, time_t time)
 				 (int) time);
 	if (WEXITSTATUS (status))
 	{
-		messages_append (app->messages,
+		anjuta_message_manager_append (app->messages,
 				 _("Build completed ... unsuccessful\n"),
 				 MESSAGE_BUILD);
 		anjuta_warning (_("Build completed ... unsuccessful"));
 	}
 	else
 	{
-		messages_append (app->messages,
+		anjuta_message_manager_append (app->messages,
 				 _("Build completed ... successful\n"),
 				 MESSAGE_BUILD);
 		anjuta_status (_("Build completed ... successful"));
 	}
-	messages_append (app->messages, buff1, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, buff1, MESSAGE_BUILD);
 	if (preferences_get_int (app->preferences, BEEP_ON_BUILD_COMPLETE))
 		gdk_beep ();
 	g_free (buff1);
