@@ -30,7 +30,7 @@
 #include <gnome.h>
 #include "anjuta.h"
 #include "launcher.h"
-#include "messages.h"
+#include "message-manager.h"
 #include "compile.h"
 
 #if 0
@@ -57,7 +57,7 @@ compile_file_with_make ()
 		cmd = command_editor_get_command (app->command_editor, COMMAND_BUILD_MODULE);
 		if (cmd == NULL)
 		{
-			anjuta_warning (_("Unable to build module. Check Preferences->Commands."));
+			anjuta_warning (_("Unable to build module. Check Settings->Commands."));
 			g_free (src_dir);
 			return;
 		}
@@ -73,15 +73,15 @@ compile_file_with_make ()
 			return;
 		}
 		anjuta_update_app_status (TRUE, _("Build Project"));
-		messages_clear (app->messages, MESSAGE_BUILD);
-		messages_append (app->messages, _("Building source directory of the project: "),
+		anjuta_message_manager_clear (app->messages, MESSAGE_BUILD);
+		anjuta_message_manager_append (app->messages, _("Building source directory of the Project: "),
 				 MESSAGE_BUILD);
 		prj_name = project_dbase_get_proj_name (app->project_dbase);
-		messages_append (app->messages, prj_name, MESSAGE_BUILD);
-		messages_append (app->messages, " ...\n", MESSAGE_BUILD);
-		messages_append (app->messages, cmd, MESSAGE_BUILD);
-		messages_append (app->messages, "\n", MESSAGE_BUILD);
-		messages_show (app->messages, MESSAGE_BUILD);
+		anjuta_message_manager_append (app->messages, prj_name, MESSAGE_BUILD);
+		anjuta_message_manager_append (app->messages, " ...\n", MESSAGE_BUILD);
+		anjuta_message_manager_append (app->messages, cmd, MESSAGE_BUILD);
+		anjuta_message_manager_append (app->messages, "\n", MESSAGE_BUILD);
+		anjuta_message_manager_show (app->messages, MESSAGE_BUILD);
 		g_free (cmd);
 		g_free (prj_name);
 	}
@@ -95,7 +95,7 @@ compile_file_with_make ()
 #endif
 
 void
-compile_file ()
+compile_file (gboolean use_make)
 {
 	gchar *dirname, *cmd, *buff;
 	TextEditor *te;
@@ -105,7 +105,7 @@ compile_file ()
 	
 	if (te->full_filename == NULL)
 	{
-		anjuta_warning (_("This file is not saved. Save it first and then compile."));
+		anjuta_warning (_("This file has not been saved. Save it first and then compile."));
 		return;
 	}
 	if (text_editor_is_saved(te) == FALSE)
@@ -126,7 +126,7 @@ compile_file ()
 	flg = stat (filename, &st2);
 	if ((flg == 0) && (st2.st_mtime > st1.st_mtime))
 	{
-		anjuta_warning (_("The object file is up to date. No need to compile again."));
+		anjuta_warning (_("The object file is up-to-date, there is no need to compile it again."));
 		g_free (filename);
 		return;
 	}
@@ -134,13 +134,11 @@ compile_file ()
 #endif
 
 	anjuta_set_file_properties (te->full_filename);
-	cmd =
-		command_editor_get_command_file (app->command_editor,
-						 COMMAND_COMPILE_FILE,
-						 te->filename);
+	cmd = command_editor_get_command_file (app->command_editor,
+		use_make?COMMAND_MAKE_FILE:COMMAND_COMPILE_FILE, te->filename);
 	if (cmd == NULL)
 	{
-		anjuta_warning (_("I do not really know how to compile this file."));
+		anjuta_warning (_("No compile command has been specified for this type of file."));
 		return;
 	}
 	dirname = g_dirname (te->full_filename);
@@ -154,12 +152,12 @@ compile_file ()
 		return;
 	}
 	anjuta_update_app_status (TRUE, _("Compile"));
-	messages_clear (app->messages, MESSAGE_BUILD);
+	anjuta_message_manager_clear (app->messages, MESSAGE_BUILD);
 	buff = g_strdup_printf (_("Compiling file: %s ...\n"), te->filename);
-	messages_append (app->messages, buff, MESSAGE_BUILD);
-	messages_append (app->messages, cmd, MESSAGE_BUILD);
-	messages_append (app->messages, "\n", MESSAGE_BUILD);
-	messages_show (app->messages, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, buff, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, cmd, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, "\n", MESSAGE_BUILD);
+	anjuta_message_manager_show (app->messages, MESSAGE_BUILD);
 	g_free (buff);
 	g_free (cmd);
 }
@@ -167,7 +165,7 @@ compile_file ()
 void
 compile_mesg_arrived (gchar * mesg)
 {
-	messages_append (app->messages, mesg, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, mesg, MESSAGE_BUILD);
 }
 
 void
@@ -177,24 +175,24 @@ compile_terminated (int status, time_t time)
 
 	if (WEXITSTATUS (status))
 	{
-		messages_append (app->messages,
+		anjuta_message_manager_append (app->messages,
 				 _("Compile completed ... unsuccessful"),
 				 MESSAGE_BUILD);
-		messages_append (app->messages, "\n", MESSAGE_BUILD);
+		anjuta_message_manager_append (app->messages, "\n", MESSAGE_BUILD);
 		anjuta_warning (_("Compile completed ... unsuccessful"));
 	}
 	else
 	{
-		messages_append (app->messages,
+		anjuta_message_manager_append (app->messages,
 				 _("Compile completed ... successful"),
 				 MESSAGE_BUILD);
-		messages_append (app->messages, "\n", MESSAGE_BUILD);
+		anjuta_message_manager_append (app->messages, "\n", MESSAGE_BUILD);
 		anjuta_status (_("Compile completed ... successful"));
 	}
 	buff1 =
 		g_strdup_printf (_("Total time taken: %d secs\n"),
 				 (int) time);
-	messages_append (app->messages, buff1, MESSAGE_BUILD);
+	anjuta_message_manager_append (app->messages, buff1, MESSAGE_BUILD);
 	if (preferences_get_int (app->preferences, BEEP_ON_BUILD_COMPLETE))
 		gdk_beep ();
 	g_free (buff1);
