@@ -244,19 +244,19 @@ on_co_supp_info_clicked (GtkButton * button, gpointer data)
 	fprintf (tmp, _("Description:\n"));
 	fprintf (tmp, "%s\n\n", anjuta_supports[index][ANJUTA_SUPPORT_DESCRIPTION]);
 	fprintf (tmp, _("Dependencies: %s\n\n"), anjuta_supports[index][ANJUTA_SUPPORT_DEPENDENCY]);
-	fprintf (tmp, _("Macros in configure.in fie:\n"));
+	fprintf (tmp, _("Macros in configure.in file:\n"));
 	fprintf (tmp, "%s\n", anjuta_supports[index][ANJUTA_SUPPORT_MACROS]);
-	fprintf (tmp, _("Variable(s) for cflags: %s\n\n"),
+	fprintf (tmp, _("Variables for cflags: %s\n\n"),
 		 anjuta_supports[index][ANJUTA_SUPPORT_PRJ_CFLAGS]);
-	fprintf (tmp, _("Variable(s) for Libs: %s\n\n"),
+	fprintf (tmp, _("Variables for libraries: %s\n\n"),
 		 anjuta_supports[index][ANJUTA_SUPPORT_PRJ_LIBS]);
-	fprintf (tmp, _("Compile time Cflags: %s\n\n"),
+	fprintf (tmp, _("Compile time cflags: %s\n\n"),
 		 anjuta_supports[index][ANJUTA_SUPPORT_FILE_CFLAGS]);
-	fprintf (tmp, _("Compile time Libs: %s\n\n"),
+	fprintf (tmp, _("Compile time libraries: %s\n\n"),
 		 anjuta_supports[index][ANJUTA_SUPPORT_FILE_LIBS]);
 	fprintf (tmp, _("Entries in acconfig.h file:\n"));
 	fprintf (tmp, "%s\n", anjuta_supports[index][ANJUTA_SUPPORT_ACCONFIG_H]);
-	fprintf (tmp, _("Installed status:\n"));
+	fprintf (tmp, _("Installation status:\n"));
 	str = anjuta_supports[index][ANJUTA_SUPPORT_INSTALL_STATUS];
 	if (str)
 	{
@@ -352,9 +352,14 @@ on_co_inc_remove_clicked (GtkButton * button, gpointer data)
 	CompilerOptions *co = data;
 	if (g_list_length (GTK_CLIST (co->widgets.inc_clist)->row_list) < 1)
 		return;
+	
+	compiler_options_disconnect_signals(co);
+	
 	gtk_entry_set_text (GTK_ENTRY (co->widgets.inc_entry), "");
 	gtk_clist_remove (GTK_CLIST (co->widgets.inc_clist), co->inc_index);
 	compiler_options_update_controls (co);
+	
+	compiler_options_connect_signals(co);
 }
 
 void
@@ -445,9 +450,14 @@ on_co_lib_remove_clicked (GtkButton * button, gpointer data)
 	CompilerOptions *co = data;
 	if (g_list_length (GTK_CLIST (co->widgets.lib_clist)->row_list) < 1)
 		return;
+	
+	compiler_options_disconnect_signals(co);
+	
 	gtk_entry_set_text (GTK_ENTRY (co->widgets.lib_entry), "");
 	gtk_clist_remove (GTK_CLIST (co->widgets.lib_clist), co->lib_index);
 	compiler_options_update_controls (co);
+	
+	compiler_options_connect_signals(co);
 }
 
 void
@@ -628,9 +638,14 @@ on_co_def_remove_clicked (GtkButton * button, gpointer data)
 	CompilerOptions *co = data;
 	if (g_list_length (GTK_CLIST (co->widgets.def_clist)->row_list) < 1)
 		return;
+	
+	compiler_options_disconnect_signals(co);
+	
 	gtk_entry_set_text (GTK_ENTRY (co->widgets.def_entry), "");
 	gtk_clist_remove (GTK_CLIST (co->widgets.def_clist), co->def_index);
 	compiler_options_update_controls (co);
+	
+	compiler_options_connect_signals(co);
 }
 
 void
