@@ -63,7 +63,7 @@ create_compiler_options_gui (CompilerOptions * co)
 	GtkWidget *label111;
 
 	dialog1 = gnome_dialog_new (_("Compiler Options"), NULL);
-	gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, FALSE, FALSE);
+	gtk_window_set_policy (GTK_WINDOW (dialog1), FALSE, TRUE, FALSE);
 	gtk_window_set_wmclass (GTK_WINDOW (dialog1), "comp_opt", "Anjuta");
 	gnome_dialog_close_hides (GNOME_DIALOG (dialog1), TRUE);
 
@@ -187,7 +187,9 @@ create_compiler_options_gui (CompilerOptions * co)
 	GTK_WIDGET_SET_FLAGS (comopt_cancel, GTK_CAN_DEFAULT);
 
 	gtk_accel_group_attach (app->accel_group, GTK_OBJECT (window1));
-
+	
+	compiler_options_connect_signals(co);
+	
 	gtk_signal_connect (GTK_OBJECT (dialog1), "delete_event",
 			    GTK_SIGNAL_FUNC (on_comopt_delete_event), co);
 	gtk_signal_connect (GTK_OBJECT (comopt_ok), "clicked",
@@ -246,7 +248,7 @@ create_compiler_options_page0 (CompilerOptions * co)
 				      GTK_SELECTION_BROWSE);
 	gtk_clist_column_titles_show (GTK_CLIST (clist1));
 
-	label7 = gtk_label_new (_("Select the Supports to add"));
+	label7 = gtk_label_new (_("Select the support libraries to add"));
 	gtk_widget_show (label7);
 	gtk_clist_set_column_widget (GTK_CLIST (clist1), 1, label7);
 
@@ -265,10 +267,6 @@ create_compiler_options_page0 (CompilerOptions * co)
 	gtk_box_pack_start (GTK_BOX (vbox1), button2, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (button2), 5);
 
-	gtk_signal_connect (GTK_OBJECT (clist1), "select_row",
-			    GTK_SIGNAL_FUNC (on_co_supp_clist_select_row),
-			    co);
-
 	gtk_signal_connect (GTK_OBJECT (button0), "clicked",
 			    GTK_SIGNAL_FUNC (on_co_supp_info_clicked), co);
 
@@ -376,8 +374,6 @@ create_compiler_options_page1 (CompilerOptions * co)
 	gtk_box_pack_start (GTK_BOX (vbox1), button4, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (button4), 5);
 
-	gtk_signal_connect (GTK_OBJECT (clist1), "select_row",
-			    GTK_SIGNAL_FUNC (on_co_inc_clist_select_row), co);
 	gtk_signal_connect (GTK_OBJECT (button0), "clicked",
 			    GTK_SIGNAL_FUNC (on_co_inc_add_clicked), co);
 	gtk_signal_connect (GTK_OBJECT (button1), "clicked",
@@ -496,9 +492,6 @@ create_compiler_options_page2 (CompilerOptions * co)
 	gtk_box_pack_start (GTK_BOX (vbox1), button4, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (button4), 5);
 
-	gtk_signal_connect (GTK_OBJECT (clist1), "select_row",
-			    GTK_SIGNAL_FUNC
-			    (on_co_lib_paths_clist_select_row), co);
 	gtk_signal_connect (GTK_OBJECT (button0), "clicked",
 			    GTK_SIGNAL_FUNC (on_co_lib_paths_add_clicked),
 			    co);
@@ -653,8 +646,6 @@ create_compiler_options_page3 (CompilerOptions * co)
 	gtk_box_pack_start (GTK_BOX (vbox1), button4, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (button4), 5);
 
-	gtk_signal_connect (GTK_OBJECT (clist1), "select_row",
-			    GTK_SIGNAL_FUNC (on_co_lib_clist_select_row), co);
 	gtk_signal_connect (GTK_OBJECT (clist2), "select_row",
 			    GTK_SIGNAL_FUNC
 			    (on_co_lib_stock_clist_select_row), co);
@@ -781,8 +772,6 @@ create_compiler_options_page4 (CompilerOptions * co)
 	gtk_box_pack_start (GTK_BOX (vbox1), button4, FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (button4), 5);
 
-	gtk_signal_connect (GTK_OBJECT (clist1), "select_row",
-			    GTK_SIGNAL_FUNC (on_co_def_clist_select_row), co);
 	gtk_signal_connect (GTK_OBJECT (button0), "clicked",
 			    GTK_SIGNAL_FUNC (on_co_def_add_clicked), co);
 	gtk_signal_connect (GTK_OBJECT (button1), "clicked",
@@ -832,7 +821,7 @@ create_compiler_options_page5 (CompilerOptions * co)
 
 	checkbutton[0] =
 		gtk_check_button_new_with_label (_
-						 ("Treat warnings as errors."));
+						 ("Treat warnings as errors"));
 	gtk_widget_show (checkbutton[0]);
 	gtk_box_pack_start (GTK_BOX (vbox1), checkbutton[0], FALSE, FALSE, 0);
 
@@ -1029,7 +1018,7 @@ create_compiler_options_page6 (CompilerOptions * co)
 	radiobutton[3] =
 		gtk_radio_button_new_with_label (vbox2_group,
 						 _
-						 ("Fastest-code optimization (functions inlined whereever possible"));
+						 ("Fastest-code optimization (functions inlined where possible"));
 	vbox2_group =
 		gtk_radio_button_group (GTK_RADIO_BUTTON (radiobutton[3]));
 	gtk_widget_show (radiobutton[3]);
@@ -1046,10 +1035,10 @@ create_compiler_options_page6 (CompilerOptions * co)
 	gtk_widget_show (frame1);
 
 	label1 = gtk_label_new (
-		_("With optimization enabled, you might have some difficulty\n"
-	          "debugging your program. So it is not a good idea to enable\n"
-		  "both debug and optimization options, unless what you want\n"
-		  "is to debug the optimized code."));
+		_("With optimization enabled, you may have some difficulty\n"
+	      "debugging your program. Avoid enabling both debug and\n"
+		  "optimization options, unless you want to\n"
+		  "debug the optimized code."));
 	gtk_widget_show (label1);
 	gtk_misc_set_alignment (GTK_MISC (label1), 0.5, 0.5);
 	gtk_container_add (GTK_CONTAINER (frame1), label1);
@@ -1167,3 +1156,49 @@ create_compiler_options_page7 (CompilerOptions * co)
 
 	return frame;
 }
+
+void
+compiler_options_connect_signals(CompilerOptions* co)
+{
+	gtk_signal_connect (GTK_OBJECT (co->widgets.supp_clist), "select_row",
+			    GTK_SIGNAL_FUNC (on_co_supp_clist_select_row),
+			    co);
+	
+	gtk_signal_connect (GTK_OBJECT (co->widgets.inc_clist), "select_row",
+			    GTK_SIGNAL_FUNC (on_co_inc_clist_select_row), co);
+	
+	gtk_signal_connect (GTK_OBJECT (co->widgets.lib_paths_clist), "select_row",
+			    GTK_SIGNAL_FUNC (on_co_lib_paths_clist_select_row),
+				co);
+	
+	gtk_signal_connect (GTK_OBJECT (co->widgets.lib_clist), "select_row",
+			    GTK_SIGNAL_FUNC (on_co_lib_clist_select_row),
+				co);
+	
+	gtk_signal_connect (GTK_OBJECT (co->widgets.def_clist), "select_row",
+			    GTK_SIGNAL_FUNC (on_co_def_clist_select_row),
+				co);
+}
+
+void
+compiler_options_disconnect_signals(CompilerOptions* co)
+{
+	gtk_signal_disconnect_by_func (GTK_OBJECT (co->widgets.supp_clist),
+			    GTK_SIGNAL_FUNC (on_co_supp_clist_select_row),
+			    co);
+	
+	gtk_signal_disconnect_by_func (GTK_OBJECT (co->widgets.inc_clist),
+			    GTK_SIGNAL_FUNC (on_co_inc_clist_select_row), co);
+	
+	gtk_signal_disconnect_by_func (GTK_OBJECT (co->widgets.lib_paths_clist),
+			    GTK_SIGNAL_FUNC (on_co_lib_paths_clist_select_row),
+				co);
+	
+	gtk_signal_disconnect_by_func (GTK_OBJECT (co->widgets.lib_clist),
+			    GTK_SIGNAL_FUNC (on_co_lib_clist_select_row),
+				co);
+	
+	gtk_signal_disconnect_by_func (GTK_OBJECT (co->widgets.def_clist),
+			    GTK_SIGNAL_FUNC (on_co_def_clist_select_row),
+				co);
+}
