@@ -24,6 +24,7 @@
 #include "text_editor.h"
 #include "debugger.h"
 #include "toolbar.h"
+#include "toolbar_callbacks.h"
 #include "anjuta.h"
 #include "utilities.h"
 #include "controls.h"
@@ -102,6 +103,7 @@ main_toolbar_update ()
 	gtk_widget_set_sensitive (mt->find_combo, F);
 	gtk_widget_set_sensitive (mt->go_to, F);
 	gtk_widget_set_sensitive (mt->line_entry, F);
+
 	update_main_menubar ();
 }
 
@@ -197,6 +199,30 @@ browser_toolbar_update()
 	gtk_widget_set_sensitive (bt->last_bookmark, F);
 	gtk_widget_set_sensitive (bt->block_start, FLD);
 	gtk_widget_set_sensitive (bt->block_end, FLD);
+	/* Goto Tag Stuff */
+	gtk_widget_set_sensitive (bt->tag, F);
+	gtk_widget_set_sensitive (bt->tag_combo, F);
+	if (F)
+	{
+		const GList *tags = anjuta_get_tag_list(te, tm_tag_max_t);
+		if (tags)
+		{
+			gtk_signal_disconnect_by_func(GTK_OBJECT(GTK_COMBO(bt->tag_combo)->list)
+			  , GTK_SIGNAL_FUNC(on_toolbar_tag_clicked), NULL);
+			gtk_combo_set_popdown_strings(GTK_COMBO(bt->tag_combo), (GList *) tags);
+			gtk_signal_connect (GTK_OBJECT(GTK_COMBO(bt->tag_combo)->list),
+			    "selection-changed", GTK_SIGNAL_FUNC (on_toolbar_tag_clicked), NULL);
+			gtk_widget_show(bt->tag_combo);
+			gtk_widget_show(bt->tag);
+			gtk_label_set_text(GTK_LABEL(bt->tag_label), _("Tags: "));
+		}
+		else
+		{
+			gtk_widget_hide(bt->tag_combo);
+			gtk_widget_hide(bt->tag);
+			gtk_label_set_text(GTK_LABEL(bt->tag_label), _("No Tags"));
+		}
+	}
 }
 
 void
@@ -274,6 +300,7 @@ update_main_menubar ()
 	gtk_widget_set_sensitive (fm->close_all_file, F);
 	gtk_widget_set_sensitive (fm->reload_file, F);
 	gtk_widget_set_sensitive (fm->new_project, !P);
+	gtk_widget_set_sensitive (fm->import_project, !P);
 	gtk_widget_set_sensitive (fm->open_project, !P);
 	gtk_widget_set_sensitive (fm->save_project, P);
 	gtk_widget_set_sensitive (fm->close_project, P);
@@ -287,12 +314,20 @@ update_main_menubar ()
 	gtk_widget_set_sensitive (em->copy, F);
 	gtk_widget_set_sensitive (em->paste, F);
 	gtk_widget_set_sensitive (em->clear, F);
+	
 	gtk_widget_set_sensitive (em->uppercase, F);
 	gtk_widget_set_sensitive (em->lowercase, F);
-	gtk_widget_set_sensitive (em->convert, F);
+	gtk_widget_set_sensitive (em->convert_crlf, F);
+	gtk_widget_set_sensitive (em->convert_lf, F);
+	gtk_widget_set_sensitive (em->convert_cr, F);
+	gtk_widget_set_sensitive (em->convert_auto, F);
+	
 	gtk_widget_set_sensitive (em->insert_c_gpl, F);
 	gtk_widget_set_sensitive (em->insert_cpp_gpl, F);
-	gtk_widget_set_sensitive (em->insert_datetime, F);
+	gtk_widget_set_sensitive (em->insert_py_gpl, F);
+	gtk_widget_set_sensitive (em->insert_username, F);
+   	gtk_widget_set_sensitive (em->insert_datetime, F);
+	gtk_widget_set_sensitive (em->insert_header_template, F);
 	gtk_widget_set_sensitive (em->select_all, F);
 	gtk_widget_set_sensitive (em->select_brace, F);
 	gtk_widget_set_sensitive (em->select_block, FLD);
@@ -335,6 +370,7 @@ update_main_menubar ()
 	gtk_widget_set_sensitive (ftm->indent_dcr, F);
 
 	gtk_widget_set_sensitive (bm->compile, C && !L);
+	gtk_widget_set_sensitive (bm->make, C && !L);
 	gtk_widget_set_sensitive (bm->build, (C || P) && !L);
 	gtk_widget_set_sensitive (bm->build_all, P && !L);
 	gtk_widget_set_sensitive (bm->install, P && !L);
