@@ -19,18 +19,13 @@
 #ifndef _CONTROLS_H_
 #define _CONTROLS_H_
 
-void
-main_toolbar_update(void);
+void main_toolbar_update(void);
+void debug_toolbar_update(void);
+void extended_toolbar_update(void); 
+void format_toolbar_update(void);
+void browser_toolbar_update(void);
 
-void
-debug_toolbar_update(void);
+void update_main_menubar(void);
+void update_led_animator(void);
 
-void
-extended_toolbar_update(void);
-
-void
-update_main_menubar(void);
-
-void
-update_led_animator(void);
 #endif
