@@ -21,6 +21,7 @@
 #  include <config.h>
 #endif
 
+#include <sys/stat.h>
 #include <gnome.h>
 #include "splash.h"
 #include "anjuta.h"
@@ -28,6 +29,7 @@
 #include "fileselection.h"
 #include "CORBA-Server.h"
 
+/* #define DEBUG */
 
 /* One and only one instance of AnjutaApp. */
 AnjutaApp *app;			
@@ -43,10 +45,50 @@ poptOption anjuta_options[] = {
 	 	NULL, '\0', POPT_ARG_INTL_DOMAIN, PACKAGE,
 	 	0, NULL, NULL
 	},
-	{"no-splash", 's', POPT_ARG_NONE, &no_splash, 0, N_("Don't show the splashscreen"), NULL},
+	{"no-splash", 's', POPT_ARG_NONE, &no_splash, 0, N_("Do not show the splashscreen"), NULL},
 	POPT_AUTOHELP {NULL}
 };
 
+/*
+ * This is work around function to make sure that the users get a 
+ * smooth transition from 0.1.8 to 0.1.9 version. It works by
+ * detecting the version of the old config file and deleting
+ * ~/.gnome/Anjuta if it is lesser than 0.1.9.
+*/
+static void delete_old_config_file (void)
+{
+	gchar *config_file, *config_dir;
+	gchar *config_version;
+	PropsID prop;
+	
+	config_dir = g_strconcat(g_get_home_dir(), "/.anjuta", NULL);
+	config_file = g_strconcat(config_dir, "/session.properties", NULL);
+	
+	prop = prop_set_new();
+	prop_read (prop, config_file, config_dir);
+	g_free (config_dir);
+	g_free (config_file);
+	
+	config_version = prop_get(prop, "anjuta.version");
+	if (config_version) {
+		gint last_ver;
+		sscanf(config_version, "0.1.%d", &last_ver);
+#ifdef DEBUG
+		g_message ("Old Version = %d", last_ver);
+#endif
+		if (last_ver < 9) {
+			gchar* conf_file;
+			conf_file = g_strconcat (g_get_home_dir(), "/.gnome/Anjuta", NULL);
+#ifdef DEBUG
+			g_message("Old config file %s found: Removing it", conf_file);
+#endif
+			remove(conf_file);
+			g_free(conf_file);
+		}
+		g_free(config_version);
+	}
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -54,11 +96,14 @@ main (int argc, char *argv[])
 	GnomeClientFlags flags;
 	poptContext context;
 	const char** args;
-	CORBA_Environment	ev;
-	CORBA_ORB			corb ;
-	int		retCode ;
+	CORBA_Environment ev;
+	CORBA_ORB corb ;
+	int retCode ;
 
 
+	/* Before anything starts */
+	delete_old_config_file();
+	
 #ifdef ENABLE_NLS
 	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
 	textdomain (PACKAGE);
@@ -68,15 +113,15 @@ main (int argc, char *argv[])
 	anjuta_connect_kernel_signals();
 	
 	CInitEx( &ev );
-	corb = gnome_CORBA_init_with_popt_table("anjuta", VERSION, &argc, argv,
+	corb = gnome_CORBA_init_with_popt_table(PACKAGE, VERSION, &argc, argv,
 					   anjuta_options, 0, &context,
 					   GNORBA_INIT_SERVER_FUNC, &ev );
-	/*corb = gnome_CORBA_init( "anjuta", VERSION, &argc, argv, 
-								GNORBA_INIT_SERVER_FUNC, &ev );*/
+	/*corb = gnome_CORBA_init(PACKAGE, VERSION, &argc, argv, 
+		GNORBA_INIT_SERVER_FUNC, &ev );*/
 
 
-	//gnome_init_with_popt_table("anjuta", VERSION, argc, argv,
-	//			   anjuta_options, 0, &context);
+	//gnome_init_with_popt_table(PACKAGE, VERSION, argc, argv,
+	//	   anjuta_options, 0, &context);
 	
 	/* Session management */
 	client = gnome_master_client();
@@ -92,12 +137,22 @@ main (int argc, char *argv[])
 	if (args)
 	{
 		gint i;
+		gchar* cur_dir;
 		i = 0;
-		while (args[i])
-		{
-			command_args = g_list_append (command_args, g_strdup(args[i]));
+		
+		cur_dir = g_get_current_dir ();
+		
+		while (args[i]) {
+			gchar *full_name;
+			if (args[i][0] != '/') {
+				full_name = g_strconcat (cur_dir, "/", args[i], NULL);
+			} else {
+				full_name = g_strdup(args[i]);
+			}
+			command_args = g_list_append (command_args, full_name);
 			i++;
 		}
+		g_free (cur_dir);
 	}
 	poptFreeContext(context);
 
