@@ -26,14 +26,12 @@
 #include "mainmenu_callbacks.h"
 #include "main_menubar_def.h"
 #include "fileselection.h"
+#include "scroll-menu.h"
 
-void on_file_menu_realize (GtkWidget * widget, gpointer data);
-
-void on_project_menu_realize (GtkWidget * widget, gpointer data);
-/*-------------------------------------------------------------------------------------------*/
+static void on_file_menu_realize (GtkWidget * widget, gpointer data);
+static void on_project_menu_realize (GtkWidget * widget, gpointer data);
 static void on_plugins_menu_realize (GtkWidget * widget, gpointer data);
 static void on_plugins_menu_item_activate (GtkMenuItem * item, AnjutaAddInPtr pPlug );
-/*-------------------------------------------------------------------------------------------*/
 
 void
 create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
@@ -50,21 +48,22 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	mb->file.close_all_file = file1_menu_uiinfo[6].widget;
 	mb->file.reload_file = file1_menu_uiinfo[7].widget;
 	mb->file.new_project = file1_menu_uiinfo[9].widget;
-	mb->file.open_project = file1_menu_uiinfo[10].widget;
-	mb->file.save_project = file1_menu_uiinfo[11].widget;
-	mb->file.close_project = file1_menu_uiinfo[12].widget;
-	mb->file.rename = file1_menu_uiinfo[14].widget;
+	mb->file.import_project = file1_menu_uiinfo[10].widget;
+	mb->file.open_project = file1_menu_uiinfo[11].widget;
+	mb->file.save_project = file1_menu_uiinfo[12].widget;
+	mb->file.close_project = file1_menu_uiinfo[13].widget;
+	mb->file.rename = file1_menu_uiinfo[15].widget;
 	
 	/* Unimplemented */
-	gtk_widget_hide (file1_menu_uiinfo[14].widget);
 	gtk_widget_hide (file1_menu_uiinfo[15].widget);
+	gtk_widget_hide (file1_menu_uiinfo[16].widget);
 
-	mb->file.page_setup = file1_menu_uiinfo[16].widget;
-	mb->file.print = file1_menu_uiinfo[17].widget;
-	mb->file.recent_files = file1_menu_uiinfo[19].widget;
-	mb->file.recent_projects = file1_menu_uiinfo[20].widget;
-	mb->file.exit = file1_menu_uiinfo[22].widget;
-	for (i = 0; i < 23 ; i++)
+	mb->file.page_setup = file1_menu_uiinfo[17].widget;
+	mb->file.print = file1_menu_uiinfo[18].widget;
+	mb->file.recent_files = file1_menu_uiinfo[20].widget;
+	mb->file.recent_projects = file1_menu_uiinfo[21].widget;
+	mb->file.exit = file1_menu_uiinfo[23].widget;
+	for (i = 0; i < 24 ; i++)
 	{
 		gtk_widget_ref (file1_menu_uiinfo[i].widget);
 		gtk_accel_group_attach(GNOME_APP(ap)->accel_group, GTK_OBJECT(file1_menu_uiinfo[i].widget));
@@ -72,8 +71,12 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 
 	mb->edit.uppercase = transform1_submenu_uiinfo[0].widget;
 	mb->edit.lowercase = transform1_submenu_uiinfo[1].widget;
-	mb->edit.convert = transform1_submenu_uiinfo[2].widget;
-	for (i = 0; i < 3; i++)
+	mb->edit.convert_crlf = transform1_submenu_uiinfo[3].widget;
+	mb->edit.convert_lf = transform1_submenu_uiinfo[4].widget;
+	mb->edit.convert_cr = transform1_submenu_uiinfo[5].widget;
+	mb->edit.convert_auto = transform1_submenu_uiinfo[6].widget;
+	
+	for (i = 0; i < NUM_TRANSFORM_SUBMENUS; i++)
 	{
 		gtk_widget_ref (transform1_submenu_uiinfo[i].widget);
 		gtk_accel_group_attach(GNOME_APP(ap)->accel_group, GTK_OBJECT(transform1_submenu_uiinfo[i].widget));
@@ -81,8 +84,11 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	
 	mb->edit.insert_c_gpl = inserttext1_submenu_uiinfo[0].widget;
 	mb->edit.insert_cpp_gpl = inserttext1_submenu_uiinfo[1].widget;
-	mb->edit.insert_datetime = inserttext1_submenu_uiinfo[2].widget;
-	for (i = 0; i < 3; i++)
+	mb->edit.insert_py_gpl = inserttext1_submenu_uiinfo[2].widget;
+	mb->edit.insert_username = inserttext1_submenu_uiinfo[3].widget;
+	mb->edit.insert_datetime = inserttext1_submenu_uiinfo[4].widget;
+	mb->edit.insert_header_template = inserttext1_submenu_uiinfo[5].widget;
+	for (i = 0; i < 6; i++)
 	{
 		gtk_widget_ref (inserttext1_submenu_uiinfo[i].widget);
 		gtk_accel_group_attach(GNOME_APP(ap)->accel_group, GTK_OBJECT(inserttext1_submenu_uiinfo[i].widget));
@@ -111,25 +117,23 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	mb->edit.goto_next_mesg = goto1_submenu_uiinfo[5].widget;
 	mb->edit.repeat_find = edit1_menu_uiinfo[18].widget;
 	mb->edit.edit_app_gui = edit1_menu_uiinfo[22].widget;
-	mb->edit.plugins = edit1_menu_uiinfo[24].widget;
-	for (i = 0; i < NUM_EDIT_MENUES ; i++)
+	for (i = 0; i < NUM_EDIT_MENUS ; i++)
 	{
 		gtk_widget_ref (edit1_menu_uiinfo[i].widget);
 		gtk_accel_group_attach(GNOME_APP(ap)->accel_group, GTK_OBJECT(edit1_menu_uiinfo[i].widget));
 	}
-	
+
 	mb->view.main_toolbar = toolbar1_submenu_uiinfo[0].widget;
 	mb->view.extended_toolbar = toolbar1_submenu_uiinfo[2].widget;
-	mb->view.tags_toolbar = toolbar1_submenu_uiinfo[4].widget;
-	mb->view.debug_toolbar = toolbar1_submenu_uiinfo[6].widget;
-	mb->view.browser_toolbar = toolbar1_submenu_uiinfo[8].widget;
-	mb->view.format_toolbar = toolbar1_submenu_uiinfo[10].widget;
-	for (i = 0; i < 11; i++)
+	mb->view.debug_toolbar = toolbar1_submenu_uiinfo[4].widget;
+	mb->view.browser_toolbar = toolbar1_submenu_uiinfo[6].widget;
+	mb->view.format_toolbar = toolbar1_submenu_uiinfo[8].widget;
+	for (i = 0; i < 9; i++)
 	{
 		gtk_widget_ref (toolbar1_submenu_uiinfo[i].widget);
 		gtk_accel_group_attach(GNOME_APP(ap)->accel_group, GTK_OBJECT(toolbar1_submenu_uiinfo[i].widget));
 	}
-	
+
 	mb->view.editor_linenos = editor1_submenu_uiinfo[0].widget;
 	mb->view.editor_markers = editor1_submenu_uiinfo[1].widget;
 	mb->view.editor_folds = editor1_submenu_uiinfo[2].widget;
@@ -142,7 +146,6 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 		gtk_accel_group_attach(GNOME_APP(ap)->accel_group, GTK_OBJECT(editor1_submenu_uiinfo[i].widget));
 	}
 
-	
 	mb->view.messages = view1_menu_uiinfo[0].widget;
 	mb->view.project_listing = view1_menu_uiinfo[1].widget;
 	mb->view.bookmarks = view1_menu_uiinfo[2].widget;
@@ -155,7 +158,7 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	mb->view.dump_window = view1_menu_uiinfo[17].widget;
 	mb->view.console = view1_menu_uiinfo[19].widget;
 	mb->view.show_hide_locals = view1_menu_uiinfo[20].widget;
-	for (i = 0; i < NVIEWMENUS ; i++)
+	for (i = 0; i < NUM_VIEW_MENUS ; i++)
 	{
 		gtk_widget_ref (view1_menu_uiinfo[i].widget);
 		gtk_accel_group_attach(GNOME_APP(ap)->accel_group, GTK_OBJECT(view1_menu_uiinfo[i].widget));
@@ -217,6 +220,7 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	}
 	
 	mb->build.compile = build1_menu_uiinfo[0].widget;
+	mb->build.make = build1_menu_uiinfo[1].widget;
 	mb->build.build = build1_menu_uiinfo[2].widget;
 	mb->build.build_all = build1_menu_uiinfo[3].widget;
 	mb->build.install = build1_menu_uiinfo[5].widget;
@@ -349,15 +353,20 @@ create_main_menubar (GtkWidget * ap, MainMenuBar * mb)
 	}
 	
 	/* unimplemented */
-	gtk_widget_hide (menubar1_uiinfo[8].widget);
+	gtk_widget_hide (menubar1_uiinfo[9].widget);
 
+
+	/* Note: this is because we don't know yet what's the contents of these
+	         menus*/
+	
 	gtk_signal_connect (GTK_OBJECT (mb->file.recent_files), "realize",
 			    GTK_SIGNAL_FUNC (on_file_menu_realize), NULL);
 
 	gtk_signal_connect (GTK_OBJECT (mb->file.recent_projects), "realize",
 			    GTK_SIGNAL_FUNC (on_project_menu_realize), NULL);
 	
-	gtk_signal_connect (GTK_OBJECT (mb->edit.plugins), "realize",
+	/* Plugin Menu */
+	gtk_signal_connect (GTK_OBJECT (menubar1_uiinfo[8].widget), "realize",
 			    GTK_SIGNAL_FUNC (on_plugins_menu_realize), NULL);
 }
 
@@ -373,44 +382,67 @@ void
 main_menu_unref ()
 {
 	gint i;
+	
 	for (i = 0; i < 23; i++)
 		gtk_widget_unref (file1_menu_uiinfo[i].widget);
+	
+	for (i = 0; i < NUM_TRANSFORM_SUBMENUS ; i++)
+		gtk_widget_unref (transform1_submenu_uiinfo[i].widget);
+	
 	for (i = 0; i < 3; i++)
 		gtk_widget_unref (select1_submenu_uiinfo[i].widget);
+	
 	for (i = 0; i < 6; i++)
 		gtk_widget_unref (goto1_submenu_uiinfo[i].widget);
-	for (i = 0; i < 3; i++)
+	
+	for (i = 0; i < 6; i++)
 		gtk_widget_unref (inserttext1_submenu_uiinfo[i].widget);
-	for (i = 0; i < NUM_EDIT_MENUES ; i++)
+	
+	for (i = 0; i < NUM_EDIT_MENUS ; i++)
 		gtk_widget_unref (edit1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 11; i++)
 		gtk_widget_unref (toolbar1_submenu_uiinfo[i].widget);
+	
 	for (i = 0; i < 6; i++)
 		gtk_widget_unref (editor1_submenu_uiinfo[i].widget);
-	for (i = 0; i < NVIEWMENUS; i++)
+	
+	for (i = 0; i < NUM_VIEW_MENUS; i++)
 		gtk_widget_unref (view1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 17; i++)
 		gtk_widget_unref (project1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 13; i++)
 		gtk_widget_unref (format1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 18; i++)
 		gtk_widget_unref (build1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 8; i++)
 		gtk_widget_unref (bookmark1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 5; i++)
 		gtk_widget_unref (execution1_submenu_uiinfo[i].widget);
+	
 	for (i = 0; i < 6; i++)
 		gtk_widget_unref (breakpoints1_submenu_uiinfo[i].widget);
+	
 	for (i = 0; i < 8; i++)
 		gtk_widget_unref (info1_submenu_uiinfo[i].widget);
+	
 	for (i = 0; i < 22; i++)
 		gtk_widget_unref (debug1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 9; i++)
 		gtk_widget_unref (utilities1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 2; i++)
 		gtk_widget_unref (windows1_menu_uiinfo[i].widget);
+	
 	for (i = 0; i < 6; i++)
 		gtk_widget_unref (settings1_menu_uiinfo[i].widget);
+	
 	for (i = 1; i < 18; i++)
 		gtk_widget_unref (help1_menu_uiinfo[i].widget);
 }
@@ -421,13 +453,11 @@ create_submenu (gchar * title, GList * strings, GtkSignalFunc callback_func)
 	GtkWidget *submenu;
 	GtkWidget *item;
 	gint i;
-	submenu = gtk_menu_new ();
+	submenu = scroll_menu_new ();
 
-	item = gtk_menu_item_new ();
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
-
-	item = gtk_menu_item_new ();
+	/* FIXME: what about the user opinion on tearoff menuitems ?
+	          perhaps (s)he has desactivated the option. */
+	item = gtk_tearoff_menu_item_new ();
 	gtk_menu_append (GTK_MENU (submenu), item);
 	gtk_widget_show (item);
 
@@ -450,70 +480,48 @@ create_submenu (gchar * title, GList * strings, GtkSignalFunc callback_func)
 		gtk_signal_connect (GTK_OBJECT (item), "activate",
 				    callback_func, text);
 	}
-	item = gtk_menu_item_new ();
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
-
-	item = gtk_menu_item_new ();
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
-
 	gtk_widget_show (submenu);
 	return GTK_WIDGET (submenu);
 }
 
-static 
-GtkWidget *
-create_submenu_plugin (gchar * title, GList * pList, GtkSignalFunc callback_func)
+static GtkWidget *
+create_submenu_plugin (GList * pList, GtkSignalFunc callback_func)
 {
 	GtkWidget *submenu;
 	GtkWidget *item;
 	gint i;
-	submenu = gtk_menu_new ();
 
-	item = gtk_menu_item_new ();
+	submenu = scroll_menu_new ();
+
+	/* FIXME: what about the user opinion on tearoff menuitems ?
+	          perhaps (s)he has desactivated the option. */
+	item = gtk_tearoff_menu_item_new ();
 	gtk_menu_append (GTK_MENU (submenu), item);
 	gtk_widget_show (item);
 
-	item = gtk_menu_item_new ();
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
+	for (i = 0; i < g_list_length (pList); i++) {
+		AnjutaAddInPtr pPlug;
+		gchar *szTitle;
 
-	item = gtk_menu_item_new_with_label (title);
-	gtk_widget_set_sensitive (item, FALSE);
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
-
-	item = gtk_menu_item_new ();
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
-
-	for (i = 0; i < g_list_length (pList); i++)
-	{
-		AnjutaAddInPtr	pPlug;
-		gchar			*szTitle ;
 		pPlug = (AnjutaAddInPtr) (g_list_nth (pList, i)->data);
 		szTitle = (*pPlug->GetMenuTitle)( pPlug->m_Handle, pPlug->m_UserData ) ;
+
 		item = gtk_menu_item_new_with_label ( szTitle );
+
 		g_free( szTitle );
+
 		gtk_menu_append (GTK_MENU (submenu), item);
 		gtk_widget_show (item);
 		gtk_signal_connect (GTK_OBJECT (item), "activate",
 				    callback_func, pPlug );
 	}
-	item = gtk_menu_item_new ();
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
-
-	item = gtk_menu_item_new ();
-	gtk_menu_append (GTK_MENU (submenu), item);
-	gtk_widget_show (item);
 
 	gtk_widget_show (submenu);
+
 	return GTK_WIDGET (submenu);
 }
 
-void
+static void
 on_file_menu_realize (GtkWidget * widget, gpointer data)
 {
 	GtkWidget *submenu =
@@ -527,12 +535,16 @@ on_file_menu_realize (GtkWidget * widget, gpointer data)
 static void
 on_plugins_menu_realize (GtkWidget * widget, gpointer data)
 {
-	GtkWidget *submenu =
-		create_submenu_plugin (_("Plug Ins"), app->addIns_list,
-				GTK_SIGNAL_FUNC
-				(on_plugins_menu_item_activate));
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (widget), submenu);
-	app->widgets.menubar.edit.plugins = widget;
+	if (app->addIns_list) {
+		GtkWidget *submenu =
+			create_submenu_plugin (app->addIns_list,
+					GTK_SIGNAL_FUNC
+					(on_plugins_menu_item_activate));
+		gtk_menu_item_set_submenu (GTK_MENU_ITEM (widget), submenu);
+	} else
+		/* Note: we only hide it to keep a proper ref counting */
+		gtk_widget_hide (widget);
+		
 }
 
 static void
@@ -541,7 +553,7 @@ on_plugins_menu_item_activate (GtkMenuItem * item, AnjutaAddInPtr pPlug )
 	(*pPlug->Activate)( pPlug->m_Handle, pPlug->m_UserData, app ) ;
 }
 
-void
+static void
 on_project_menu_realize (GtkWidget * widget, gpointer data)
 {
 	GtkWidget *submenu =
@@ -564,7 +576,7 @@ on_recent_projects_menu_item_activate (GtkMenuItem * item, gchar * data)
 	if (app->project_dbase->project_is_open)
 	{
 		anjuta_warning (_
-				("You have a project opened. Close it first."));
+				("A Project is already open. Close it first."));
 		return;
 	}
 	fileselection_set_filename (app->project_dbase->fileselection_open, data);
