@@ -44,6 +44,7 @@ struct _FileSubMenu
 	GtkWidget *close_all_file;
 	GtkWidget *reload_file;
 	GtkWidget *new_project;
+	GtkWidget *import_project;
 	GtkWidget *open_project;
 	GtkWidget *save_project;
 	GtkWidget *close_project;
@@ -63,12 +64,20 @@ struct _EditSubMenu
 	GtkWidget *copy;
 	GtkWidget *paste;
 	GtkWidget *clear;
+	
 	GtkWidget *uppercase;
 	GtkWidget *lowercase;
-	GtkWidget *convert;
-    GtkWidget *insert_c_gpl;
-    GtkWidget *insert_cpp_gpl;
-    GtkWidget *insert_datetime;
+	GtkWidget *convert_crlf;
+	GtkWidget *convert_lf;
+	GtkWidget *convert_cr;
+	GtkWidget *convert_auto;
+	
+	GtkWidget *insert_c_gpl;
+	GtkWidget *insert_cpp_gpl;
+	GtkWidget *insert_py_gpl;
+	GtkWidget *insert_username;
+	GtkWidget *insert_datetime;
+	GtkWidget *insert_header_template;
 
 	GtkWidget *select_all;
 	GtkWidget *select_brace;
@@ -90,7 +99,6 @@ struct _EditSubMenu
 	GtkWidget *goto_next_mesg;
 
 	GtkWidget *edit_app_gui;
-	GtkWidget *plugins;
 };
 
 struct _ViewSubMenu
@@ -99,7 +107,6 @@ struct _ViewSubMenu
 	GtkWidget *extended_toolbar;
 	GtkWidget *browser_toolbar;
 	GtkWidget *debug_toolbar;
-	GtkWidget *tags_toolbar;
 	GtkWidget *format_toolbar;
 
 	GtkWidget *editor_linenos;
@@ -158,6 +165,7 @@ struct _FormatSubMenu
 struct _BuildSubMenu
 {
 	GtkWidget *compile;
+	GtkWidget *make;
 	GtkWidget *build;
 	GtkWidget *build_all;
 	GtkWidget *install;
