@@ -32,20 +32,10 @@ static GnomeUIInfo recent_projects1_menu_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
-static GnomeUIInfo plugins_menu_uiinfo[] = {
-	{
-	 GNOME_APP_UI_ITEM, N_("plugins"),
-	 NULL,
-	 on_nonimplemented_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
-	GNOMEUIINFO_END
-};
-
 static GnomeUIInfo file1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("_New"),
-	 N_("New Text File"),
+	 N_("New file"),
 	 on_new_file1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 GDK_N, GDK_MOD1_MASK, NULL},
@@ -94,10 +84,16 @@ static GnomeUIInfo file1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("N_ew Project ..."),
-	 N_("Create a Project using application wizard"),
+	 N_("Create a Project using the Application Wizard"),
 	 on_new_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("_Import Project ..."),
+	 N_("Import an existing code project using the Project Import Wizard"),
+	 on_import_project_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CONVERT,
+	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Open P_roject ..."),
 	 N_("Open a Project"),
@@ -154,25 +150,53 @@ static GnomeUIInfo file1_menu_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
-static GnomeUIInfo transform1_submenu_uiinfo[] = {
+# define NUM_TRANSFORM_SUBMENUS (7)
+static GnomeUIInfo transform1_submenu_uiinfo[NUM_TRANSFORM_SUBMENUS+1] = {
 	{
+	 /* 0 */
 	 GNOME_APP_UI_ITEM, N_("_Make Selection Uppercase"),
 	 N_("Make the selected text uppercase"),
 	 on_transform_upper1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
+	 /* 1 */
 	 GNOME_APP_UI_ITEM, N_("Make Selection Lowercase"),
 	 N_("Make the selected text lowercase"),
 	 on_transform_lower1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
+	 /* 2 */
+	 GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_ITEM, N_("Convert EOL chars to LF"),
-	 N_("Convert End Of Line characters to UNIX EOL (line feed: LF)"),
-	 on_transform_eolchars1_activate, NULL, NULL,
+	 /* 3 */
+	 GNOME_APP_UI_ITEM, N_("Convert EOL chars to CRLF"),
+	 N_("Convert End Of Line characters to DOS EOL (CRLF)"),
+	 on_transform_eolchars1_activate, GUINT_TO_POINTER (ANE_EOL_CRLF), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
+	{
+	 /* 4 */
+	 GNOME_APP_UI_ITEM, N_("Convert EOL chars to LF"),
+	 N_("Convert End Of Line characters to Unix EOL (LF)"),
+	 on_transform_eolchars1_activate, GUINT_TO_POINTER (ANE_EOL_LF), NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{
+	 /* 5 */
+	 GNOME_APP_UI_ITEM, N_("Convert EOL chars to CR"),
+	 N_("Convert End Of Line characters to Mac OS EOL (CR)"),
+	 on_transform_eolchars1_activate, GUINT_TO_POINTER (ANE_EOL_CR), NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{
+	 /* 6 */
+	 GNOME_APP_UI_ITEM, N_("Convert EOL chars to majority EOL"),
+	 N_("Convert End Of Line characters to mojority of the EOL found in the file"),
+	 on_transform_eolchars1_activate, GUINT_TO_POINTER (0), NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	 /* 7 */
 	GNOMEUIINFO_END
 };
 
@@ -211,19 +235,37 @@ static GnomeUIInfo inserttext1_submenu_uiinfo[] = {
         on_insert_cpp_gpl_notice, NULL, NULL,
         GNOME_APP_PIXMAP_NONE, NULL,
         0, 0, NULL},
+	   {
+		GNOME_APP_UI_ITEM, N_("# GPL Notice"),
+		N_("Insert GPL notice with Python style comments"),
+		on_insert_py_gpl_notice, NULL, NULL,
+		GNOME_APP_PIXMAP_NONE, NULL,
+		0, 0, NULL},
+	   {
+		GNOME_APP_UI_ITEM, N_("Current Username"),
+		N_("Insert name of current user"),
+		on_insert_username, NULL, NULL,
+		GNOME_APP_PIXMAP_NONE, NULL,
+		0, 0, NULL},
        { 
         GNOME_APP_UI_ITEM, N_("Current Date & Time"),
         N_("Insert current date & time"),
         on_insert_date_time, NULL, NULL,
         GNOME_APP_PIXMAP_NONE, NULL,
         0, 0, NULL},
+       { 
+        GNOME_APP_UI_ITEM, N_("Header File Template"),
+        N_("Insert a standard header file template"),
+        on_insert_header_template, NULL, NULL,
+        GNOME_APP_PIXMAP_NONE, NULL,
+        0, 0, NULL},
        GNOMEUIINFO_END
 };
 
 
 static GnomeUIInfo goto1_submenu_uiinfo[] = {
 	{
-	 GNOME_APP_UI_ITEM, N_("_Goto Line no ..."),
+	 GNOME_APP_UI_ITEM, N_("_Goto Line number ..."),
 	 N_("Go to a particular line in the editor"),
 	 on_goto_line_no1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
@@ -262,9 +304,8 @@ static GnomeUIInfo goto1_submenu_uiinfo[] = {
 };
 
 
-#define	NUM_EDIT_MENUES	(25)
-
-static GnomeUIInfo edit1_menu_uiinfo[NUM_EDIT_MENUES+1] = {
+#define	NUM_EDIT_MENUS	(24)
+static GnomeUIInfo edit1_menu_uiinfo[NUM_EDIT_MENUS+1] = {
 	{/*0*/
 	 GNOME_APP_UI_ITEM, N_("U_ndo"),
 	 N_("Undo the last action"),
@@ -352,13 +393,13 @@ static GnomeUIInfo edit1_menu_uiinfo[NUM_EDIT_MENUES+1] = {
 	
 	{/*15*/
 	 GNOME_APP_UI_ITEM, N_("_Find ..."),
-	 N_("Search for a string or regexp in the editor"),
+	 N_("Search for a string or regular expression in the editor"),
 	 on_find1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
 	 GDK_F, GDK_CONTROL_MASK, NULL},
 	
 	{/*16*/
-	 GNOME_APP_UI_ITEM, N_("Fin_d in files ..."),
+	 GNOME_APP_UI_ITEM, N_("Fin_d in Files ..."),
 	 N_("Search for a string in multiple files or directories"),
 	 on_find_in_files1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
@@ -366,14 +407,14 @@ static GnomeUIInfo edit1_menu_uiinfo[NUM_EDIT_MENUES+1] = {
 	
 	{/*17*/
 	GNOME_APP_UI_ITEM, N_("Find and R_eplace ..."),
-	N_("Search for and replace a string or regexp with another string"),
+	N_("Search for and replace a string or regular expression with another string"),
 	on_find_and_replace1_activate, NULL, NULL,
 	GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SRCHRPL,
-	GDK_R, GDK_CONTROL_MASK, NULL},
+	GDK_F, GDK_CONTROL_MASK | GDK_SHIFT_MASK, NULL},
 	
 	{/*18*/
 	 GNOME_APP_UI_ITEM, N_("Find _Next"),
-	 N_("Repeat the Last Find command"),
+	 N_("Repeat the last Find command"),
 	 on_findnext1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_SEARCH,
 	 GDK_P, GDK_CONTROL_MASK, NULL},
@@ -392,7 +433,7 @@ static GnomeUIInfo edit1_menu_uiinfo[NUM_EDIT_MENUES+1] = {
 	 N_("Edit application GUI with the Glade GUI editor"),
 	 on_edit_app_gui1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
-	 GDK_E, GDK_MOD1_MASK, NULL},
+	 GDK_G, GDK_MOD1_MASK, NULL},
 	
 	GNOMEUIINFO_SEPARATOR,/*22*/
 	
@@ -402,15 +443,7 @@ static GnomeUIInfo edit1_menu_uiinfo[NUM_EDIT_MENUES+1] = {
 	 on_save_build_messages_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
-	 
-	{/*24*/
-	 GNOME_APP_UI_SUBTREE, N_("_Plug Ins"),
-	 NULL,
-	 plugins_menu_uiinfo, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
-
-	 
+	/*24*/
 	GNOMEUIINFO_END
 };
 
@@ -429,13 +462,6 @@ static GnomeUIInfo toolbar1_submenu_uiinfo[] = {
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
-	{
-	 GNOME_APP_UI_TOGGLEITEM, N_("_Tags Toolbar"),
-	 N_("Hide/Unhide Tags toolbar"),
-	 on_tags_toolbar1_activate, NULL, NULL,
-	 GNOME_APP_PIXMAP_NONE, NULL,
-	 0, 0, NULL},
-	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_TOGGLEITEM, N_("_Debug Toolbar"),
 	 N_("Hide/Unhide Debug toolbar"),
@@ -569,8 +595,8 @@ static GnomeUIInfo zoom_text1_submenu_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
-#define	NVIEWMENUS	(21)
-static GnomeUIInfo view1_menu_uiinfo[NVIEWMENUS+1] = {
+#define	NUM_VIEW_MENUS	(21)
+static GnomeUIInfo view1_menu_uiinfo[NUM_VIEW_MENUS+1] = {
 	{/*0*/
 	 GNOME_APP_UI_ITEM, N_("_Messages"),
 	 N_("Show/Hide the Message window"),
@@ -663,7 +689,7 @@ static GnomeUIInfo view1_menu_uiinfo[NVIEWMENUS+1] = {
 	 GDK_F11, GDK_CONTROL_MASK, NULL},
 	{/*20*/
 	 GNOME_APP_UI_TOGGLEITEM, N_("Show _Locals"),
-	 N_("Show/Hide Local Variables in MessagePane"),
+	 N_("Show/Hide Local variables in Message window"),
 	 on_showhide_locals, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -732,45 +758,45 @@ static GnomeUIInfo project1_menu_uiinfo[] = {
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Remove"),
-	 N_("Remove the current file from the project"),
+	 N_("Remove the current file from the Project"),
 	 on_project_remove1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, "READ_ME",
-	 N_("Open the README file of the project"),
+	 N_("Open the README file of the Project"),
 	 on_prj_readme1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, "_TODO",
-	 N_("Open the TODO file of the project"),
+	 N_("Open the TODO file of the Project"),
 	 on_prj_todo1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, "Change_Log",
-	 N_("Open the ChangeLog file of the project"),
+	 N_("Open the ChangeLog file of the Project"),
 	 on_prj_changelog1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, "_NEWS",
-	 N_("Open the NEWS file of the project"),
+	 N_("Open the NEWS file of the Project"),
 	 on_prj_news1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Project _Configuration ..."),
-	 N_("Edit the configuration of the project"),
+	 N_("Edit the configuration of the Project"),
 	 on_project_configure1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Project _Information"),
-	 N_("Detailed information about the project"),
+	 N_("Detailed information about the Project"),
 	 on_project_project_info1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_OPEN,
 	 0, 0, NULL},
@@ -910,6 +936,18 @@ static GnomeUIInfo hilitetype1_submenu_uiinfo[] = {
 	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_CONF), NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Ada"),
+	 N_("Force the highlight style to Ada"),
+	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_ADA), NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_ITEM, N_("Baan"),
+	 N_("Force the highlight style to Baan"),
+	 on_force_hilite1_activate, GUINT_TO_POINTER (TE_LEXER_BAAN), NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
 	GNOMEUIINFO_END
 };
 
@@ -983,36 +1021,41 @@ static GnomeUIInfo build1_menu_uiinfo[] = {
 	 on_compile1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CONVERT,
 	 GDK_F9, 0, NULL},
-	GNOMEUIINFO_SEPARATOR,
+	{
+	 GNOME_APP_UI_ITEM, N_("Compile With _Make"),
+	 N_("Compile the current source file using Make"),
+	 on_make1_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 GDK_F9, GDK_SHIFT_MASK, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Build"),
-	 N_("Build the source directory of the project/current source file"),
+	 N_("Build the source directory of the Project/current source file"),
 	 on_build_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_EXEC,
 	 GDK_F10, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Build _All"),
-	 N_("Build the whole project"),
+	 N_("Build the whole Project"),
 	 on_build_all_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_F11, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("_Install"),
-	 N_("Install the project on your system"),
+	 N_("Install the Project on your system"),
 	 on_install_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Build _Distribution"),
-	 N_("Build the distribution tarball of the project"),
+	 N_("Build the distribution tarball of the Project"),
 	 on_build_dist_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Con_figure ..."),
-	 N_("Configure the project"),
+	 N_("Configure the Project"),
 	 on_configure_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -1031,7 +1074,7 @@ static GnomeUIInfo build1_menu_uiinfo[] = {
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Clean A_ll"),
-	 N_("Clean the whole project directory"),
+	 N_("Clean the whole Project directory"),
 	 on_clean_all_project1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -1322,6 +1365,16 @@ static GnomeUIInfo debug1_menu_uiinfo[] = {
 	GNOMEUIINFO_END
 };
 
+static GnomeUIInfo plugins_menu_uiinfo[] = {
+	{
+	 GNOME_APP_UI_ITEM, N_("plugins"),
+	 NULL,
+	 on_nonimplemented_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
+	GNOMEUIINFO_END
+};
+
 static GnomeUIInfo utilities1_menu_uiinfo[] = {
 	{
 	 GNOME_APP_UI_ITEM, N_("Grep Utility"),
@@ -1384,7 +1437,7 @@ static GnomeUIInfo utilities1_menu_uiinfo[] = {
 
 static GnomeUIInfo windows1_menu_uiinfo[] = {
 	{
-	 GNOME_APP_UI_ITEM, N_("_Create New Window"),
+	 GNOME_APP_UI_ITEM, N_("_Create new window"),
 	 N_("Open a new file window"),
 	 on_windows1_new_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_NEW,
@@ -1394,7 +1447,7 @@ static GnomeUIInfo windows1_menu_uiinfo[] = {
  given below. Otherwise, I won't be able to find it.
 */
 	{
-	 GNOME_APP_UI_ITEM, "Cl_ose Current window",
+	 GNOME_APP_UI_ITEM, "Cl_ose current window",
 	 N_("Close current document window"),
 	 on_windows1_close_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_CLOSE,
@@ -1411,7 +1464,7 @@ static GnomeUIInfo settings1_menu_uiinfo[] = {
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("_Source Paths ..."),
-	 N_("Specify the source paths for the Anjuta to search"),
+	 N_("Specify the source paths for Anjuta to search"),
 	 on_set_src_paths1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PREF,
 	 0, 0, NULL},
@@ -1441,8 +1494,8 @@ static GnomeUIInfo help1_menu_uiinfo[] = {
 	GNOMEUIINFO_HELP ("anjuta"),
 	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_ITEM, N_("Browse Gnome API Pages"),
-	 N_("The gnome API pages"),
+	 GNOME_APP_UI_ITEM, N_("Browse GNOME API Pages"),
+	 N_("The GNOME API pages"),
 	 on_gnome_pages1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_BOOK_RED,
 	 GDK_F1, 0, NULL},
@@ -1473,7 +1526,7 @@ static GnomeUIInfo help1_menu_uiinfo[] = {
 	 0, 0, NULL},
 	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_ITEM, N_("Anjuta Home site"),
+	 GNOME_APP_UI_ITEM, N_("Anjuta Home Page"),
 	 N_("Online documentation and resources"),
 	 on_url_activate, "http://anjuta.sourceforge.net", NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
@@ -1493,7 +1546,7 @@ static GnomeUIInfo help1_menu_uiinfo[] = {
 	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_ITEM, N_("Request Features"),
-	 N_("Submit a feature request for Anjtua"),
+	 N_("Submit a feature request for Anjuta"),
 	 on_url_activate, "http://sourceforge.net/tracker/?atid=364222&group_id=14222&func=browse", NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
@@ -1548,6 +1601,12 @@ static GnomeUIInfo menubar1_uiinfo[] = {
 	 debug1_menu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL},
+	{
+	 GNOME_APP_UI_SUBTREE, N_("Plug_ins"),
+	 NULL,
+	 plugins_menu_uiinfo, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+	 0, 0, NULL},
 	{
 	 GNOME_APP_UI_SUBTREE, N_("_Utilities"),
 	 NULL,
