@@ -38,7 +38,7 @@
 #include "build_project.h"
 #include "clean_project.h"
 #include "preferences.h"
-#include "messages.h"
+#include "message-manager.h"
 #include "compile.h"
 #include "launcher.h"
 #include "appwizard.h"
@@ -52,9 +52,13 @@
 #include "signals_cbs.h"
 #include "watch_cbs.h"
 #include "help.h"
+#include "project_import.h"
 #include "Scintilla.h"
 #include "ScintillaWidget.h"
 
+#include "tm_tagmanager.h"
+#include "file_history.h"
+
 void on_toolbar_find_clicked (GtkButton * button, gpointer user_data);
 
 gboolean closing_state;		/* Do not temper with this variable  */
@@ -107,17 +111,7 @@ on_save_as1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_save_all1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	TextEditor *te;
-	int i;
-	tags_manager_freeze (app->tags_manager);
-	for (i = 0; i < g_list_length (app->text_editor_list); i++)
-	{
-		te = g_list_nth_data (app->text_editor_list, i);
-		if (te->full_filename && !text_editor_is_saved (te))
-			text_editor_save_file (te);
-	}
-	tags_manager_thaw (app->tags_manager);
-	anjuta_status (_("All files saved ..."));
+	anjuta_save_all_files();
 }
 
 void
@@ -164,7 +158,7 @@ on_close_all_file1_activate (GtkMenuItem * menuitem, gpointer user_data)
 		next = node->next; // Save it now, as we may change it.
 		if(te)
 		{
-			if (text_editor_is_saved (te) && te->full_filename)
+			if (text_editor_is_saved (te))
 			{
 				anjuta_remove_text_editor(te);
 			}
@@ -199,6 +193,12 @@ on_new_project1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	app_wizard_proceed ();
 }
 
+void
+on_import_project_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	create_project_import_gui ();
+}
+
 void
 on_open_project1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -409,13 +409,14 @@ void
 on_transform_eolchars1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	TextEditor *te;
+	glong mode = (glong)user_data;
+	
 	te = anjuta_get_current_text_editor ();
 	if (te == NULL)
 		return;
-	aneditor_command (te->editor_id, ANE_EOL_CONVERT, 0, 0);
+	aneditor_command (te->editor_id, ANE_EOL_CONVERT, mode, 0);
 }
 
-
 void
 on_insert_c_gpl_notice(GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -470,6 +471,68 @@ on_insert_cpp_gpl_notice(GtkMenuItem * menuitem, gpointer user_data)
        aneditor_command (te->editor_id, ANE_INSERTTEXT, -1, (long)GPLNotice);
 }
 
+void
+on_insert_py_gpl_notice(GtkMenuItem * menuitem, gpointer user_data)
+{
+	   TextEditor *te;
+	   char *GPLNotice =
+		   "# This program is free software; you can redistribute it and/or modify\n"
+		   "# it under the terms of the GNU General Public License as published by\n"
+		   "# the Free Software Foundation; either version 2 of the License, or\n"
+		   "# (at your option) any later version.\n"
+		   "#\n"
+		   "# This program is distributed in the hope that it will be useful,\n"
+		   "# but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
+		   "# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+		   "# GNU Library General Public License for more details.\n"
+		   "#\n"
+		   "# You should have received a copy of the GNU General Public License\n"
+		   "# along with this program; if not, write to the Free Software\n"
+		   "# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n"
+		   "\n";
+
+	   te = anjuta_get_current_text_editor ();
+	   if (te == NULL)
+			   return;
+	   aneditor_command (te->editor_id, ANE_INSERTTEXT, -1, (long)GPLNotice);
+}
+
+void
+on_insert_username(GtkMenuItem * menuitem, gpointer user_data)
+{
+       TextEditor *te;
+	   char *Username;
+	  
+	   Username = getenv("USERNAME");
+	   
+	   te = anjuta_get_current_text_editor ();
+	   if (te == NULL)
+			   return;
+       aneditor_command (te->editor_id, ANE_INSERTTEXT, -1, (long)Username);
+}
+
+void
+on_insert_changelog_entry(GtkMenuItem * menuitem, gpointer user_data)
+{
+/* TODO: this function should insert a string of the form yyyy-mm-dd<tab>name<tab>e-mail */
+/* it will require preferences to specify a name and e-mail address                      */
+/* NB the name should be the user's personal name "Albert Einstein" since we             */
+/* can get USERNAME from the environment (see above)                                     */
+/* suggest the default should be getenv("USERNAME") plus the machine hostname            */
+/*
+       TextEditor *te;
+	   char *CLEntry;
+	   
+	   .... some code to build the changelog entry string in CLEntry ....
+			   create the date string (build from ctime?)
+			   read the name and e-mail from prefs
+
+	   te = anjuta_get_current_text_editor ();
+	   if (te == NULL)
+			   return;
+       aneditor_command (te->editor_id, ANE_INSERTTEXT, -1, (long)CLEntry);
+*/
+}
 
 void
 on_insert_date_time(GtkMenuItem * menuitem, gpointer user_data)
@@ -487,6 +550,31 @@ on_insert_date_time(GtkMenuItem * menuitem, gpointer user_data)
        aneditor_command (te->editor_id, ANE_INSERTTEXT, -1, (long)DateTime);
 }
 
+void
+on_insert_header_template(GtkMenuItem * menuitem, gpointer user_data)
+{
+       TextEditor *te;
+       char *header_template =
+	"#ifndef _HEADER_H\n"
+	"#define _HEADER_H\n"
+	"\n"
+	"#ifdef __cplusplus\n"
+	"extern \"C\"\n"
+	"{\n"
+	"#endif\n"
+	"\n"
+	"#ifdef __cplusplus\n"
+	"}\n"
+	"#endif\n"
+	"\n"
+	"#endif /* _HEADER_H */\n";
+
+       te = anjuta_get_current_text_editor ();
+       if (te == NULL)
+               return;
+       aneditor_command (te->editor_id, ANE_INSERTTEXT, -1, (long)header_template);
+}
+
 void
 on_autocomplete1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -594,13 +682,13 @@ on_goto_block_end1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_goto_prev_mesg1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	messages_previous_message (app->messages);
+	anjuta_message_manager_previous (app->messages);
 }
 
 void
 on_goto_next_mesg1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	messages_next_message (app->messages);
+	anjuta_message_manager_next (app->messages);
 }
 
 void
@@ -613,7 +701,7 @@ on_edit_app_gui1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_save_build_messages_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	if (app->messages->data[MESSAGE_BUILD])
+	if (!anjuta_message_manager_build_is_empty(app->messages))
 		gtk_widget_show (app->save_as_build_msg_sel);
 	else
 		anjuta_error("There are no build messages.");
@@ -628,11 +716,11 @@ void
 on_messages1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
 	gboolean state;
-	state = app->messages->is_showing;
+	state = anjuta_message_manager_is_shown(app->messages);
 	if(state) {
-		messages_hide (app->messages);
+		gtk_widget_hide(GTK_WIDGET(app->messages));
 	} else {
-		messages_show (app->messages, MESSAGE_TYPE_END);
+		anjuta_message_manager_show (app->messages, MESSAGE_NONE);
 	}
 }
 
@@ -946,14 +1034,6 @@ on_extended_toolbar1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	anjuta_toolbar_set_view (ANJUTA_EXTENDED_TOOLBAR, state, TRUE, TRUE);
 }
 
-void
-on_tags_toolbar1_activate (GtkMenuItem * menuitem, gpointer user_data)
-{
-	gboolean state;
-	state = GTK_CHECK_MENU_ITEM (menuitem)->active;
-	anjuta_toolbar_set_view (ANJUTA_TAGS_TOOLBAR, state, TRUE, TRUE);
-}
-
 void
 on_debug_toolbar1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -1115,29 +1195,8 @@ on_indent_dcr1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_update_tags1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	TextEditor *te;
-	gint i;
-
-	tags_manager_freeze (app->tags_manager);
-	/*tags_manager_clear (app->tags_manager);*/
-
 	if (app->project_dbase->project_is_open)
-	{
 		project_dbase_update_tags_image(app->project_dbase);
-	}
-	else
-	{
-		tags_manager_clear (app->tags_manager);
-		for (i = 0; i < g_list_length (app->text_editor_list); i++)
-		{
-			te = g_list_nth_data (app->text_editor_list, i);
-			if (te->full_filename)
-				tags_manager_update (app->tags_manager,
-						     te->full_filename);
-		}
-	}
-	tags_manager_thaw (app->tags_manager);
-	anjuta_status (_("Tags image update successfully."));
 }
 
 void
@@ -1186,6 +1245,7 @@ on_detach1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	text_editor_undock (te, container);
 	gtk_notebook_remove_page (GTK_NOTEBOOK (app->widgets.notebook),
 				  page_num);
+	
 	on_anjuta_window_focus_in_event (NULL, NULL, NULL);
 }
 
@@ -1193,9 +1253,14 @@ on_detach1_activate (GtkMenuItem * menuitem, gpointer user_data)
 void
 on_compile1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	compile_file ();
+	compile_file (FALSE);
 }
 
+void
+on_make1_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	compile_file (TRUE);
+}
 
 void
 on_build_project1_activate (GtkMenuItem * menuitem, gpointer user_data)
@@ -1544,13 +1609,13 @@ on_debugger_start_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gint target_type;
 		target_type = project_dbase_get_target_type (app->project_dbase);
 		if (target_type >= PROJECT_TARGET_TYPE_END_MARK)
-			anjuta_error (_("Target of this project is unknown"));
+			anjuta_error (_("The target executable of this Project is unknown"));
 		else if ( target_type != PROJECT_TARGET_TYPE_EXECUTABLE)
-			anjuta_warning (_("Target of this project is not executable"));
+			anjuta_warning (_("The target executable of this Project is not executable"));
 		prog = project_dbase_get_source_target (app->project_dbase);
 		if (file_is_executable (prog) == FALSE)
 		{
-			anjuta_warning(_("Executable does not exist for this project."));
+			anjuta_warning(_("The target executable does not exist for this Project"));
 			g_free (prog);
 			prog = NULL;
 		}
@@ -1576,7 +1641,7 @@ on_debugger_start_activate (GtkMenuItem * menuitem, gpointer user_data)
 				}
 				else if ((!text_editor_is_saved (te)) || (e_stat.st_mtime < s_stat.st_mtime))
 				{
-					anjuta_warning (_("Executable is not up-to-date."));
+					anjuta_warning (_("The executable is not up-to-date."));
 				}
 			}
 			else
@@ -1647,7 +1712,7 @@ on_debugger_stop_activate (GtkMenuItem * menuitem, gpointer user_data)
 		{
 			messagebox2 (GNOME_MESSAGE_BOX_QUESTION,
 				     _
-				     ("Program is running.\nDo you still want to stop Debugger?"),
+				     ("Program is RUNNING.\nDo you still want to stop Debugger?"),
 				     GNOME_STOCK_BUTTON_YES,
 				     GNOME_STOCK_BUTTON_NO,
 				     on_debugger_confirm_stop_yes_clicked,
@@ -1910,6 +1975,56 @@ on_context_help_activate (GtkMenuItem * menuitem, gpointer user_data)
 	anjuta_help_search(app->help_system, buffer);
 }
 
+void
+on_goto_tag_definition_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	TextEditor* te;
+	gboolean ret;
+	gchar buffer[1000];
+
+	te = anjuta_get_current_text_editor();
+	if(!te) return;
+	ret = aneditor_command (te->editor_id, ANE_GETCURRENTWORD, (long)buffer, (long)sizeof(buffer));
+	if (!ret)
+		return;
+	else
+		anjuta_goto_tag(buffer, te, TRUE);
+}
+
+void
+on_goto_tag_declaration_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	TextEditor* te;
+	gboolean ret;
+	gchar buffer[1000];
+
+	te = anjuta_get_current_text_editor();
+	if(!te) return;
+	ret = aneditor_command (te->editor_id, ANE_GETCURRENTWORD, (long)buffer, (long)sizeof(buffer));
+	if (!ret)
+		return;
+	else
+		anjuta_goto_tag(buffer, te, FALSE);
+}
+
+void
+on_go_back_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	an_file_history_back();
+}
+
+void
+on_go_forward_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	an_file_history_forward();
+}
+
+void
+on_history_activate (GtkMenuItem * menuitem, gpointer user_data)
+{
+	an_file_history_dump();
+}
+
 void
 on_search_a_topic1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
