@@ -58,6 +58,14 @@ void
 on_new_project1_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_import_project_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
+void
+on_open_project1_activate              (GtkMenuItem     *menuitem,
+                                        gpointer         user_data);
+
 void
 on_open_project1_activate              (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -227,9 +235,6 @@ void
 on_extended_toolbar1_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 void
-on_tags_toolbar1_activate           (GtkMenuItem     *menuitem,
-                                        gpointer         user_data);
-void
 on_debug_toolbar1_activate           (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 void
@@ -355,6 +360,9 @@ void
 on_compile1_activate                   (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
 
+void
+on_make1_activate (GtkMenuItem * menuitem, gpointer user_data);
+
 void
 on_build_project1_activate             (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -627,6 +635,21 @@ on_info_pages1_activate            (GtkMenuItem     *menuitem,
 void
 on_context_help_activate (GtkMenuItem * menuitem, gpointer user_data);
 
+void
+on_goto_tag_definition_activate (GtkMenuItem * menuitem, gpointer user_data);
+
+void
+on_goto_tag_declaration_activate (GtkMenuItem * menuitem, gpointer user_data);
+
+void
+on_go_back_activate (GtkMenuItem * menuitem, gpointer user_data);
+
+void
+on_go_forward_activate (GtkMenuItem * menuitem, gpointer user_data);
+
+void
+on_history_activate (GtkMenuItem * menuitem, gpointer user_data);
+
 void
 on_search_a_topic1_activate            (GtkMenuItem     *menuitem,
                                         gpointer         user_data);
@@ -654,13 +677,24 @@ on_reload_yes_clicked                  (GtkButton       *button,
 void
 on_insert_c_gpl_notice(GtkMenuItem * menuitem, gpointer user_data);
 
-
 void
 on_insert_cpp_gpl_notice(GtkMenuItem * menuitem, gpointer user_data);
 
+void
+on_insert_py_gpl_notice(GtkMenuItem * menuitem, gpointer user_data);
+
 void
 on_insert_date_time(GtkMenuItem * menuitem, gpointer user_data);
 
+void
+on_insert_changelog_entry(GtkMenuItem * menuitem, gpointer user_data);
+
+void
+on_insert_header_template(GtkMenuItem * menuitem, gpointer user_data);
+ 
+void
+on_insert_username(GtkMenuItem * menuitem, gpointer user_data);
+
 void
 on_save_build_messages_activate (GtkMenuItem * menuitem, gpointer user_data);
 
