@@ -45,7 +45,7 @@ preferences_new ()
 	pr = (Preferences *) malloc (sizeof (Preferences));
 	if (pr)
 	{
-		gchar *propdir, *propfile, *internfile, *str;
+		gchar *propdir, *propfile, *str;
 
 		pr->props_build_in = prop_set_new ();
 		pr->props_global = prop_set_new ();
@@ -92,37 +92,45 @@ preferences_new ()
 		prop_set_with_key (pr->props_build_in, "anjuta.pixmap.directory", app->dirs->pixmaps);
 	
 		/* Load the external configuration files */
-		propdir = g_strconcat (app->dirs->data, "/", NULL);
-		internfile =
-			g_strconcat (propdir, "/internal.properties", NULL);
-		propfile = g_strconcat (propdir, "/anjuta.properties", NULL);
-		if (file_is_readable (internfile) == FALSE
-		    || file_is_readable (propfile) == FALSE)
+		propdir = g_strconcat (app->dirs->data, "/properties/", NULL);
+		propfile = g_strconcat (propdir, "anjuta.properties", NULL);
+		
+		if (file_is_readable (propfile) == FALSE)
 		{
 			anjuta_error
-				("Cannot load Global defaults and internal configuration files:\n"
-				 "%s.\n%s.\n"
+				(_("Cannot load Global defaults and configuration files:\n"
+				 "%s.\n"
 				 "This may result in improper behaviour or instabilities.\n"
-				 "Anjuta will fall back to build in (limited) settings",
-				 propfile, internfile);
+				 "Anjuta will fall back to built in (limited) settings"),
+				 propfile);
 		}
 		prop_read (pr->props_global, propfile, propdir);
-		g_free (internfile);
 		g_free (propfile);
 		g_free (propdir);
 
-		propdir = g_strconcat (app->dirs->home, "/.anjuta", NULL);
-		propfile = g_strconcat (propdir, "/users.properties", NULL);
+		propdir = g_strconcat (app->dirs->home, "/.anjuta/", NULL);
+		propfile = g_strconcat (propdir, "user.properties", NULL);
 		prop_read (pr->props_local, propfile, propdir);
 		g_free (propdir);
 		g_free (propfile);
 
-		propdir = g_strconcat (app->dirs->home, "/.anjuta", NULL);
-		propfile = g_strconcat (propdir, "/session.properties", NULL);
+		propdir = g_strconcat (app->dirs->home, "/.anjuta/", NULL);
+		propfile = g_strconcat (propdir, "session.properties", NULL);
 		prop_read (pr->props_session, propfile, propdir);
 		g_free (propdir);
 		g_free (propfile);
 
+		/* A quick hack to fix the 'invisible' browser toolbar */
+		str = prop_get(pr->props_session, "anjuta.version");
+		if (str) {
+			if (strcmp(str, VERSION) != 0)
+				remove("~/.gnome/Anjuta");
+			g_free (str);
+		} else {
+			remove("~/.gnome/Anjuta");
+		}
+		/* quick hack ends */
+		
 		preferences_set_build_options (pr);
 		pr->current_style = NULL;
 		pr->is_showing = FALSE;
@@ -160,7 +168,8 @@ preferences_destroy (Preferences * pr)
 		gtk_widget_unref (pr->widgets.build_debug_check);
 		gtk_widget_unref (pr->widgets.build_warn_undef_check);
 		gtk_widget_unref (pr->widgets.build_jobs_spin);
-
+		// gtk_widget_unref (pr->widgets.build_autosave_check);
+		
 		gtk_widget_unref (pr->widgets.auto_save_check);
 		gtk_widget_unref (pr->widgets.auto_indent_check);
 		gtk_widget_unref (pr->widgets.tab_size_spin);
@@ -312,6 +321,12 @@ preferences_sync (Preferences * pr)
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				      (pr->widgets.build_warn_undef_check),
 				      preferences_get_int (pr, BUILD_OPTION_WARN_UNDEF));
+
+		
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+				      (pr->widgets.build_autosave_check),
+				      preferences_get_int (pr, BUILD_OPTION_AUTOSAVE));
+		 
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON
 				   (pr->widgets.build_jobs_spin),
 				   preferences_get_int (pr, BUILD_OPTION_JOBS));
@@ -467,6 +482,94 @@ preferences_sync (Preferences * pr)
 	g_free (str);
 
 /* Page 6 */
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+				      (pr->widgets.truncat_mesg_check),
+				      preferences_get_int (pr,
+							   TRUNCAT_MESSAGES));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON
+				   (pr->widgets.mesg_first_spin),
+				   preferences_get_int (pr,
+							TRUNCAT_MESG_FIRST));
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON
+				   (pr->widgets.mesg_last_spin),
+				   preferences_get_int (pr,
+							TRUNCAT_MESG_LAST));
+	
+	str = preferences_get (pr, MESSAGES_TAG_POS);
+	if (str != NULL)
+	{
+		if (strcmp (str, "top") == 0)
+		{
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+							  (pr->widgets.tag_pos_msg_radio[0]),
+							  TRUE);
+		}
+		else if (strcmp (str, "left") == 0)
+		{
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+							  (pr->widgets.tag_pos_msg_radio[2]),
+							  TRUE);
+		}
+		else if (strcmp (str, "right") == 0)
+		{
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+							  (pr->widgets.tag_pos_msg_radio[3]),
+							  TRUE);
+		}
+		else
+		{
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+							  (pr->widgets.tag_pos_msg_radio[1]),
+							  TRUE);
+		}
+		g_free (str);
+	}
+	else
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
+							(pr->widgets.tag_pos_msg_radio[1]), TRUE);
+
+	str = preferences_get(pr, MESSAGES_COLOR_ERROR);
+	if (str)
+	{
+		ColorFromString(str, &r, &g, &b);
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[0]), r, g, b, 0);
+		g_free(str);
+	}
+	else
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[0]), 255, 0, 0, 0);
+	
+		str = preferences_get(pr, MESSAGES_COLOR_WARNING);
+	if (str)
+	{
+		ColorFromString(str, &r, &g, &b);
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[1]), r, g, b, 0);
+		g_free(str);	
+	}
+	else
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[1]), 0, 127, 0, 0);
+
+	str = preferences_get(pr, MESSAGES_COLOR_MESSAGES1);
+	if (str)
+	{
+		ColorFromString(str, &r, &g, &b);
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[2]), r, g, b, 0);
+		g_free(str);
+	}
+	else
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[2]), 0, 0, 255, 0);
+
+	str = preferences_get(pr, MESSAGES_COLOR_MESSAGES2);
+	if (str)
+	{
+		ColorFromString(str, &r, &g, &b);
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[3]), r, g, b, 0);
+		g_free(str);
+	}
+	else
+		gnome_color_picker_set_i8(GNOME_COLOR_PICKER(pr->widgets.color_picker[3]), 0, 0, 0, 0);
+
+	
+/* Page 7 */
 	str = preferences_get (pr, EDITOR_TAG_POS);
 	if (strcmp (str, "bottom") == 0)
 	{
@@ -498,18 +601,6 @@ preferences_sync (Preferences * pr)
 				      (pr->widgets.no_tag_check),
 				      preferences_get_int (pr,
 							   EDITOR_TAG_HIDE));
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-				      (pr->widgets.truncat_mesg_check),
-				      preferences_get_int (pr,
-							   TRUNCAT_MESSAGES));
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON
-				   (pr->widgets.mesg_first_spin),
-				   preferences_get_int (pr,
-							TRUNCAT_MESG_FIRST));
-	gtk_spin_button_set_value (GTK_SPIN_BUTTON
-				   (pr->widgets.mesg_last_spin),
-				   preferences_get_int (pr,
-							TRUNCAT_MESG_LAST));
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 				      (pr->widgets.tags_update_check),
 				      preferences_get_int (pr,
@@ -612,7 +703,9 @@ gboolean preferences_save_yourself (Preferences * pr, FILE * fp)
 
 	fprintf (fp, "%s=%d\n", BUILD_OPTION_JOBS,
 		 preferences_get_int (pr, BUILD_OPTION_JOBS));
-
+	fprintf (fp, "%s=%d\n", BUILD_OPTION_AUTOSAVE,
+		 preferences_get_int (pr, BUILD_OPTION_AUTOSAVE));
+	
 	/* Page 2 */
 	for (i = 0;; i += 2)
 	{
@@ -699,25 +792,58 @@ gboolean preferences_save_yourself (Preferences * pr, FILE * fp)
 	str = preferences_get (pr, AUTOFORMAT_STYLE);
 	fprintf (fp, "%s=%s\n", AUTOFORMAT_STYLE, str);
 	g_free (str);
-
+	
 	/* Page 6 */
-	str = preferences_get (pr, EDITOR_TAG_POS);
-	fprintf (fp, "%s=%s\n", EDITOR_TAG_POS, str);
-	g_free (str);
-
-	fprintf (fp, "%s=%d\n", EDITOR_TAG_HIDE,
-		 preferences_get_int (pr, EDITOR_TAG_HIDE));
 	fprintf (fp, "%s=%d\n", TRUNCAT_MESSAGES,
 		 preferences_get_int (pr, TRUNCAT_MESSAGES));
 	fprintf (fp, "%s=%d\n", TRUNCAT_MESG_FIRST,
 		 preferences_get_int (pr, TRUNCAT_MESG_FIRST));
 	fprintf (fp, "%s=%d\n", TRUNCAT_MESG_LAST,
 		 preferences_get_int (pr, TRUNCAT_MESG_LAST));
+	
+	str = preferences_get (pr, MESSAGES_TAG_POS);
+	if (str) {
+		fprintf (fp, "%s=%s\n", MESSAGES_TAG_POS, str);
+		g_free (str);
+	}
+
+	str = preferences_get (pr, MESSAGES_COLOR_ERROR);
+	fprintf (fp, "%s=%s\n", MESSAGES_COLOR_ERROR, str);
+	g_free(str);
+	
+	str = preferences_get (pr, MESSAGES_COLOR_WARNING);
+	fprintf (fp, "%s=%s\n", MESSAGES_COLOR_WARNING, str);
+	g_free(str);
+
+	
+	str = preferences_get (pr, MESSAGES_COLOR_MESSAGES1);
+	fprintf (fp, "%s=%s\n", MESSAGES_COLOR_MESSAGES1, str);
+	g_free(str);
+
+	str = preferences_get (pr, MESSAGES_COLOR_MESSAGES2);
+	fprintf (fp, "%s=%s\n", MESSAGES_COLOR_MESSAGES2, str);
+	g_free(str);
+	
+	/* Page 7 */
+	str = preferences_get (pr, EDITOR_TAG_POS);
+	fprintf (fp, "%s=%s\n", EDITOR_TAG_POS, str);
+	g_free (str);
+
+	fprintf (fp, "%s=%d\n", EDITOR_TAG_HIDE,
+		 preferences_get_int (pr, EDITOR_TAG_HIDE));
 	fprintf (fp, "%s=%d\n", AUTOMATIC_TAGS_UPDATE,
 		 preferences_get_int (pr, AUTOMATIC_TAGS_UPDATE));
 	fprintf (fp, "%s=%d\n", USE_COMPONENTS,
 		 preferences_get_int (pr, USE_COMPONENTS));
 
+	/* Miscellaneous */
+	str = preferences_get(pr, CHARACTER_SET);
+	if (str)
+	{
+		fprintf(fp, "%s=%s\n", CHARACTER_SET, str);
+		g_free(str);
+	}
+
 	if (pr->is_showing)
 	{
 		gdk_window_get_root_origin (pr->widgets.window->window,
