@@ -40,6 +40,7 @@ project_config_new (void)
 	{
 		pc->disable_overwrite[i] = FALSE;
 	}
+	pc->blocked = FALSE;
 	pc->description = NULL;
 	pc->config_progs = NULL;
 	pc->config_libs = NULL;
@@ -169,6 +170,15 @@ project_config_sync (ProjectConfig * pc)
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
 					      (pc->widgets.disable_overwrite_check[i]), pc->disable_overwrite[i]);
 	}
+	if (pc->blocked)
+	{
+		for (i = 0; i < BUILD_FILE_END_MARK; i++)
+		{
+			gtk_widget_set_sensitive (pc->widgets.disable_overwrite_check[i],
+				FALSE);
+		}
+	}
+	
 	gtk_editable_delete_text (GTK_EDITABLE(pc->widgets.description_text), 0, -1);
 	if (pc->description)
 		gtk_text_insert (GTK_TEXT (pc->widgets.description_text), NULL, NULL, NULL, pc->description, -1);
@@ -298,6 +308,9 @@ project_config_save (ProjectConfig * pc, FILE* stream)
 	g_return_val_if_fail (pc != NULL, FALSE);
 	g_return_val_if_fail (stream != NULL, FALSE);
 
+	if (fprintf (stream, "project.config.blocked=%d\n\n", (int) pc->blocked) <1)
+		return FALSE;
+	
 	fprintf (stream, "project.config.disable.overwriting=");
 	for (i = 0; i < BUILD_FILE_END_MARK; i++)
 	{
@@ -351,44 +364,55 @@ project_config_set_disable_overwrite_all (ProjectConfig* pc, gboolean disable)
 gboolean
 project_config_load (ProjectConfig * pc, PropsID props)
 {
-	GList *list, *node;
-	gint i;
-	
 	g_return_val_if_fail (pc != NULL, FALSE);
 	
-	/* Do not call project_config_clear() */
-	/* Because we have already loaded the scripts */
-	list = glist_from_data (props, "project.config.disable.overwriting");
-	node = list;
-	i=0;
-	while (node)
-	{
-		if (node->data)
-		{
-			if (i >= BUILD_FILE_END_MARK)
-			{
-				glist_strings_free (list);
-				project_config_sync (pc);
-				return FALSE;
-			}
-			if (sscanf (node->data, "%d", &pc->disable_overwrite[i]) <1)
-			{
-				glist_strings_free (list);
-				project_config_sync (pc);
-				return FALSE;
-			}
-		}
-		i++;
-		node = g_list_next (node);
-	}
-	if (i < BUILD_FILE_END_MARK)
-	{
-		glist_strings_free (list);
-		project_config_sync (pc);
-		return FALSE;
-	}
-	glist_strings_free (list);
+	/* Is the project configuration blocked? */
+	pc->blocked = prop_get_int (props, "project.config.blocked", 0);
 	
+	if (pc->blocked == 0)
+	{
+		GList *list, *node;
+		gint i;
+		
+		/* Do not call project_config_clear() */
+		/* Because we have already loaded the scripts */
+		list = glist_from_data (props, "project.config.disable.overwriting");
+		node = list;
+		i=0;
+		while (node)
+		{
+			if (node->data)
+			{
+				if (i >= BUILD_FILE_END_MARK)
+				{
+					glist_strings_free (list);
+					project_config_sync (pc);
+					return FALSE;
+				}
+				if (sscanf (node->data, "%d", &pc->disable_overwrite[i]) <1)
+				{
+					glist_strings_free (list);
+					project_config_sync (pc);
+					return FALSE;
+				}
+			}
+			i++;
+			node = g_list_next (node);
+		}
+		if (i < BUILD_FILE_END_MARK)
+		{
+			glist_strings_free (list);
+			project_config_sync (pc);
+			return FALSE;
+		}
+		glist_strings_free (list);
+	}
+	else
+	{
+		int i;
+		for (i = 0; i < BUILD_FILE_END_MARK; i++)
+			pc->disable_overwrite[i] = 1;
+	}
 	pc->extra_modules_before = prop_get (props, "project.config.extra.modules.before");
 	pc->extra_modules_after = prop_get (props, "project.config.extra.modules.after");
 	project_config_sync (pc);
@@ -773,7 +797,7 @@ create_project_config_gui (ProjectConfig * pc)
 							       (notebook1),
 							       0), label0);
 
-	frame1 = gtk_frame_new (_("Disable Overwriting project files"));
+	frame1 = gtk_frame_new (_("Disable overwriting Project files"));
 	gtk_widget_show (frame1);
 	gtk_container_add (GTK_CONTAINER (notebook1), frame1);
 	gtk_container_set_border_width (GTK_CONTAINER (frame1), 5);
@@ -783,7 +807,7 @@ create_project_config_gui (ProjectConfig * pc)
 	gtk_container_add (GTK_CONTAINER (frame1), vbox1);
 
 	checkbutton[0] =
-		gtk_check_button_new_with_label (_("Project's configure.in"));
+		gtk_check_button_new_with_label (_("Project configure.in"));
 	gtk_widget_show (checkbutton[0]);
 	gtk_box_pack_start (GTK_BOX (vbox1), checkbutton[0], FALSE, FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER (checkbutton[0]), 5);
@@ -875,7 +899,7 @@ create_project_config_gui (ProjectConfig * pc)
 							       (notebook2),
 							       0), label2);
 
-	frame4 = gtk_frame_new (_("Check for libs in config.in"));
+	frame4 = gtk_frame_new (_("Check for libraries in config.in"));
 	gtk_widget_show (frame4);
 	gtk_container_add (GTK_CONTAINER (notebook2), frame4);
 	gtk_container_set_border_width (GTK_CONTAINER (frame4), 5);
@@ -953,7 +977,7 @@ create_project_config_gui (ProjectConfig * pc)
 
 	frame7 =
 		gtk_frame_new (_
-			       ("Check for lib functions in config.in"));
+			       ("Check for library functions in config.in"));
 	gtk_widget_show (frame7);
 	gtk_container_add (GTK_CONTAINER (notebook2), frame7);
 	gtk_container_set_border_width (GTK_CONTAINER (frame7), 5);
@@ -970,7 +994,7 @@ create_project_config_gui (ProjectConfig * pc)
 	gtk_container_add (GTK_CONTAINER (scrolledwindow5), text5);
 	gtk_text_set_editable (GTK_TEXT (text5), TRUE);
 
-	label6 = gtk_label_new (_("Lib functions checks"));
+	label6 = gtk_label_new (_("Function checks"));
 	gtk_widget_show (label6);
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook2),
 				    gtk_notebook_get_nth_page (GTK_NOTEBOOK
@@ -1092,7 +1116,7 @@ create_project_config_gui (ProjectConfig * pc)
 				    gtk_notebook_get_nth_page (GTK_NOTEBOOK
 							       (notebook1),
 							       3), label9);
-	frame9 = gtk_frame_new (_("Extra scripts at the end of Top Makefile.am"));
+	frame9 = gtk_frame_new (_("Extra scripts at the end of top level Makefile.am"));
 	gtk_widget_show (frame9);
 	gtk_container_add (GTK_CONTAINER (notebook1), frame9);
 	gtk_container_set_border_width (GTK_CONTAINER (frame9), 5);
