@@ -42,13 +42,15 @@
 #include "glade_iface.h"
 #include "compatibility_0.h"
 #include "defaults.h"
-#include "ccview.h"
 #include "glades.h"
 #include "CORBA-Server.h"
 #include "debugger.h"
 #include "find_replace.h"
 #include "executer.h"
 
+#include "an_file_view.h"
+#include "an_symbol_view.h"
+
 /* Including small pixmaps at compile time */
 /* So that these at least work when gnome pixmaps are not found */
 #include "../pixmaps/bfoldo.xpm"
@@ -96,8 +98,9 @@ gchar *project_type_map[]=
 	"GTK",
 	"GNOME",
 	"BONOBO",
-	"GTK--",
-	"GNOME--",
+	"GTKmm",
+	"GNOMEmm",
+	"LIBGLADE",
 	NULL
 };
 
@@ -111,7 +114,7 @@ gchar *project_target_type_map[]=
 
 gchar *module_map[]=
 {
-	"incude",
+	"include",
 	"source",
 	"pixmap",
 	"data",
@@ -235,6 +238,7 @@ gtree_insert_files (GtkWidget * ctree, GtkCTreeNode * parent,
 	while (node)
 	{
 		FileExtType ftype;
+		gchar *fname;
 		gchar *full_fname;
 		ProjectFileData *pfd;
 		GtkCTreeNode *cnode;
@@ -259,9 +263,11 @@ gtree_insert_files (GtkWidget * ctree, GtkCTreeNode * parent,
 						       dum_array, 5, pix_c,
 						       mask_c, pix_o, mask_o,
 						       TRUE, FALSE);
-		full_fname = g_strconcat (dir_prefix, "/", node->data, NULL);
+		
+		fname = node->data;
+		full_fname = g_strconcat (dir_prefix, "/", fname, NULL);
 		pfd =
-			project_file_data_new (parent, mod, full_fname);
+			project_file_data_new (parent, mod, fname, full_fname);
 		g_free (full_fname);
 		gtk_ctree_node_set_row_data_full (GTK_CTREE (ctree),
 						  GTK_CTREE_NODE (cnode), pfd,
@@ -272,19 +278,23 @@ gtree_insert_files (GtkWidget * ctree, GtkCTreeNode * parent,
 }
 
 ProjectFileData *
-project_file_data_new (GtkCTreeNode * parent, PrjModule mod, gchar * full_fname)
+project_file_data_new (GtkCTreeNode * parent, PrjModule mod,
+				gchar* fname, gchar * full_fname)
 {
 	ProjectFileData *pfd;
 
-	pfd = g_malloc (sizeof (ProjectFileData));
+	pfd = g_malloc0 (sizeof (ProjectFileData));
 	if (!pfd)
 		return NULL;
 
 	pfd->module = mod;
 	pfd->parent_node = parent;
 	pfd->filename = NULL;
+	pfd->full_filename = NULL;
+	if (fname)
+		pfd->filename = g_strdup (fname);
 	if (full_fname)
-		pfd->filename = g_strdup (full_fname);
+		pfd->full_filename = g_strdup (full_fname);
 	return pfd;
 }
 
@@ -294,6 +304,8 @@ project_file_data_destroy (ProjectFileData * pfd)
 	g_return_if_fail (pfd != NULL);
 	if (pfd->filename)
 		g_free (pfd->filename);
+	if (pfd->full_filename)
+		g_free (pfd->full_filename);
 	g_free (pfd);
 }
 
@@ -311,26 +323,22 @@ project_dbase_new (PropsID pr_props)
 	};
 
 	/* Must declare static, because it will be used forever */
-	static FileSelData fsd2 = { N_("Add To Project"), NULL,
+	static FileSelData fsd2 = { N_("Add to Project"), NULL,
 		on_add_prjfilesel_ok_clicked,
 		on_add_prjfilesel_cancel_clicked,
 		NULL
 	};
 
-	p = g_malloc (sizeof (ProjectDBase));
+	p = g_malloc0(sizeof (ProjectDBase));
 	if (!p) return NULL;
 	p->size = sizeof(ProjectDBase);
+	
+	/* Initialization */
 	/* Cannot assign p to static fsd.data, so doing it now */
 	fsd1.data = p;
 	fsd2.data = p;
-	create_project_dbase_gui (p);
-	gtk_window_set_title (GTK_WINDOW (p->widgets.window),
-			      _("Project: None"));
-	p->fileselection_open = create_fileselection_gui (&fsd1);
-	p->fileselection_add_file = create_fileselection_gui (&fsd2);
-	p->project_config = project_config_new ();
+	
 	p->tm_project = NULL;
-
 	p->widgets.root_node = NULL;
 	p->widgets.current_node = NULL;
 	for(i=0; i<MODULE_END_MARK; i++)
@@ -347,6 +355,14 @@ project_dbase_new (PropsID pr_props)
 	p->win_height = 400;
 	p->top_proj_dir = NULL;
 	p->current_file_data = NULL;
+	p->excluded_modules = NULL;
+	
+	create_project_dbase_gui (p);
+	gtk_window_set_title (GTK_WINDOW (p->widgets.window),
+			      _("Project: None"));
+	p->fileselection_open = create_fileselection_gui (&fsd1);
+	p->fileselection_add_file = create_fileselection_gui (&fsd2);
+	p->project_config = project_config_new ();
 	p->sel_module = MODULE_SOURCE;
 	p->props = prop_set_new ();
 	prop_set_parent (p->props, pr_props);
@@ -403,7 +419,8 @@ project_dbase_destroy (ProjectDBase * p)
 	project_config_destroy (p->project_config);
 	
 	gtk_widget_unref (p->widgets.window);
-	gtk_widget_unref (p->widgets.ccview);
+	sv_clear();
+	fv_clear();
 	gtk_widget_unref (p->widgets.client_area);
 	gtk_widget_unref (p->widgets.client);
 	gtk_widget_unref (p->widgets.scrolledwindow);
@@ -469,12 +486,17 @@ project_dbase_clear (ProjectDBase * p)
 	string_assign (&p->top_proj_dir, NULL);
 	string_assign (&p->proj_filename, NULL);
 	prop_clear (p->props);
+	if (p->excluded_modules) {
+		glist_strings_free(p->excluded_modules);
+		p->excluded_modules = NULL;
+	}
 	gtk_window_set_title (GTK_WINDOW (p->widgets.window),
 			      _("Project: None"));
 	p->project_is_open = FALSE;
 	p->is_saved = TRUE;
 	p->m_prj_ShowLocal	= SHOW_LOCALS_DEFAULT ;
 	extended_toolbar_update ();
+	anjuta_update_app_status (FALSE, NULL);
 }
 
 void
@@ -605,7 +627,7 @@ load_from_buffer (ProjectDBase* p, gchar* prj_buff, gint loc)
 		temp = g_strdup (" ");
 	if (strcmp (temp, "project") != 0)
 	{
-		anjuta_error (_("Couldn't load project: %s"), p->proj_filename);
+		anjuta_error (_("Unable to load Project: %s"), p->proj_filename);
 		g_free (temp);
 		return FALSE;
 	}
@@ -616,15 +638,14 @@ load_from_buffer (ProjectDBase* p, gchar* prj_buff, gint loc)
 		gchar *ver;
 		ver = prop_get (p->props, "anjuta.version");
 		anjuta_error(_
-					 ("Error: You need Anjuta version %s or later to open this project.\n"
-					  "Please upgrade Anjuta to the latest version (Help for more information).\n"
-					  "For the time being, I am too old to load it.:-("), ver);
+				   ("Anjuta version %s or later is required to open this Project.\n"
+					"Please upgrade to the latest version of Anjuta (Help for more information)."), ver);
 		g_free (ver);
 		return FALSE;
 	}
 	if (project_config_load(p->project_config, p->props)== FALSE)
 	{
-		anjuta_error (_("Couldn't load project: %s"), p->proj_filename);
+		anjuta_error (_("Unable to load Project: %s"), p->proj_filename);
 		return FALSE;
 	}
 	return TRUE;
@@ -717,149 +738,16 @@ project_dbase_reload_session (ProjectDBase * p)
 gboolean
 project_dbase_load_project (ProjectDBase * p, gboolean show_project)
 {
-	gchar *prj_buff, buff[512], *str;
-	gint level, read_size, pos;
-	gboolean error_shown, syserr;
-	FILE* fp;
-
+	gchar* filename = fileselection_get_filename (p->fileselection_open);
+	gboolean ret;
+	
 	anjuta_set_busy ();
-	prj_buff = NULL;
-	fp = NULL;
-	error_shown = FALSE;
-	syserr = FALSE;
-	pos = 0;
-	
-	if (p->project_is_open == TRUE)
-		project_dbase_clean_left (p);
-
-	p->project_is_open = TRUE;
-	p->proj_filename = fileselection_get_filename (p->fileselection_open);
-
-	/* Doing some check before actual loading */
-	fp = fopen (p->proj_filename, "r");
-	if (fp == NULL)
-	{
-		syserr = TRUE;
-		goto go_error;
-	}
-	
-	if (fscanf (fp, "# Anjuta Version %s \n", buff) < 1)
-	{
-		syserr = TRUE;
-		goto go_error;
-	}
-	if (fscanf (fp, "Compatibility Level: %d\n", &level) < 1)
-	{
-		syserr = TRUE;
-		goto go_error;
-	}
-	if (level < COMPATIBILITY_LEVEL)
-	{
-		switch (level)
-		{
-		case 0:
-			load_default_project (p);
-			compatibility_0_load_project (p, fp);
-			fclose (fp);
-			goto done;
-		default:
-			anjuta_error ("Unknown compatibility level of the project");
-			error_shown = TRUE;
-			goto go_error;
-		}
-	}
-	if (level > COMPATIBILITY_LEVEL)
-	{
-		anjuta_error (_
-		 ("You need Anjuta version %s or later to "
-		"open this project.\n"
-		"Please upgrade Anjuta to the latest version "
-		"(Help for more information).\n"
-		"For the time being, I am too old to load it. :-("), buff);
-		error_shown = TRUE;
-		goto go_error;
-	}
-
-	pos = ftell (fp);
-	fclose (fp);
-	fp = NULL;
-	/* Checks end here */
-
-	prj_buff = get_file_as_buffer (p->proj_filename);
-	if (prj_buff == NULL)
-	{
-		syserr = TRUE;
-		goto go_error;
-	}
-	if (pos > strlen(prj_buff))
-	{
-		syserr = TRUE;
-		goto go_error;
-	}
-	read_size = project_config_load_scripts (p->project_config, &prj_buff[pos]);
-	if (read_size < 0)
-		goto go_error;
-	if (load_from_buffer(p, prj_buff, pos+read_size) == FALSE)
-	{
-		error_shown = TRUE;
-		goto go_error;
-	}
-	g_free (prj_buff);
-	prj_buff = NULL;
-
-done:
-	/* It is necessary to transfer this variable */
-	/* from prj props to preferences props */
-	str = prop_get (p->props, "anjuta.program.parameters");
-	if (str)
-		prop_set_with_key (app->preferences->props,
-			"anjuta.program.parameters", str);
-	else
-		prop_set_with_key (app->preferences->props,
-			"anjuta.program.parameters", "");
-	string_free (str);		
-	p->is_saved = TRUE;
-	p->top_proj_dir = g_dirname (p->proj_filename);
-	compiler_options_load (app->compiler_options, p->props);
-	src_paths_load (app->src_paths, p->props);
-	ccview_project_set_directory (CCVIEW_PROJECT(p->widgets.ccview),
-		p->top_proj_dir);
-	/* Project loading completed */
-
-	/* Now Project setup */
-	project_dbase_update_tree (p);
-	extended_toolbar_update ();
-	tags_manager_load (app->tags_manager);
-	project_dbase_update_tags_image(p);
-	anjuta_status (_("Project loaded successfully."));
+	ret = project_dbase_load_project_file(p, filename);
+	if (ret)
+		project_dbase_load_project_finish(p, show_project);		
+	g_free(filename);
 	anjuta_set_active ();
-	if (show_project)
-		project_dbase_show (p);
-	project_dbase_reload_session(p);
-	if( IsGladen() )
-		project_dbase_summon_glade ( p );
-	return TRUE;
-
-go_error:
-	prop_clear (p->props);
-	if (!error_shown) /* If error is not yet shown */
-	{
-		if (syserr)
-		{
-			anjuta_system_error (errno, _("Error in loading Project: %s"), p->proj_filename);
-		}
-		else
-		{
-			anjuta_error (_("Error in loading Project: %s"), p->proj_filename);
-		}
-	}
-	string_assign (&p->proj_filename, NULL);
-	p->proj_filename = NULL;
-	p->project_is_open = FALSE;
-	if (prj_buff) g_free (prj_buff);
-	if (fp) fclose (fp);
-	anjuta_set_active ();
-	return FALSE;
+	return ret;
 }
 
 gboolean
@@ -870,7 +758,6 @@ project_dbase_save_project (ProjectDBase * p)
 	gint i;
 
 	str = NULL;
-	tags_manager_save(app->tags_manager);
 /*	if (p->is_saved) return TRUE;*/
 	anjuta_set_busy ();
 	if (p->project_is_open == FALSE)
@@ -900,7 +787,7 @@ project_dbase_save_project (ProjectDBase * p)
 		goto error_show;
 
 	str = prop_get (p->props, "project.name");
-	if (!str) str = g_strdup ("Unkown_Project");
+	if (!str) str = g_strdup ("Unknown Project");
 	if (fprintf (fp, "project.name=%s\n", str) < 1)
 		goto error_show;
 	g_free (str); str = NULL;
@@ -935,6 +822,20 @@ project_dbase_save_project (ProjectDBase * p)
 		goto error_show;
 	g_free (str); str = NULL;
 
+	fprintf (fp, "project.excluded.modules=");
+	if (p->excluded_modules) {
+		GList* node;
+		node = p->excluded_modules;
+		while (node)
+		{
+			if (node->data)
+				if (fprintf (fp, "\\\n\t%s", (gchar*)node->data) < 1)
+					goto error_show;
+			node = g_list_next (node);
+		}
+	}
+	fprintf (fp, "\n\n");
+
 	str = prop_get (p->props, "project.has.gettext");
 	if (!str) str = g_strdup ("1");
 	if (fprintf (fp, "project.has.gettext=%s\n\n", str) < 1)
@@ -949,7 +850,7 @@ project_dbase_save_project (ProjectDBase * p)
 
 	str = prop_get (p->props, "project.menu.entry");
 	if (!str) str = prop_get (p->props, "project.name");
-	if (!str) str = g_strdup ("Unkown project");
+	if (!str) str = g_strdup ("Unknown Project");
 	if (fprintf (fp, "project.menu.entry=%s\n", str) < 1)
 		goto error_show;
 	g_free (str); str = NULL;
@@ -1075,22 +976,20 @@ project_dbase_save_project (ProjectDBase * p)
 		goto error_show;
 	if (src_paths_save (app->src_paths, fp) == FALSE)
 		goto error_show;
-	tags_manager_save (app->tags_manager);
 	if (p->tm_project)
 		tm_project_save(TM_PROJECT(p->tm_project));
-	ccview_project_save(CCVIEW_PROJECT(app->project_dbase->widgets.ccview));
 	p->is_saved = TRUE;
 	fclose (fp);
 	source_write_build_files (p);
-	anjuta_status (_("Project Saved Successfully"));
+	anjuta_status (_("Project saved successfully"));
 	anjuta_set_active ();
 	return TRUE;
 
 error_show:
 	if (str) g_free (str);
-	anjuta_system_error (errno, _("Unable to save the project."));
+	anjuta_system_error (errno, _("Unable to save the Project."));
 	fclose (fp);
-	anjuta_status (_("Unable to save the project."));
+	anjuta_status (_("Unable to save the Project."));
 	anjuta_set_active ();
 	p->is_saved = FALSE;
 	return FALSE;
@@ -1145,33 +1044,42 @@ project_dbase_load_yourself (ProjectDBase * p, PropsID props)
 void
 project_dbase_update_tags_image(ProjectDBase* p)
 {
-	GList *src_files;
 	gchar* src_dir;
+
+	g_return_if_fail (p != NULL);
+
 	if (p->project_is_open == FALSE)
 		return;
+
 	if (p->tm_project)
 	{
 		if (((NULL == TM_PROJECT(p->tm_project)->file_list) ||
 			(0 == TM_PROJECT(p->tm_project)->file_list->len))
 			&& (p->top_proj_dir))
-			tm_project_autoscan(TM_PROJECT(p->tm_project), p->top_proj_dir);
+			tm_project_autoscan(TM_PROJECT(p->tm_project));
 		else
 			tm_project_update(p->tm_project, FALSE, TRUE, TRUE);
 	}
 	else if (p->top_proj_dir)
-		p->tm_project = tm_project_new(p->top_proj_dir, NULL);
+		p->tm_project = tm_project_new(p->top_proj_dir, NULL, NULL, TRUE);
+
+	sv_populate();
+	fv_populate();
+
 	src_dir = project_dbase_get_module_dir (p, MODULE_SOURCE);
+
 	if (src_dir)
 	{
 		gchar* src_path;
-		
+		GList *src_files;
+
 		src_path = g_strconcat (src_dir, "/", NULL);
 		src_files = glist_from_data (p->props, "module.source.files");
 		glist_strings_prefix (src_files, src_path);
-		tags_manager_update_image (app->tags_manager, src_files);
 		glist_strings_free (src_files);
 		g_free (src_path);
 		g_free (src_dir);
+
 	}
 }
 
@@ -1256,7 +1164,6 @@ project_dbase_close_project (ProjectDBase * p)
 	g_return_if_fail (p != NULL);
 	g_return_if_fail (p->project_is_open == TRUE);
 	
-	tags_manager_save (app->tags_manager);
 	if (p->is_saved == FALSE)
 	{
 		gint but;
@@ -1306,7 +1213,8 @@ project_dbase_close_project (ProjectDBase * p)
 	project_dbase_hide (p);
 	project_dbase_update_menu (p);	
 	project_dbase_clean_left (p);
-	ccview_project_clear(CCVIEW_PROJECT(p->widgets.ccview));
+	sv_clear();
+	fv_clear();
 	p->project_is_open = FALSE;
 }
 
@@ -1412,7 +1320,7 @@ project_dbase_show_info (ProjectDBase * p)
 	g_return_if_fail (p->project_is_open == TRUE);
 
 	str[0] = project_dbase_get_proj_name(p);
-	str[1] = prop_get (p->props, "project.verson");
+	str[1] = prop_get (p->props, "project.version");
 	str[2] = prop_get (p->props, "project.author");
 	if (project_dbase_get_project_type(p) != PROJECT_TYPE_GENERIC)
 		str[3] = g_strdup (_("Yes"));
@@ -1479,8 +1387,8 @@ project_dbase_summon_glade (ProjectDBase *p)
 	{
 		g_free (filename);
 		anjuta_error (
-			_("The Project glade file does not\n"
-			"exist in the top level project directory."));
+			_("A .glade file does not\n"
+			"exist in the top level Project directory."));
 		return FALSE;
 	}
 	ret = glade_iface_start_glade_editing (filename);
@@ -1494,17 +1402,17 @@ project_dbase_generate_source_code (ProjectDBase *p)
 {
 	gchar *filename, *target;
 	gboolean ret;
-
+	
 	if (p->project_is_open == FALSE)
 		return FALSE;
 
 	target =	prop_get (p->props, "project.source.target");
 	g_strdelimit (target, "-", '_');
-	if (project_dbase_get_project_type (p) == PROJECT_TYPE_GENERIC)
+	if (project_dbase_get_project_type (p)->id == PROJECT_TYPE_GENERIC)
 	{
 		return source_write_generic_main_c (p);
 	}
-	
+
 	filename = g_strdup_printf ("%s/%s.glade",
 				    p->top_proj_dir,
 				    target);
@@ -1512,12 +1420,16 @@ project_dbase_generate_source_code (ProjectDBase *p)
 	if (file_is_regular (filename) == FALSE)
 	{
 		anjuta_error (
-			_("The Project glade file does not\n"
-			"exist in the top level project directory."));
+			_("A .glade file does not\n"
+			"exist in the top level Project directory."));
 		ret = source_write_generic_main_c (p);
 	}
 	else
 	{
+		if (project_dbase_get_project_type (p)->id == PROJECT_TYPE_LIBGLADE)
+		{
+			ret = source_write_libglade_main_c (p);
+		} else
 		if ((ret=glade_iface_generate_source_code (filename)) == FALSE)
 			ret = source_write_generic_main_c (p);
 	}
@@ -1778,21 +1690,9 @@ project_dbase_scan_files_in_module(ProjectDBase* p, PrjModule module, gboolean w
 void
 project_dbase_clean_left (ProjectDBase * p)
 {
-	TextEditor *te;
-	gint i;
 	project_dbase_clear (p);
 	project_config_clear (p->project_config);
 
-	tags_manager_freeze (app->tags_manager);
-	tags_manager_clear (app->tags_manager);
-	for (i = 0; i < g_list_length (app->text_editor_list); i++)
-	{
-		te = g_list_nth_data (app->text_editor_list, i);
-		if (te->full_filename)
-			tags_manager_update (app->tags_manager,
-					     te->full_filename);
-	}
-	tags_manager_thaw (app->tags_manager);
 	compiler_options_load (app->compiler_options, app->preferences->props);
 	src_paths_load (app->src_paths, app->preferences->props);
 }
@@ -1941,7 +1841,7 @@ project_dbase_update_tree (ProjectDBase * p)
 					NULL, NULL, dum_array, 5, pix_c,
 					mask_c, pix_o, mask_o, FALSE, TRUE);
 	pfd =
-		project_file_data_new (NULL, MODULE_SOURCE, NULL);
+		project_file_data_new (NULL, MODULE_SOURCE, NULL, NULL);
 	gtk_ctree_node_set_row_data_full (GTK_CTREE (p->widgets.ctree),
 					  GTK_CTREE_NODE (parent), pfd,
 					  (GtkDestroyNotify)
@@ -1983,16 +1883,19 @@ project_dbase_update_tree (ProjectDBase * p)
 		g_free (key);
 		g_free (dum_array[0]);
 		p->widgets.module_node[i] = sub_parent;
-		pfd = project_file_data_new (parent, i, NULL);
+		pfd = project_file_data_new (parent, i, NULL, NULL);
 		gtk_ctree_node_set_row_data_full (GTK_CTREE
 						  (p->widgets.ctree),
 						  GTK_CTREE_NODE
 						  (sub_parent), pfd,
 						  (GtkDestroyNotify)
 						  project_file_data_destroy);
-		prefix =
-			g_strconcat (p->top_proj_dir, "/", tmp1,
-				     NULL);
+		if (strcmp(tmp1, ".") == 0) {
+			prefix = g_strdup(p->top_proj_dir);
+		} else {
+			prefix =
+				g_strconcat (p->top_proj_dir, "/", tmp1, NULL);
+		}
 		gtree_insert_files (p->widgets.ctree, sub_parent, i, prefix, list);
 		g_free (prefix);
 		glist_strings_free (list);
@@ -2058,11 +1961,15 @@ project_dbase_remove_file (ProjectDBase * p)
 		g_free (key);
 		return;
 	}
-	source_file = tm_project_find_file(p->tm_project, p->current_file_data->filename);
+	source_file = tm_project_find_file(p->tm_project, p->current_file_data->filename, FALSE);
 	if (source_file)
 		tm_project_remove_object(TM_PROJECT(p->tm_project), source_file);
-	fn = extract_filename (p->current_file_data->filename);
+ 	else
+ 		g_warning("Unable to find %s in project", p->current_file_data->filename);
 	
+	/* fn = extract_filename (p->current_file_data->filename); */
+	fn = p->current_file_data->filename;
+
 	pos = strstr (files, fn);
 	if (pos == NULL)
 	{
@@ -2115,3 +2022,161 @@ project_dbase_set_show_locals( ProjectDBase * p,  const gboolean bActive )
 		p->m_prj_ShowLocal = bActive ;
 	}
 }
+
+gboolean
+project_dbase_load_project_file (ProjectDBase * p, gchar * filename)
+{
+	gchar *prj_buff, buff[512], *str;
+	gint level, read_size, pos;
+	gboolean error_shown, syserr;
+	FILE* fp;
+	
+	prj_buff = NULL;
+	fp = NULL;
+	error_shown = FALSE;
+	syserr = FALSE;
+	pos = 0;
+	
+	if (p->project_is_open == TRUE)
+		project_dbase_clean_left (p);
+
+	p->project_is_open = TRUE;
+	p->proj_filename = g_strdup(filename);
+	
+	/* Doing some check before actual loading */
+	fp = fopen (p->proj_filename, "r");
+	if (fp == NULL)
+	{
+		syserr = TRUE;
+		goto go_error;
+	}
+	
+	if (fscanf (fp, "# Anjuta Version %s \n", buff) < 1)
+	{
+		syserr = TRUE;
+		goto go_error;
+	}
+	if (fscanf (fp, "Compatibility Level: %d\n", &level) < 1)
+	{
+		syserr = TRUE;
+		goto go_error;
+	}
+	if (level < COMPATIBILITY_LEVEL)
+	{
+		switch (level)
+		{
+		case 0:
+			load_default_project (p);
+			compatibility_0_load_project (p, fp);
+			fclose (fp);
+			goto done;
+		default:
+			anjuta_error ("Unknown compatibility level of the project");
+			error_shown = TRUE;
+			goto go_error;
+		}
+	}
+	if (level > COMPATIBILITY_LEVEL)
+	{
+		anjuta_error (_
+		 ("You need Anjuta version %s or later to "
+		"open this project.\n"
+		"Please upgrade Anjuta to the latest version "
+		"(Help for more information).\n"
+		"For the time being, I am too old to load it."), buff);
+		error_shown = TRUE;
+		goto go_error;
+	}
+
+	pos = ftell (fp);
+	fclose (fp);
+	fp = NULL;
+	/* Checks end here */
+
+	prj_buff = get_file_as_buffer (p->proj_filename);
+	if (prj_buff == NULL)
+	{
+		syserr = TRUE;
+		goto go_error;
+	}
+	if (pos > strlen(prj_buff))
+	{
+		syserr = TRUE;
+		goto go_error;
+	}
+	read_size = project_config_load_scripts (p->project_config, &prj_buff[pos]);
+	if (read_size < 0)
+		goto go_error;
+	if (load_from_buffer(p, prj_buff, pos+read_size) == FALSE)
+	{
+		error_shown = TRUE;
+		goto go_error;
+	}
+	g_free (prj_buff);
+	prj_buff = NULL;
+
+
+
+done:
+	/* It is necessary to transfer this variable */
+	/* from prj props to preferences props */
+	str = prop_get (p->props, "anjuta.program.parameters");
+	if (str)
+		prop_set_with_key (app->preferences->props,
+			"anjuta.program.parameters", str);
+	else
+		prop_set_with_key (app->preferences->props,
+			"anjuta.program.parameters", "");
+	string_free (str);		
+	p->is_saved = TRUE;
+	p->top_proj_dir = g_dirname (p->proj_filename);
+	
+	/* Load excluded modules */
+	if (p->excluded_modules) {
+		glist_strings_free(p->excluded_modules);
+	}
+	p->excluded_modules = glist_from_data(p->props, "project.excluded.modules");
+
+	compiler_options_load (app->compiler_options, p->props);
+	src_paths_load (app->src_paths, p->props);
+	/* Project loading completed */
+	return TRUE;
+	
+go_error:
+	prop_clear (p->props);
+	if (!error_shown) /* If error is not yet shown */
+	{
+		if (syserr)
+		{
+			anjuta_system_error (errno, _("Error in loading Project: %s"), p->proj_filename);
+		}
+		else
+		{
+			anjuta_error (_("Error in loading Project: %s"), p->proj_filename);
+		}
+	}
+	string_assign (&p->proj_filename, NULL);
+	p->proj_filename = NULL;
+	p->project_is_open = FALSE;
+	if (prj_buff) g_free (prj_buff);
+	if (fp) fclose (fp);
+	return FALSE;
+}
+
+gboolean
+project_dbase_load_project_finish (ProjectDBase * p, gboolean show_project)
+{
+	/* Now Project setup */
+	project_dbase_update_tree (p);
+	extended_toolbar_update ();
+	project_dbase_update_tags_image(p);
+	anjuta_update_app_status(FALSE, NULL);
+	anjuta_status (_("Project loaded successfully."));
+	anjuta_set_active ();
+	if (show_project)
+		project_dbase_show (p);
+	project_dbase_reload_session(p);
+	if( IsGladen() )
+		project_dbase_summon_glade ( p );
+	return TRUE;
+}
