@@ -25,81 +25,20 @@
 #include <string.h>
 
 #include <gnome.h>
-#include <ccview.h>
 #include "anjuta.h"
 #include "project_dbase.h"
 #include "utilities.h"
 #include "resources.h"
 #include "fileselection.h"
+#include "an_symbol_view.h"
+#include "an_file_view.h"
 
 extern gchar *module_map[];
-static gboolean close_file_state = FALSE;
-static gboolean close_prj_state = FALSE;
 
 static void on_project_dbase_remove_confirm_yes_clicked (GtkButton * button,
 							 gpointer user_data);
-static void on_project_dbase_ccview_update_start (CcviewProject *cprj, 
-						  ProjectDBase  *p);
-static void on_project_dbase_ccview_update_end (CcviewProject *cprj, 
-						ProjectDBase  *p);
 static void add_file (ProjectDBase * p);
 
-
-static 
-void on_project_dbase_ccview_go_to (CcviewProject* cprj, gchar* file,
-			gint line, ProjectDBase* p)
-{
-	anjuta_goto_file_line (file, line);
-}
-
-static 
-void on_project_dbase_ccview_update_start (CcviewProject *cprj, 
-				           ProjectDBase  *p)
-{
-	MainToolbar *mt;
-	ExtendedToolbar *et;
-	FileSubMenu *file_submenu;
-
-	anjuta_set_busy ();
-	
-	mt = (MainToolbar *) &(app->widgets.toolbar.main_toolbar);
-	close_file_state = GTK_WIDGET_IS_SENSITIVE (mt->close);
-
-	et = (ExtendedToolbar *) &(app->widgets.toolbar.extended_toolbar);
-	close_prj_state = GTK_WIDGET_IS_SENSITIVE (et->close_project);
-
-	file_submenu = &(app->widgets.menubar.file);
-
-	gtk_widget_set_sensitive (mt->close, FALSE);
-	gtk_widget_set_sensitive (et->close_project, FALSE);
-	gtk_widget_set_sensitive (file_submenu->close_file, FALSE);
-	gtk_widget_set_sensitive (file_submenu->close_project, FALSE);
-}
-
-static 
-void on_project_dbase_ccview_update_end (CcviewProject *cprj, 
-				         ProjectDBase  *p)
-{	
-	MainToolbar *mt;
-	ExtendedToolbar *et;
-	FileSubMenu *file_submenu;
-
-	mt = (MainToolbar *) &(app->widgets.toolbar.main_toolbar);
-	close_file_state = GTK_WIDGET_IS_SENSITIVE (mt->close);
-
-	et = (ExtendedToolbar *) &(app->widgets.toolbar.extended_toolbar);
-	close_prj_state = GTK_WIDGET_IS_SENSITIVE (et->close_project);
-
-	file_submenu = &(app->widgets.menubar.file);
-
-	gtk_widget_set_sensitive (mt->close, close_file_state);
-	gtk_widget_set_sensitive (et->close_project, close_prj_state);
-	gtk_widget_set_sensitive (file_submenu->close_file, close_file_state);
-	gtk_widget_set_sensitive (file_submenu->close_project, close_prj_state);
-
-	anjuta_set_active ();
-}
-
 void
 on_project_add_new1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
@@ -113,7 +52,9 @@ on_project_view1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	ProjectDBase *p = app->project_dbase;
 	g_return_if_fail (p->widgets.current_node != NULL);
 	g_return_if_fail (p->current_file_data != NULL);
-	anjuta_view_file (p->current_file_data->filename);
+	if (p->widgets.current_node && p->current_file_data) {
+		anjuta_view_file (p->current_file_data->full_filename);
+	}
 }
 
 
@@ -123,7 +64,7 @@ on_project_edit1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	ProjectDBase *p = app->project_dbase;
 	g_return_if_fail (p->widgets.current_node != NULL);
 	g_return_if_fail (p->current_file_data != NULL);
-	anjuta_open_file (p->current_file_data->filename);
+	anjuta_open_file (p->current_file_data->full_filename);
 }
 
 void
@@ -140,7 +81,7 @@ on_project_remove1_activate (GtkMenuItem * menuitem, gpointer user_data)
 	buff =
 		g_strdup_printf (_
 				 ("Are you sure you want to remove the item\n\"%s\""
-				  " from the Project Data Base?"),
+				  " from the Project?"),
 extract_filename (p->current_file_data->filename));
 	messagebox2 (GNOME_MESSAGE_BOX_QUESTION, buff, GNOME_STOCK_BUTTON_YES,
 		     GNOME_STOCK_BUTTON_NO,
@@ -306,7 +247,7 @@ on_open_prjfilesel_ok_clicked (GtkButton * button, gpointer user_data)
 	if (p->project_is_open)
 	{
 		messagebox2 (GNOME_MESSAGE_BOX_WARNING,
-			     _("There is already a project opened." \
+			     _("There is already a Project open." \
 			       "Do you want to close it first?"),
 			     GNOME_STOCK_BUTTON_YES,
 			     GNOME_STOCK_BUTTON_NO,
@@ -525,9 +466,10 @@ create_project_dbase_gui (ProjectDBase * p)
 	GtkWidget *eventbox1;
 	GtkWidget *notebook1;
 	GtkWidget *scrolledwindow1;
-	GtkWidget *ccview_prj;
 	GtkWidget *ctree1;
 	GtkCList *clist1;
+	AnSymbolView *sv;
+	AnFileView *fv;
 
 	window1 = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_title (GTK_WINDOW (window1), _("Project: None"));
@@ -536,19 +478,23 @@ create_project_dbase_gui (ProjectDBase * p)
 	eventbox1 = gtk_event_box_new ();
 	gtk_widget_show (eventbox1);
 	gtk_container_add (GTK_CONTAINER (window1), eventbox1);
-	
-	ccview_prj = ccview_project_new();
-	gtk_widget_show (ccview_prj);
-	notebook1 = CCVIEW_PROJECT (ccview_prj)->notebook;
-	ccview_project_set_recursive (CCVIEW_PROJECT(ccview_prj), TRUE);
-	ccview_project_set_use_automake (CCVIEW_PROJECT(ccview_prj), FALSE);
-	ccview_project_set_follow_includes (CCVIEW_PROJECT(ccview_prj), FALSE);
+
+	notebook1 = gtk_notebook_new();
+	gtk_widget_show(notebook1);
+	gtk_notebook_set_tab_pos(GTK_NOTEBOOK(notebook1), GTK_POS_BOTTOM);
+	fv = fv_populate();
+	gtk_notebook_prepend_page(GTK_NOTEBOOK(notebook1), fv->win
+	  , gtk_label_new(_("Files")));
+
+	sv = sv_populate();
+	gtk_notebook_prepend_page(GTK_NOTEBOOK(notebook1), sv->win
+	  , gtk_label_new(_("Symbols")));
 
 	scrolledwindow1 = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow1),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_widget_show (scrolledwindow1);
-    gtk_notebook_prepend_page(GTK_NOTEBOOK(notebook1),scrolledwindow1,
+	gtk_notebook_prepend_page(GTK_NOTEBOOK(notebook1),scrolledwindow1,
                              gtk_label_new(_("Project")));
 	gtk_notebook_set_page(GTK_NOTEBOOK(notebook1), 0);
 
@@ -558,6 +504,7 @@ create_project_dbase_gui (ProjectDBase * p)
 	gtk_container_add (GTK_CONTAINER (scrolledwindow1), ctree1);
 	gtk_clist_set_selection_mode (clist1, GTK_SELECTION_BROWSE);
 	gtk_ctree_set_line_style (GTK_CTREE(ctree1), GTK_CTREE_LINES_DOTTED);
+	gtk_ctree_set_expander_style (GTK_CTREE(ctree1), GTK_CTREE_EXPANDER_SQUARE);
 	gtk_widget_show (ctree1);
 
 	gtk_accel_group_attach (app->accel_group, GTK_OBJECT (window1));
@@ -571,26 +518,17 @@ create_project_dbase_gui (ProjectDBase * p)
 	gtk_signal_connect (GTK_OBJECT (ctree1), "event",
 			    GTK_SIGNAL_FUNC (on_project_dbase_event), p);
 
-	gtk_signal_connect (GTK_OBJECT (ccview_prj), "go_to",
-			    GTK_SIGNAL_FUNC (on_project_dbase_ccview_go_to), p);
-
-	gtk_signal_connect (GTK_OBJECT (ccview_prj), "update_start",
-			    GTK_SIGNAL_FUNC (on_project_dbase_ccview_update_start), p);
-
-	gtk_signal_connect (GTK_OBJECT (ccview_prj), "update_end",
-			    GTK_SIGNAL_FUNC (on_project_dbase_ccview_update_end), p);
-
 	p->widgets.window = window1;
-	p->widgets.ccview = ccview_prj;
+	p->widgets.notebook = notebook1;
 	p->widgets.client_area = eventbox1;
-	p->widgets.client = ccview_prj;
+	p->widgets.client = notebook1;
 	p->widgets.ctree = ctree1;
 	p->widgets.scrolledwindow = scrolledwindow1;
 
 	create_project_menus (p);
 
 	gtk_widget_ref (p->widgets.window);
-	gtk_widget_ref (p->widgets.ccview);
+	gtk_widget_ref(p->widgets.notebook);
 	gtk_widget_ref (p->widgets.client_area);
 	gtk_widget_ref (p->widgets.client);
 	gtk_widget_ref (p->widgets.scrolledwindow);
@@ -793,35 +731,35 @@ create_project_dbase_info_gui (gchar * lab[])
 			  (GtkAttachOptions) (0), 3, 0);
 	gtk_misc_set_alignment (GTK_MISC (label11), 0, -1);
 
-	label13 = gtk_label_new (_("No of src files:"));
+	label13 = gtk_label_new (_("Source files:"));
 	gtk_widget_show (label13);
 	gtk_table_attach (GTK_TABLE (table1), label13, 3, 4, 4, 5,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (0), 3, 0);
 	gtk_misc_set_alignment (GTK_MISC (label13), 0, -1);
 
-	label15 = gtk_label_new (_("No of help files:"));
+	label15 = gtk_label_new (_("Help files:"));
 	gtk_widget_show (label15);
 	gtk_table_attach (GTK_TABLE (table1), label15, 3, 4, 5, 6,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (0), 3, 0);
 	gtk_misc_set_alignment (GTK_MISC (label15), 0, -1);
 
-	label17 = gtk_label_new (_("No of data files:"));
+	label17 = gtk_label_new (_("Data files:"));
 	gtk_widget_show (label17);
 	gtk_table_attach (GTK_TABLE (table1), label17, 3, 4, 6, 7,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (0), 3, 0);
 	gtk_misc_set_alignment (GTK_MISC (label17), 0, -1);
 
-	label19 = gtk_label_new (_("No of pix files:"));
+	label19 = gtk_label_new (_("Pixmap files:"));
 	gtk_widget_show (label19);
 	gtk_table_attach (GTK_TABLE (table1), label19, 3, 4, 8, 9,
 			  (GtkAttachOptions) (0),
 			  (GtkAttachOptions) (0), 3, 0);
 	gtk_misc_set_alignment (GTK_MISC (label19), 0, -1);
 
-	label21 = gtk_label_new (_("No of doc files:"));
+	label21 = gtk_label_new (_("Doc files:"));
 	gtk_widget_show (label21);
 	gtk_table_attach (GTK_TABLE (table1), label21, 3, 4, 9, 10,
 			  (GtkAttachOptions) (0),
@@ -842,7 +780,7 @@ create_project_dbase_info_gui (gchar * lab[])
 	gtk_misc_set_padding (GTK_MISC (label22), 3, 0);
 	gtk_misc_set_alignment (GTK_MISC (label22), 0, -1);
 
-	label23 = gtk_label_new (_("No of po files:"));
+	label23 = gtk_label_new (_("Po files:"));
 	gtk_widget_show (label23);
 	gtk_table_attach (GTK_TABLE (table1), label23, 3, 4, 10, 11,
 			  (GtkAttachOptions) (0),
@@ -1142,7 +1080,7 @@ create_langsel_dialog (void)
 	gtk_widget_show (table1);
 	gtk_box_pack_start (GTK_BOX (dialog_vbox1), table1, TRUE, TRUE, 0);
 
-	label1 = gtk_label_new (_("Select Regional Language:"));
+	label1 = gtk_label_new (_("Select regional language:"));
 	gtk_widget_ref (label1);
 	gtk_object_set_data_full (GTK_OBJECT (dialog1), "label1", label1,
 				  (GtkDestroyNotify) gtk_widget_unref);
@@ -1182,7 +1120,7 @@ create_langsel_dialog (void)
 		gnome_pixmap_load_file (GNOME_PIXMAP (pixmap1),
 					pixmap1_filename);
 	else
-		g_warning (_("Couldn't find pixmap file: %s"),
+		g_warning (_("Unable to find pixmap file: %s"),
 			   "gnome-globe.png");
 	g_free (pixmap1_filename);
 	gtk_widget_ref (pixmap1);
@@ -1254,7 +1192,7 @@ on_prj_import_confirm_yes (GtkButton * button, gpointer user_data)
 			 */
 			messagebox (GNOME_MESSAGE_BOX_INFO,
 				    _
-				    ("This file has already been added to the project."));
+				    ("This file has already been added to the Project"));
 			g_free (dir);
 			g_free (comp_dir);
 			g_free (filename);
@@ -1287,6 +1225,10 @@ on_prj_import_confirm_yes (GtkButton * button, gpointer user_data)
 				    _("Error while copying the file inside the module."));
 			return;
 		}
+		tm_project_update(app->project_dbase->tm_project, FALSE
+		  , TRUE, TRUE);
+		sv_populate();
+		fv_populate();
 		g_free(fn);
 	}
 	project_dbase_add_file_to_module (p, p->sel_module, filename);
@@ -1337,7 +1279,7 @@ on_add_prjfilesel_ok_clicked (GtkButton * button, gpointer user_data)
 		mesg =
 			g_strdup_printf (_
 					 ("\"%s\"\ndoes not exist in the current module directory."
-					  "\nDo you want to IMPORT (copy) into the module?"),
+					  "\nDo you want to IMPORT (copy) it into the module?"),
 					filename);
 		if (strcmp (dir, comp_dir) == 0)
 			on_prj_import_confirm_yes (NULL, user_data);
