@@ -55,13 +55,6 @@ static GnomeUIInfo signals_menu_uiinfo[] =
     0, 0, NULL
   },
   GNOMEUIINFO_SEPARATOR,
-  {
-    GNOME_APP_UI_ITEM, N_("Dock/Undock"),
-    NULL,
-    on_signals_dock_undock_activate, NULL, NULL,
-    GNOME_APP_PIXMAP_NONE, NULL,
-    0, 0, NULL
-  },
   {
     GNOME_APP_UI_ITEM, N_("Help"),
     NULL,
