@@ -118,7 +118,7 @@ source_create_file_if_not_exist (const gchar * directory,
 		}
 		else
 		{
-			anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+			anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 			ret = FALSE;
 		}
 	}
@@ -165,7 +165,7 @@ source_write_autogen_sh (ProjectDBase * data)
 
 	if (!copy_file (srcbuffer, destbuffer, FALSE))
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), destbuffer);
+		anjuta_system_error (errno, _("Unable to create file: %s."), destbuffer);
 		g_free (destbuffer);
 		g_free (srcbuffer);
 		return FALSE;
@@ -203,7 +203,7 @@ source_write_configure_in (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		g_free (actual_file);
 		return FALSE;
@@ -439,7 +439,7 @@ source_write_configure_in (ProjectDBase * data)
 	fclose (fp);
 
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (filename);
 	g_free (actual_file);
 	g_free (target);
@@ -463,7 +463,7 @@ source_write_toplevel_makefile_am (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		g_free (actual_file);
 		return FALSE;
@@ -548,7 +548,7 @@ source_write_toplevel_makefile_am (ProjectDBase * data)
 		  "\n");
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (actual_file);
 	g_free (target);
 	g_free (filename);
@@ -614,7 +614,7 @@ source_write_macros_files (ProjectDBase * data)
 		{
 			if (!copy_file (srcbuffer, destbuffer, FALSE))
 			{
-				anjuta_system_error (errno, _("Couldn't create file: %s."), destbuffer);
+				anjuta_system_error (errno, _("Unable to create file: %s."), destbuffer);
 				g_free (srcbuffer);
 				g_free (destbuffer);
 				return FALSE;
@@ -654,7 +654,7 @@ source_write_po_files (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		g_free (actual_file);
 		return FALSE;
@@ -669,7 +669,7 @@ source_write_po_files (ProjectDBase * data)
 	source_write_module_file_list (data, fp, FALSE, prefix, MODULE_SOURCE);
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (actual_file);
 	g_free (prefix);
 	g_free (filename);
@@ -682,7 +682,8 @@ source_write_executable_source_files (ProjectDBase * data)
 	FILE *fp;
 	gchar *src_dir, *filename, *actual_file, *target;
 	Project_Type* type;
-
+	gint lang;
+	
 	g_return_val_if_fail (data != NULL, FALSE);
 
 	type = project_dbase_get_project_type(data);
@@ -702,7 +703,7 @@ source_write_executable_source_files (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		free_project_type(type);
 		g_free (actual_file);
@@ -713,11 +714,30 @@ source_write_executable_source_files (ProjectDBase * data)
 	source_write_no_modify_warning (data, fp);
 	/* If the project directory is the source directory, we need to output
 	 * SUBDIRS here. */
+	/* Fixed bug #460321 "Problem with optimization options" by separating 
+	   INCLUDE AND C(XX)FLAGS. Johannes Schmid 3.2.2002 */ 
+	
 	fprintf (fp, "INCLUDES =");
 	fprintf (fp, type->cflags);
-	compiler_options_set_prjcflags_in_file (app->compiler_options, fp);
+	compiler_options_set_prjincl_in_file (app->compiler_options, fp);
 	fprintf (fp, "\n\n");
-
+	
+	lang = project_dbase_get_language(data);
+	if (lang == PROJECT_PROGRAMMING_LANGUAGE_C ||
+		lang == PROJECT_PROGRAMMING_LANGUAGE_C_CPP)
+	{
+		fprintf (fp, "CFLAGS =");
+		compiler_options_set_prjcflags_in_file (app->compiler_options, fp);
+		fprintf (fp, "\n\n");
+	}
+	if (lang == PROJECT_PROGRAMMING_LANGUAGE_CPP ||
+		lang == PROJECT_PROGRAMMING_LANGUAGE_C_CPP)
+	{
+		fprintf (fp, "CXXFLAGS =");
+		compiler_options_set_prjcflags_in_file (app->compiler_options, fp);
+		fprintf (fp, "\n\n");
+	}
+	
 	target =
 		prop_get (data->props, "project.source.target");
 	g_strdelimit (target, "-", '_');
@@ -738,7 +758,7 @@ source_write_executable_source_files (ProjectDBase * data)
 	fclose (fp);
 	
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	
 	g_free (actual_file);
 	g_free (target);
@@ -810,7 +830,7 @@ source_write_include_files (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		g_free (actual_file);
 		return FALSE;
@@ -829,7 +849,7 @@ source_write_include_files (ProjectDBase * data)
 	fprintf (fp, "EXTRA_DIST = $(%s_include_DATA)\n", target);
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (actual_file);
 	g_free (target);
 	g_free (filename);
@@ -862,7 +882,7 @@ source_write_pixmap_files (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		g_free (actual_file);
 		free_project_type(type);
@@ -882,7 +902,7 @@ source_write_pixmap_files (ProjectDBase * data)
 	fprintf (fp, "EXTRA_DIST = $(%s_pixmaps_DATA)\n", target);
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (actual_file);
 	g_free (target);
 	g_free (filename);
@@ -915,7 +935,7 @@ source_write_help_files (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		free_project_type(type);
 		g_free (actual_file);
@@ -935,7 +955,7 @@ source_write_help_files (ProjectDBase * data)
 	fprintf (fp, "EXTRA_DIST = $(%s_help_DATA)\n", target);
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (actual_file);
 	g_free (target);
 	free_project_type(type);
@@ -966,7 +986,7 @@ source_write_doc_files (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		g_free (actual_file);
 		return FALSE;
@@ -984,7 +1004,7 @@ source_write_doc_files (ProjectDBase * data)
 	fprintf (fp, "EXTRA_DIST = $(%s_doc_DATA)\n", target);
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (actual_file);
 	g_free (target);
 	g_free (filename);
@@ -1014,7 +1034,7 @@ source_write_data_files (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		g_free (actual_file);
 		return FALSE;
@@ -1032,7 +1052,7 @@ source_write_data_files (ProjectDBase * data)
 	fprintf (fp, "EXTRA_DIST = $(%s_data_DATA)\n", target);
 	fclose (fp);
 	if (move_file_if_not_same(filename, actual_file) == FALSE)
-		anjuta_system_error (errno, _("Couldn't create file: %s."), actual_file);
+		anjuta_system_error (errno, _("Unable to create file: %s."), actual_file);
 	g_free (actual_file);
 	g_free (target);
 	g_free (filename);
@@ -1059,7 +1079,7 @@ source_write_acconfig_h (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		return FALSE;
 	}
@@ -1091,6 +1111,7 @@ source_write_desktop_entry (ProjectDBase * data)
 	FILE *fp;
 	gchar *filename, *target, *name, *comment, *term, *icon;
 	gint t;
+	gboolean has_icon;
 
 	g_return_val_if_fail (data != NULL, FALSE);
 
@@ -1111,7 +1132,7 @@ source_write_desktop_entry (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		return FALSE;
 	}
@@ -1122,6 +1143,7 @@ source_write_desktop_entry (ProjectDBase * data)
 	if (!comment)
 		comment = g_strdup ("No comment");
 	icon = prop_get (data->props, "project.menu.icon");
+	has_icon = (gboolean) icon;
 	if (!icon)
 		icon = g_strdup (" ");
 	t = prop_get_int (data->props, "project.menu.need.terminal", 1);
@@ -1135,11 +1157,15 @@ source_write_desktop_entry (ProjectDBase * data)
 		"Name=%s\n"
 		"Comment=%s\n"
 		"Exec=%s\n"
-		"Icon=@PACKAGE_PIXMAPS_DIR@/%s\n"
+		"Icon=%s%s\n"
 		"Terminal=%s\n"
 		"MultipleArgs=false\n"
 		"Type=Application\n\n",
-		name, comment, target, icon, term);
+		name, comment, target,
+		icon ? "@PACKAGE_PIXMAPS_DIR@/" : "",
+		icon ? icon : "",
+		term);
+
 	fclose (fp);
 
 	g_free (filename);
@@ -1182,7 +1208,7 @@ source_write_glade_file (ProjectDBase * data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		free_project_type(type);
 		g_free (filename);
 		return FALSE;
@@ -1265,7 +1291,7 @@ source_write_glade_file (ProjectDBase * data)
 	free_project_type(type);
 	fflush( fp );
 	if( ferror( fp ) )
-	{		anjuta_system_error (errno, _("Error writing to : %s."), filename);
+	{		anjuta_system_error (errno, _("Error writing to: %s."), filename);
 		bOK = FALSE ;
 	}
 	fclose (fp);
@@ -1314,7 +1340,7 @@ source_write_generic_main_c (ProjectDBase *data)
 	fp = fopen (filename, "w");
 	if (fp == NULL)
 	{
-		anjuta_system_error (errno, _("Couldn't create file: %s."), filename);
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
 		g_free (filename);
 		return FALSE;
 	}
@@ -1346,6 +1372,100 @@ source_write_generic_main_c (ProjectDBase *data)
 	return TRUE;
 }
 
+gboolean
+source_write_libglade_main_c (ProjectDBase *data)
+{
+	FILE *fp;
+	gchar *filename, *src_dir, *gladefile, *target;
+	gint lang;
+
+	target = prop_get (data->props, "project.source.target");
+	g_strdelimit (target, "-", '_');
+	
+	gladefile = g_strconcat (data->top_proj_dir, "/", target, ".glade", NULL);
+
+	g_return_val_if_fail (data != NULL, FALSE);
+	g_return_val_if_fail (data->project_is_open, FALSE);
+
+	src_dir = project_dbase_get_module_dir (data, MODULE_SOURCE);
+	if (!src_dir)
+		return FALSE;
+	force_create_dir (src_dir);
+
+	lang = project_dbase_get_language (data);
+	if (lang == PROJECT_PROGRAMMING_LANGUAGE_C)
+	{
+		filename = g_strconcat (src_dir, "/main.c", NULL);
+	}
+	else
+	{
+		filename = g_strconcat (src_dir, "/main.cc", NULL);
+	}
+	g_free (src_dir);
+
+	/* FIXME: If main.c exists, just leave it, for now. */
+	if (file_is_regular (filename))
+	{
+		g_free (filename);
+		return TRUE;
+	}
+
+	fp = fopen (filename, "w");
+	if (fp == NULL)
+	{
+		anjuta_system_error (errno, _("Unable to create file: %s."), filename);
+		g_free (filename);
+		return FALSE;
+	}
+	fprintf(fp,
+		"/* Created by Anjuta version %s */\n", VERSION);
+	fprintf(fp,
+		"/*\tThis file will not be overwritten */\n\n");
+	if (lang == PROJECT_PROGRAMMING_LANGUAGE_C)
+	{
+
+		fprintf(fp,
+			"#ifdef HAVE_CONFIG_H\n"
+			"#  include <config.h>\n"
+			"#endif\n\n"
+			"#include <gnome.h>\n"
+			"#include <glade/glade.h>\n\n"
+			"int main (int argc, char *argv[])\n"
+			"{\n"
+			"	GtkWidget *window1;\n"
+			"	GladeXML *xml;\n\n"
+			"	#ifdef ENABLE_NLS\n"
+			"		bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);\n"
+			"		textdomain (PACKAGE);\n"
+			"	#endif\n\n"
+			"	gnome_init (PACKAGE, VERSION, argc, argv);\n"
+			"	glade_gnome_init ();\n"
+			"	/*\n"
+			"	 * The .glade filename should be on the next line.\n"
+			"	 */\n"
+			"	xml = glade_xml_new(\"%s\", NULL);\n\n"
+			"	/* This is important */\n"
+			"	glade_xml_signal_autoconnect(xml);\n"
+			"	window1 = glade_xml_get_widget(xml, \"window1\");\n"
+			"	gtk_widget_show (window1);\n\n"
+			"	gtk_main ();\n"
+			"	return 0;\n"
+			"}\n", gladefile);
+	}
+	else
+	{
+		fprintf(fp,
+			"#include <iostream.h>\n"
+			"int main()\n\n"
+			"{\n"
+			"\tcout << \"Hello world\\n\";\n"
+			"\treturn (0);\n"
+			"}\n\n");
+	}
+	fclose (fp);
+	return TRUE;
+}
+
 gboolean
 source_write_build_files (ProjectDBase * data)
 {
@@ -1355,6 +1475,11 @@ source_write_build_files (ProjectDBase * data)
 	g_return_val_if_fail (data != NULL, FALSE);
 	g_return_val_if_fail (data->project_is_open, FALSE);
 
+	/* project is blocked, don't bother to disturb the
+	project */
+	if (data->project_config->blocked)
+		return TRUE;
+	
 	ret = source_write_autogen_sh (data);
 	if (!ret) return FALSE;
 	ret = source_write_acconfig_h (data);
@@ -1372,6 +1497,7 @@ source_write_build_files (ProjectDBase * data)
 				break;
 			case PROJECT_TYPE_GNOME:
 			case PROJECT_TYPE_BONOBO:
+			case PROJECT_TYPE_LIBGLADE:
 			case PROJECT_TYPE_GNOMEMM:
 				ret = source_write_desktop_entry (data);
 				if (!ret) return FALSE;
@@ -1381,7 +1507,7 @@ source_write_build_files (ProjectDBase * data)
 				if (!ret) return FALSE;
 				break;
 			default:
-				anjuta_error (_("Project type does not support glade."));
+				anjuta_error (_("Project type does not support Glade."));
 				free_project_type(type);
 				return FALSE;
 		}
