@@ -37,8 +37,8 @@
 #include "text_editor_cbs.h"
 #include "text_editor_menu.h"
 #include "utilities.h"
-#include "syntax.h"
 #include "launcher.h"
+#include "pixmaps.h"
 
 #define GTK
 #undef PLAT_GTK
@@ -52,6 +52,9 @@
 #include "aneditor.h"
 #include "controls.h"
 
+/* Debug flag */
+// #define DEBUG
+
 /* Marker 0 is defined for bookmarks */
 #define TEXT_EDITOR_LINEMARKER	2
 
@@ -60,7 +63,7 @@
 /* marker fore and back colors */
 static glong marker_prop[] = 
 {
-	SC_MARK_ROUNDRECT, 0x00007f, 0xffff80,			/* Book mark */
+	SC_MARK_ROUNDRECT, 0x00007f, 0xffff80,			/* Bookmark */
 	SC_MARK_CIRCLE, 0x00007f, 0xff80ff,		/* Breakpoint mark */
 	SC_MARK_SHORTARROW, 0x00007f, 0x00ffff,	/* Line mark */
 	MARKER_PROP_END,	/* end */
@@ -71,7 +74,7 @@ static void check_tm_file(TextEditor *te)
 	if (NULL == te->tm_file)
 	{
 		te->tm_file = tm_workspace_find_object(
-		  TM_WORK_OBJECT(app->tm_workspace), te->full_filename);
+		  TM_WORK_OBJECT(app->tm_workspace), te->full_filename, FALSE);
 		if (NULL == te->tm_file)
 		{
 			te->tm_file = tm_source_file_new(te->full_filename, TRUE);
@@ -108,13 +111,14 @@ text_editor_new (gchar * filename, TextEditor * parent, Preferences * eo)
 	TextEditor *te;
 	static guint new_file_count;
 
-	te = (TextEditor *) g_malloc (sizeof (TextEditor));
+	te = (TextEditor *) g_malloc0(sizeof (TextEditor));
 	if (te == NULL)
 		return NULL;
 	te->size	= sizeof(TextEditor);
 	te->filename = g_strdup_printf ("Newfile#%d", ++new_file_count);
 	te->full_filename = NULL;
 	te->tm_file = NULL;
+	
 	te->modified_time = time (NULL);
 	te->preferences = eo;
 	te->force_hilite = TE_LEXER_AUTOMATIC;
@@ -144,7 +148,7 @@ text_editor_new (gchar * filename, TextEditor * parent, Preferences * eo)
 		te->geom.height = 400;
 	}
 
-	/* Editor is created here and not in create_text_editot_gui() */
+	/* Editor is created here and not in create_text_editor_gui() */
 	te->editor_id = aneditor_new (prop_get_pointer (te->props_base));
 	/*
 	aneditor_command (te->editor_id, ANE_SETACCELGROUP,
@@ -170,7 +174,7 @@ text_editor_new (gchar * filename, TextEditor * parent, Preferences * eo)
 		if (te->full_filename)
 			g_free (te->full_filename);
 		te->filename = g_strdup (extract_filename (filename));
-		te->full_filename = g_strdup (filename);
+		te->full_filename = resolved_file_name(filename);
 		buff = g_strdup_printf ("Anjuta: %s", te->full_filename);
 		gtk_window_set_title (GTK_WINDOW (te->widgets.window), buff);
 		g_free (buff);
@@ -247,6 +251,10 @@ text_editor_destroy (TextEditor * te)
 
 		if (te->widgets.window)
 			gtk_widget_destroy (te->widgets.window);
+		
+		if (te->buttons.close)
+			text_editor_tab_widget_destroy(te);
+		
 		if (te->filename)
 			g_free (te->filename);
 		if (te->full_filename)
@@ -278,6 +286,7 @@ text_editor_undock (TextEditor * te, GtkWidget * container)
 			   te->widgets.client);
 	gtk_widget_show (te->widgets.client);
 	gtk_widget_show (te->widgets.window);
+	text_editor_tab_widget_destroy(te);
 }
 
 void
@@ -376,7 +385,7 @@ text_editor_get_current_lineno (TextEditor * te)
 }
 
 gboolean
-text_editor_goto_point (TextEditor * te, guint point)
+text_editor_goto_point (TextEditor * te, glong point)
 {
 	g_return_val_if_fail (te != NULL, FALSE);
 	g_return_val_if_fail(IS_SCINTILLA (te->widgets.editor) == TRUE, FALSE);
@@ -387,7 +396,7 @@ text_editor_goto_point (TextEditor * te, guint point)
 }
 
 gboolean
-text_editor_goto_line (TextEditor * te, guint line, gboolean mark)
+text_editor_goto_line (TextEditor * te, glong line, gboolean mark)
 {
 	gint selpos;
 	g_return_val_if_fail (te != NULL, FALSE);
@@ -437,9 +446,9 @@ text_editor_set_marker (TextEditor *te, glong line, gint marker)
 	g_return_val_if_fail (te != NULL, -1);
 	g_return_val_if_fail(IS_SCINTILLA (te->widgets.editor) == TRUE, -1);
 
-	/* Scintilla interpretes line+1 rather than line */
+	/* Scintilla interprets line+1 rather than line */
 	/* A bug perhaps */
-	/* So counter balance it with line-1 */
+	/* So counterbalance it with line-1 */
 	/* Using the macros linenum_* */
 	return scintilla_send_message (SCINTILLA (te->widgets.editor), SCI_MARKERADD,
 		linenum_text_editor_to_scintilla (line), marker);
@@ -465,7 +474,7 @@ text_editor_set_line_marker (TextEditor *te, glong line)
  * instead of <LF>.
  * The DOS_EOL_CHECK-checkbox will be set on loading a DOS-file.
  *
- *  23.Sep.2001  Denis Boehme<boehme at syncio dot de>
+ *  23.Sep.2001  Denis Boehme <boehme at syncio dot de>
  */
 
 /*
@@ -508,7 +517,7 @@ static struct {
  *
  */
 static size_t
-filter_chars( gchar *data_, size_t size )
+filter_chars_in_dos_mode(gchar *data_, size_t size )
 {
 	int k;
 	size_t i;
@@ -536,10 +545,9 @@ filter_chars( gchar *data_, size_t size )
  * save buffer. filter chars and set dos-like CR/LF if dos_text is set.
  */
 static size_t
-save_filtered( FILE * f, gchar *data_, size_t size, gint dos_text )
+save_filtered_in_dos_mode(FILE * f, gchar *data_, size_t size)
 {
 	size_t i, j;
-	gchar dos_eol_data[] = { 0x0d, 0x0a };
 	unsigned char *data;
 	unsigned char *tr_map;
 	int k;
@@ -554,39 +562,19 @@ save_filtered( FILE * f, gchar *data_, size_t size, gint dos_text )
 	i = 0; j = 0;
 	while ( i < size )
 	{
-		if ( data[i] == 0x0d )
-		{
-			/* ignore CR */
-			i++;
-			continue;
-		}
-		if ( data[i]==0x0a )
-		{
-			/* create CR+LF or LF */
-			if ( dos_text )
-				j += fwrite( dos_eol_data, 1, 2, f );
+		if (data[i]>=128) {
+			/* convert dos-text */
+			if ( tr_map[data[i]] != 0 )
+				j += fwrite( &tr_map[data[i]], 1, 1, f );
 			else
+				/* char not found, skip transform */
 				j += fwrite( &data[i], 1, 1, f );
 			i++;
-		}
-		else if ( data[i]>=128 && dos_text )
-		  {
-		    /* convert dos-text */
-		    if ( tr_map[data[i]] != 0 )
-		      j += fwrite( &tr_map[data[i]], 1, 1, f );
-		    else
-		      /* char not found, skip transform */
-		      j += fwrite( &data[i], 1, 1, f );
-
-		    i++;
-		  }
-		else
-		  {
+		} else {
 			/* write normal chars */
 			j += fwrite( &data[i], 1, 1, f );
 			i++;
-		  }
-		
+		}
 	}
 
 	if ( tr_map )
@@ -596,24 +584,58 @@ save_filtered( FILE * f, gchar *data_, size_t size, gint dos_text )
 	return size;
 }
 
-/*
- * Check end-of-line type. Returns true, if it is DOS <cr><lf> type. 
- */
-static gboolean
-is_dos_eol ( const gchar * buffer, gint size )
+static gint
+determine_editor_mode(gchar* buffer, glong size)
 {
-	int i;
-	int cr = 0;
+	gint i;
+	guint cr, lf, crlf, max_mode;
+	gint mode;
+	
+	cr = lf = crlf = 0;
 	
 	for ( i = 0; i < size ; i++ )
 	{
-		if ( buffer[i] == 0x0a ) // LF
-			break;
-		if ( buffer[i] == 0x0d ) // CR
-			cr = TRUE;
+		if ( buffer[i] == 0x0a ){
+			// LF
+			// mode = SC_EOF_LF;
+			lf++;
+		} else if ( buffer[i] == 0x0d ) {
+			if (i >= (size-1)) {
+				// Last char
+				// CR
+				// mode = SC_EOL_CR;
+				cr++;
+			} else {
+				if (buffer[i+1] != 0x0a) {
+					// CR
+					// mode = SC_EOL_CR;
+					cr++;
+				} else {
+					// CRLF
+					// mode = SC_EOL_CRLF;
+					crlf++;
+				}
+				i++;
+			}
+		}
 	}
-	
-	return cr;
+
+	/* Vote for the maximum */
+	mode = SC_EOL_LF;
+	max_mode = lf;
+	if (crlf > max_mode) {
+		mode = SC_EOL_CRLF;
+		max_mode = crlf;
+	}
+	if (cr > max_mode) {
+		mode = SC_EOL_CR;
+		max_mode = cr;
+	}
+#ifdef DEBUG
+	g_message("EOL chars: LR = %d, CR = %d, CRLF = %d", lf, cr, crlf);
+	g_message("Autodetected Editor mode [%d]", mode);
+#endif
+	return mode;
 }
 
 static gboolean
@@ -621,14 +643,13 @@ load_from_file (TextEditor * te, gchar * fn)
 {
 	FILE *fp;
 	gchar *buffer;
-	gint nchars;
-	gint dos_text;
+	gint nchars, dos_filter, editor_mode;
 	struct stat st;
 	size_t size;
 
 	if (stat (fn, &st) != 0)
 	{
-		g_warning ("Could not stat the file");
+		g_warning ("Could not stat the file %s", fn);
 		return FALSE;
 	}
 	size = st.st_size;
@@ -638,7 +659,7 @@ load_from_file (TextEditor * te, gchar * fn)
 	if (buffer == NULL && size != 0)
 	{
 		/* This is funny in unix, but never hurts */
-		g_warning ("This file is too big. Unable to allocate memory");
+		g_warning ("This file is too big. Unable to allocate memory.");
 		return FALSE;
 	}
 	fp = fopen (fn, "rb");
@@ -649,18 +670,27 @@ load_from_file (TextEditor * te, gchar * fn)
 	}
 	/* Crude way of loading, but faster */
 	nchars = fread (buffer, 1, size, fp);
-	/* check EOL type */
-	dos_text = is_dos_eol(buffer,nchars);
-	preferences_set_int ( te->preferences, DOS_EOL_CHECK, 
-			      dos_text );
-	preferences_sync( te->preferences );
-	if ( dos_text )
-	  nchars = filter_chars( buffer, nchars );
-       
-	if (size != nchars)
-		g_warning ("File size and loaded size not matching");
+	
+	if (size != nchars) g_warning ("File size and loaded size not matching");
+	dos_filter = preferences_get_int ( te->preferences, DOS_EOL_CHECK);
+	
+	/* Set editor mode */
+	editor_mode =  determine_editor_mode(buffer, nchars);
+	scintilla_send_message (SCINTILLA (te->widgets.editor),
+			SCI_SETEOLMODE, editor_mode, 0);
+#ifdef DEBUG
+	g_message("Loaded in editor mode [%d]", editor_mode);
+#endif
+
+	if (dos_filter && editor_mode == SC_EOL_CRLF){
+#ifdef DEBUG
+		g_message("Filtering Extrageneous DOS characters in dos mode [Dos => Unix]");
+#endif
+		nchars = filter_chars_in_dos_mode( buffer, nchars );
+	}
 	scintilla_send_message (SCINTILLA (te->widgets.editor), SCI_ADDTEXT,
 				nchars, (long) buffer);
+	
 	g_free (buffer);
 	if (ferror (fp))
 	{
@@ -671,57 +701,6 @@ load_from_file (TextEditor * te, gchar * fn)
 	return TRUE;
 }
 
-#if 0
-
-static gint
-strip_trailing_spaces (char *data, int ds, gboolean lastBlock)
-{
-	gint lastRead;
-	gchar *w;
-	gint i;
-
-	w = data;
-	lastRead = 0;
-
-	for (i = 0; i < ds; i++)
-	{
-		gchar ch;
-
-		ch = data[i];
-		if ((ch == ' ') || (ch == '\t'))
-		{
-			/* Swallow those spaces */
-		}
-		else if ((ch == '\r') || (ch == '\n'))
-		{
-			*w++ = ch;
-			lastRead = i + 1;
-		}
-		else
-		{
-			while (lastRead < i)
-			{
-				*w++ = data[lastRead++];
-			}
-			*w++ = ch;
-			lastRead = i + 1;
-		}
-	}
-	/* If a non-final block, then preserve whitespace
-	 * at end of block as it may be significant.
-	 */
-	if (!lastBlock)
-	{
-		while (lastRead < ds)
-		{
-			*w++ = data[lastRead++];
-		}
-	}
-	return w - data;
-}
-
-#endif
-
 static gboolean
 save_to_file (TextEditor * te, gchar * fn)
 {
@@ -734,24 +713,32 @@ save_to_file (TextEditor * te, gchar * fn)
 	if (!fp)
 		return FALSE;
 	strip = prop_get_int (te->props_base, "strip.trailing.spaces", 1);
-	nchars =
-		scintilla_send_message (SCINTILLA (te->widgets.editor),
+	nchars = scintilla_send_message (SCINTILLA (te->widgets.editor),
 					SCI_GETLENGTH, 0, 0);
-	data =
-		(gchar *) aneditor_command (te->editor_id, ANE_GETTEXTRANGE,
+	data =	(gchar *) aneditor_command (te->editor_id, ANE_GETTEXTRANGE,
 					    0, nchars);
 	if (data)
 	{
 		size_t size;
-		gint dos_text;
+		gint dos_filter, editor_mode;
 		
 		size = strlen (data);
-		dos_text = preferences_get_int( te->preferences, DOS_EOL_CHECK );
+		dos_filter = preferences_get_int( te->preferences, DOS_EOL_CHECK );
+		editor_mode =  scintilla_send_message (SCINTILLA (te->widgets.editor),
+					SCI_GETEOLMODE, 0, 0);
+#ifdef DEBUG
+		g_message("Saving in editor mode [%d]", editor_mode);
+#endif
 		if (size != nchars)
-			g_warning
-				("Text length and no. of bytes saved is not equal");
-//		size = fwrite (data, size, 1, fp);
-		size = save_filtered( fp, data, size, dos_text );
+			g_warning("Text length and number of bytes saved is not equal");
+		if (editor_mode == SC_EOL_CRLF && dos_filter) {
+#ifdef DEBUG
+			g_message("Filtering Extrageneous DOS characters in dos mode [Unix => Dos]");
+#endif
+			size = save_filtered_in_dos_mode( fp, data, size);
+		} else {
+			size = fwrite (data, size, 1, fp);
+		}
 		g_free (data);
 	}
 	if (ferror (fp))
@@ -766,13 +753,11 @@ save_to_file (TextEditor * te, gchar * fn)
 gboolean
 text_editor_load_file (TextEditor * te)
 {
-	gint tags_update;
-
 	if (te == NULL || te->filename == NULL)
 		return FALSE;
 	if (IS_SCINTILLA (te->widgets.editor) == FALSE)
 		return FALSE;
-	anjuta_status (_("Loading File ..."));
+	anjuta_status (_("Loading file ..."));
 	text_editor_freeze (te);
 	anjuta_set_busy ();
 	te->modified_time = time (NULL);
@@ -785,16 +770,6 @@ text_editor_load_file (TextEditor * te)
 	}
 	scintilla_send_message (SCINTILLA (te->widgets.editor), SCI_GOTOPOS,
 				0, 0);
-	tags_update = preferences_get_int (te->preferences, AUTOMATIC_TAGS_UPDATE);
-	if (app->project_dbase->project_is_open == FALSE && tags_update)
-	{
-		tags_manager_update (app->tags_manager, te->full_filename);
-	}
-	else if (project_dbase_is_file_in_module
-		    (app->project_dbase, MODULE_SOURCE, te->full_filename) && tags_update)
-	{
-		tags_manager_update (app->tags_manager, te->full_filename);
-	}
 	check_tm_file(te);
 	anjuta_set_active ();
 	text_editor_thaw (te);
@@ -807,7 +782,7 @@ text_editor_load_file (TextEditor * te)
 	{
 		aneditor_command (te->editor_id, ANE_CLOSE_FOLDALL, 0, 0);
 	}
-	anjuta_status (_("File Loaded Successfully"));
+	anjuta_status (_("File loaded successfully"));
 	return TRUE;
 }
 
@@ -822,12 +797,12 @@ text_editor_save_file (TextEditor * te)
 		return FALSE;
 	anjuta_set_busy ();
 	text_editor_freeze (te);
-	anjuta_status (_("Saving File ..."));
+	anjuta_status (_("Saving file ..."));
 	if (save_to_file (te, te->full_filename) == FALSE)
 	{
 		text_editor_thaw (te);
 		anjuta_set_active ();
-		anjuta_system_error (errno, _("Couldn't save file: %s."), te->full_filename);
+		anjuta_system_error (errno, _("Could not save file: %s."), te->full_filename);
 		return FALSE;
 	}
 	else
@@ -836,25 +811,24 @@ text_editor_save_file (TextEditor * te)
 		tags_update =
 			preferences_get_int (te->preferences,
 					     AUTOMATIC_TAGS_UPDATE);
-		if (app->project_dbase->project_is_open == FALSE
-		    && tags_update)
-			tags_manager_update (app->tags_manager,
-					     te->full_filename);
-		else
-			if (project_dbase_is_file_in_module
-			    (app->project_dbase, MODULE_SOURCE, te->full_filename)
-			    && tags_update)
-			tags_manager_update (app->tags_manager,
-					     te->full_filename);
-		check_tm_file(te);
-		if (te->tm_file)
-			tm_source_file_update(TM_WORK_OBJECT(te->tm_file), FALSE, FALSE, TRUE);
+		if (tags_update)
+		{
+			if ((app->project_dbase->project_is_open == FALSE)
+			  || (project_dbase_is_file_in_module
+			    (app->project_dbase, MODULE_SOURCE, te->full_filename)))
+			{
+				check_tm_file(te);
+				if (te->tm_file)
+					tm_source_file_update(TM_WORK_OBJECT(te->tm_file)
+					  , FALSE, FALSE, TRUE);
+			}
+		}
 		/* we need to update UI with the call to scintilla */
 		text_editor_thaw (te);
 		scintilla_send_message (SCINTILLA (te->widgets.editor),
 					SCI_SETSAVEPOINT, 0, 0);
 		anjuta_set_active ();
-		anjuta_status (_("File Saved successfully"));
+		anjuta_status (_("File saved successfully"));
 		return TRUE;
 	}
 }
@@ -949,8 +923,8 @@ text_editor_check_disk_status (TextEditor * te, const gboolean bForce )
 		{
 			buff =
 				g_strdup_printf (_
-						 ("WARNING: The file \"%s\" in the disk is more recent "
-						  "than\nthe current buffer.\nDo you want to reload it."),
+						 ("The file \"%s\" on the disk is more recent "
+						  "than\nthe current buffer.\nDo you want to reload it?"),
 				te->filename);
 			messagebox2 (GNOME_MESSAGE_BOX_WARNING, buff,
 					 GNOME_STOCK_BUTTON_YES,
@@ -1065,13 +1039,13 @@ text_editor_autoformat (TextEditor * te)
 		return;
 	if (preferences_get_int (app->preferences, AUTOFORMAT_DISABLE))
 	{
-		anjuta_warning (_("Autoformat is disablde. If you want, enable in Preferences."));
+		anjuta_warning (_("Auto format is currently disabled. Change the setting in Preferences."));
 		return;
 	}
 	if (te == NULL)
 		return;
 
-	anjuta_status (_("Auto formating ..."));
+	anjuta_status (_("Auto formatting ..."));
 	anjuta_set_busy ();
 	text_editor_freeze (te);
 	file = get_a_tmp_file ();
@@ -1081,7 +1055,7 @@ text_editor_autoformat (TextEditor * te)
 		g_free (file);
 		text_editor_thaw (te);
 		anjuta_set_active ();
-		anjuta_warning (_("Error in auto formating ..."));
+		anjuta_warning (_("Error in auto formatting ..."));
 		return;
 	}
 
@@ -1108,13 +1082,13 @@ text_editor_autoformat (TextEditor * te)
 				SCI_BEGINUNDOACTION, 0, 0);
 	if (load_from_file (te, file) == FALSE)
 	{
-		anjuta_warning (_("Error in auto formating ..."));
+		anjuta_warning (_("Error in auto formatting ..."));
 	}
 	else
 	{
 		text_editor_set_hilite_type (te);
 		gtk_widget_queue_draw (te->widgets.editor);
-		anjuta_status (_("Auto formating completed"));
+		anjuta_status (_("Auto formatting completed"));
 	}
 	remove (file);
 	g_free (file);
@@ -1128,7 +1102,7 @@ text_editor_autoformat (TextEditor * te)
 }
 
 gboolean
-text_editor_is_marker_set (TextEditor* te, gint line, gint marker)
+text_editor_is_marker_set (TextEditor* te, glong line, gint marker)
 {
 	gint state;
 
@@ -1142,7 +1116,7 @@ text_editor_is_marker_set (TextEditor* te, gint line, gint marker)
 }
 
 void
-text_editor_delete_marker (TextEditor* te, gint line, gint marker)
+text_editor_delete_marker (TextEditor* te, glong line, gint marker)
 {
 	g_return_if_fail (te != NULL);
 	g_return_if_fail (line >= 0);
@@ -1164,7 +1138,7 @@ text_editor_line_from_handle (TextEditor* te, gint marker_handle)
 	return linenum_scintilla_to_text_editor (line);
 }
 
-gint text_editor_get_bookmark_line( TextEditor* te, const gint nLineStart )
+gint text_editor_get_bookmark_line( TextEditor* te, const glong nLineStart )
 {
 	return aneditor_command (te->editor_id, ANE_GETBOOKMARK_POS, nLineStart, 0 );
 }
@@ -1185,3 +1159,83 @@ gint text_editor_get_num_bookmarks(TextEditor* te)
 	//printf( "out Line %d\n", nLineNo );
 	return nMarkers ;
 }
+
+GtkWidget* text_editor_tab_widget_new(TextEditor* te)
+{
+	GtkWidget *button15;
+	GtkWidget *close_pixmap;
+	GtkWidget *tmp_toolbar_icon;
+	GtkWidget *label;
+	GtkWidget *box;
+	GtkRequisition r;
+	GtkStyle *style;
+	GdkColor color;
+	
+	g_return_val_if_fail(te != NULL, NULL);
+	
+	if (te->buttons.close)
+		text_editor_tab_widget_destroy(te);
+	
+	tmp_toolbar_icon = anjuta_res_get_pixmap_widget (te->widgets.window,
+		ANJUTA_PIXMAP_CLOSE_FILE_SMALL, FALSE);
+	gtk_widget_show(tmp_toolbar_icon);
+	
+	button15 = gtk_button_new();
+	gtk_container_add(GTK_CONTAINER(button15), tmp_toolbar_icon);
+	gtk_button_set_relief(GTK_BUTTON(button15), GTK_RELIEF_NONE);
+	
+	close_pixmap = anjuta_res_get_pixmap_widget (te->widgets.window,
+		ANJUTA_PIXMAP_CLOSE_FILE_SMALL, FALSE);
+	gtk_widget_size_request (button15, &r);
+	gtk_widget_set_usize (close_pixmap, r.width, r.height);
+	gtk_widget_set_sensitive(close_pixmap, FALSE);
+	
+	label = gtk_label_new (te->filename);
+	gtk_widget_show (label);
+	
+	color.red = 0;
+	color.green = 0;
+	color.blue = 0;
+	
+	style = gtk_widget_get_style(button15);
+	style->fg[GTK_STATE_NORMAL] = color;
+	gtk_widget_set_style(button15, style);
+	gtk_widget_show(button15);
+	
+	
+	box = gtk_hbox_new(FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(box), label, TRUE, TRUE, 0);
+    gtk_box_pack_start(GTK_BOX(box), button15, FALSE, FALSE, 0);
+    gtk_box_pack_start(GTK_BOX(box), close_pixmap, FALSE, FALSE, 0);
+	
+	gtk_widget_show(box);
+
+	gtk_signal_connect (GTK_OBJECT (button15), "clicked",
+				GTK_SIGNAL_FUNC(on_text_editor_notebook_close_page),
+				te);
+
+	te->widgets.close_pixmap = close_pixmap;
+	te->buttons.close = button15;
+	te->widgets.tab_label = label;
+	
+	gtk_widget_ref (te->buttons.close);
+	gtk_widget_ref (te->widgets.close_pixmap);
+	gtk_widget_ref (te->widgets.tab_label);
+	
+	return box;
+}
+
+void
+text_editor_tab_widget_destroy(TextEditor* te)
+{
+	g_return_if_fail(te != NULL);
+	g_return_if_fail(te->buttons.close != NULL);
+
+	gtk_widget_unref (te->buttons.close);
+	gtk_widget_unref (te->widgets.close_pixmap);
+	gtk_widget_unref (te->widgets.tab_label);
+	
+	te->widgets.close_pixmap = NULL;
+	te->buttons.close = NULL;
+	te->widgets.tab_label = NULL;
+}
