@@ -62,6 +62,7 @@ struct _TextEditorButtons
 	GtkWidget *build;
 	GtkWidget *print;
 	GtkWidget *attach;
+	GtkWidget *close;
 };
 
 struct _TextEditorGui
@@ -72,6 +73,7 @@ struct _TextEditorGui
 	GtkWidget *line_label;
 	GtkWidget *editor;
 	GtkWidget *tab_label;
+	GtkWidget *close_pixmap;
 };
 
 struct _TextEditor
@@ -148,8 +150,8 @@ guint text_editor_get_total_lines (TextEditor * te);
 guint text_editor_get_current_lineno (TextEditor * te);
 gchar* text_editor_get_selection (TextEditor * te);
 
-gboolean text_editor_goto_point (TextEditor * te, guint num);
-gboolean text_editor_goto_line (TextEditor * te, guint num, gboolean mark);
+gboolean text_editor_goto_point (TextEditor * te, glong num);
+gboolean text_editor_goto_line (TextEditor * te, glong num, gboolean mark);
 gint text_editor_goto_block_start (TextEditor* te);
 gint text_editor_goto_block_end (TextEditor* te);
 
@@ -175,12 +177,14 @@ gboolean text_editor_recover_yourself (TextEditor * te, FILE * stream);
 gboolean text_editor_check_disk_status (TextEditor * te, const gboolean bForce );
 
 void text_editor_autoformat (TextEditor * te);
-gboolean text_editor_is_marker_set (TextEditor* te, gint line, gint marker);
-void text_editor_delete_marker (TextEditor* te, gint line, gint marker);
+gboolean text_editor_is_marker_set (TextEditor* te, glong line, gint marker);
+void text_editor_delete_marker (TextEditor* te, glong line, gint marker);
 gint text_editor_line_from_handle (TextEditor* te, gint marker_handle);
-gint text_editor_get_bookmark_line( TextEditor* te, const gint nLineStart );
+gint text_editor_get_bookmark_line( TextEditor* te, const glong nLineStart );
 gint text_editor_get_num_bookmarks(TextEditor* te);
 
+GtkWidget* text_editor_tab_widget_new(TextEditor* te);
+void text_editor_tab_widget_destroy(TextEditor* te);
 
 #define linenum_text_editor_to_scintilla(x) (x-1)
 
