@@ -68,6 +68,44 @@ on_tem_toggle_guides_activate (GtkWidget* menuitem, gpointer data)
 }
 
 GnomeUIInfo text_editor_menu_goto_submenu_uiinfo[] = {
+	{
+	 GNOME_APP_UI_ITEM, N_("Back"),
+	 NULL,
+	 on_go_back_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+ 	 0, 0, NULL}
+	 ,
+	{
+	 GNOME_APP_UI_ITEM, N_("Forward"),
+	 NULL,
+	 on_go_forward_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+ 	 0, 0, NULL}
+	 ,
+	{
+	 GNOME_APP_UI_ITEM, N_("History"),
+	 NULL,
+	 on_history_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+ 	 0, 0, NULL}
+	 ,
+	 GNOMEUIINFO_SEPARATOR
+	 ,
+	{
+	 GNOME_APP_UI_ITEM, N_("Tag Definition"),
+	 NULL,
+	 on_goto_tag_definition_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+ 	 0, 0, NULL}
+	 ,
+	{
+	 GNOME_APP_UI_ITEM, N_("Tag Declaration"),
+	 NULL,
+	 on_goto_tag_declaration_activate, NULL, NULL,
+	 GNOME_APP_PIXMAP_NONE, NULL,
+ 	 0, 0, NULL}
+	 ,
+	GNOMEUIINFO_SEPARATOR,
 	{
 	 GNOME_APP_UI_ITEM, N_("Prev mesg"),
 	 NULL,
@@ -152,7 +190,7 @@ GnomeUIInfo text_editor_menu_debug_submenu_uiinfo[] = {
 
 GnomeUIInfo text_editor_menu_options_submenu_uiinfo[] = {
 	{
-	 GNOME_APP_UI_ITEM, N_("Toggle Linenums"),
+	 GNOME_APP_UI_ITEM, N_("Toggle Line numbers"),
 	 NULL,
 	 on_tem_toggle_linenum_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
@@ -199,6 +237,7 @@ GnomeUIInfo text_editor_menu_options_submenu_uiinfo[] = {
 
 GnomeUIInfo text_editor_menu_uiinfo[] = {
 	{
+	 /* 0 */
 	 GNOME_APP_UI_ITEM, N_("Cut"),
 	 NULL,
 	 on_cut1_activate, NULL, NULL,
@@ -206,6 +245,7 @@ GnomeUIInfo text_editor_menu_uiinfo[] = {
 	 0, 0, NULL}
 	,
 	{
+	 /* 1 */
 	 GNOME_APP_UI_ITEM, N_("Copy"),
 	 NULL,
 	 on_copy1_activate, NULL, NULL,
@@ -213,22 +253,27 @@ GnomeUIInfo text_editor_menu_uiinfo[] = {
 	 0, 0, NULL}
 	,
 	{
+	 /* 2 */
 	 GNOME_APP_UI_ITEM, N_("Paste"),
 	 NULL,
 	 on_paste1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 GDK_v, GDK_CONTROL_MASK, NULL}
 	,
+	/* 3 */
 	GNOMEUIINFO_SEPARATOR,
 	{
+	 /* 4 */
 	 GNOME_APP_UI_ITEM, N_("Context Help"),
 	 NULL,
 	 on_context_help_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
  	 0, 0, NULL}
 	 ,
+	/* 5 */
 	GNOMEUIINFO_SEPARATOR,
 	{
+	 /* 6 */
 	 GNOME_APP_UI_ITEM, N_("Toggle Bookmark"),
 	 NULL,
 	 on_book_toggle1_activate, NULL, NULL,
@@ -236,6 +281,7 @@ GnomeUIInfo text_editor_menu_uiinfo[] = {
 	 0, 0, NULL}
 	,
 	{
+	 /* 7 */
 	 GNOME_APP_UI_ITEM, N_("Auto format"),
 	 NULL,
 	 on_indent1_activate, NULL, NULL,
@@ -243,52 +289,62 @@ GnomeUIInfo text_editor_menu_uiinfo[] = {
 	 0, 0, NULL}
 	,
 	{
+	 /* 8 */
 	 GNOME_APP_UI_ITEM, N_("Swap .h/.c"),
 	 NULL,
 	 on_text_editor_menu_swap_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL}
 	,
+	 /* 9 */
 	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_SUBTREE, N_("Goto"),
+	 /* 10 */
+	 GNOME_APP_UI_SUBTREE, N_("Go"),
 	 NULL,
 	 text_editor_menu_goto_submenu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL}
 	,
-	GNOMEUIINFO_SEPARATOR,
 	{
-	 GNOME_APP_UI_ITEM, N_("Function"),
+	 /* 11 */
+	 GNOME_APP_UI_ITEM, N_("Tags"),
 	 NULL,
 	 NULL, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL}
 	,
+	 /* 12 */
 	GNOMEUIINFO_SEPARATOR,
 	{
+	 /* 13 */
 	 GNOME_APP_UI_SUBTREE, N_("Debug"),
 	 NULL,
 	 text_editor_menu_debug_submenu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL}
 	,
+	 /* 14 */
 	GNOMEUIINFO_SEPARATOR,
 	{
+	 /* 15 */
 	 GNOME_APP_UI_SUBTREE, N_("Options"),
 	 NULL,
 	 text_editor_menu_options_submenu_uiinfo, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL}
 	,
+	 /* 16 */
 	GNOMEUIINFO_SEPARATOR,
 	{
+	 /* 17 */
 	 GNOME_APP_UI_ITEM, N_("Close"),
 	 NULL,
 	 on_close_file1_activate, NULL, NULL,
 	 GNOME_APP_PIXMAP_NONE, NULL,
 	 0, 0, NULL}
 	,
+	 /* 18 */
 	GNOMEUIINFO_END
 };
 
@@ -325,10 +381,9 @@ text_editor_menu_destroy (TextEditorMenu * tm)
 void
 text_editor_menu_popup (TextEditorMenu * menu, GdkEventButton * bevent)
 {
-	GList *funcs;
+	const GList *local_tags;
 	GtkWidget *submenu;
 	TextEditor *te;
-	gchar *tmp;
 	gboolean A;
 	
 	g_return_if_fail (menu != NULL);
@@ -339,15 +394,13 @@ text_editor_menu_popup (TextEditorMenu * menu, GdkEventButton * bevent)
 
 	A = debugger_is_active ();
 
-	funcs = tags_manager_get_function_list (app->tags_manager,
-						te->filename);
-	tmp = g_list_nth_data (funcs, 0);
-	if (strlen (tmp) > 0)
+	local_tags = anjuta_get_tag_list(te, tm_tag_max_t);
+	if (local_tags)
 	{
 		submenu =
-			create_submenu (_("Functions "), funcs,
+			create_submenu (N_("Tags"), (GList *) local_tags,
 					GTK_SIGNAL_FUNC
-					(on_text_editor_menu_function_activate));
+					(on_text_editor_menu_tags_activate));
 		gtk_menu_item_set_submenu (GTK_MENU_ITEM
 					   (menu->functions), submenu);
 	}
@@ -384,9 +437,9 @@ create_text_editor_menu_gui (TextEditorMenu * menu)
 		menu->copy = text_editor_menu_uiinfo[0].widget;
 		menu->cut = text_editor_menu_uiinfo[1].widget;
 		menu->autoformat = text_editor_menu_uiinfo[7].widget;
-		menu->swap = text_editor_menu_uiinfo[8].widget;
-		menu->functions = text_editor_menu_uiinfo[12].widget;
-		menu->debug = text_editor_menu_uiinfo[14].widget;
+		menu->swap = text_editor_menu_uiinfo[9].widget;
+		menu->functions = text_editor_menu_uiinfo[11].widget;
+		menu->debug = text_editor_menu_uiinfo[13].widget;
 
 		gtk_widget_ref (menu->GUI);
 		gtk_widget_ref (menu->copy);
@@ -420,17 +473,11 @@ on_text_editor_menu_swap_activate (GtkMenuItem * menuitem, gpointer user_data)
 }
 
 void
-on_text_editor_menu_function_activate (GtkMenuItem * menuitem,
+on_text_editor_menu_tags_activate (GtkMenuItem * menuitem,
 				       gpointer user_data)
 {
-	gchar *func = user_data;
-	gchar *file;
-	guint line;
-	tags_manager_get_tag_info (app->tags_manager, func, &file, &line);
-	if (file)
-	{
-		anjuta_goto_file_line (file, line);
-		g_free (file);
-	}
+	TextEditor *te = anjuta_get_current_text_editor();
+	if (!te)
+		return;
+	anjuta_goto_local_tag(te, (const char *) user_data);
 }
-
