@@ -25,6 +25,7 @@
 #include <unistd.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
+#include <limits.h>
 #include <ctype.h>
 #include <stdlib.h>
 #include <glib.h>
@@ -58,6 +59,23 @@ extract_filename (gchar * full_filename)
 	return &full_filename[++i];
 }
 
+#define NSTR(S) ((S)?(S):"NULL")
+gchar *
+resolved_file_name(gchar *full_filename)
+{
+	char real_filename[PATH_MAX], *final_filename;
+	if (!full_filename)
+		final_filename = NULL;
+	else if (realpath(full_filename, real_filename))
+		final_filename = g_strdup(real_filename);
+	else
+		final_filename = g_strdup(full_filename);
+#ifdef DEBUG
+	g_message("%s -> %s", NSTR(full_filename), NSTR(final_filename));
+#endif
+	return final_filename;
+}
+
 GList *
 update_string_list (GList * list, gchar * string, gint length)
 {
@@ -104,7 +122,7 @@ free_string_list ( GList * pList )
 
 
 gboolean
-parse_error_line (gchar * line, gchar ** filename, int *lineno)
+parse_error_line (const gchar * line, gchar ** filename, int *lineno)
 {
 	gint i = 0;
 	gint j = 0;
@@ -336,6 +354,14 @@ FileExtType get_file_ext_type (gchar * file)
 	{
 		filetype = FILE_TYPE_VB;
 	}
+	else if (strcmp (filetype_str, "baan") == 0)
+	{
+		filetype = FILE_TYPE_BAAN;
+	}
+	else if (strcmp (filetype_str, "ada") == 0)
+	{
+		filetype = FILE_TYPE_ADA;
+	}
 	else if (strcmp (filetype_str, "wscript") == 0)
 	{
 		filetype = FILE_TYPE_WSCRIPT;
@@ -686,7 +712,7 @@ copy_file (gchar * src, gchar * dest, gboolean show_error)
 	if (input_fp == NULL)
 	{
 		if( show_error)
-			anjuta_system_error (errno, _("Couldn't read file: %s."), src);
+			anjuta_system_error (errno, _("Unable to read file: %s."), src);
 		return FALSE;
 	}
 	
@@ -694,7 +720,7 @@ copy_file (gchar * src, gchar * dest, gboolean show_error)
 	if (output_fp == NULL)
 	{
 		if( show_error)
-			anjuta_system_error (errno, _("Couldn't create file: %s."), dest);
+			anjuta_system_error (errno, _("Unable to create file: %s."), dest);
 		fclose (input_fp);
 		return TRUE;
 	}
@@ -728,7 +754,7 @@ copy_file (gchar * src, gchar * dest, gboolean show_error)
 	fclose (output_fp);
 	
 	if( show_error && (error == FALSE))
-		anjuta_system_error (errno, _("Couldn't complete file copy"));
+		anjuta_system_error (errno, _("Unable to complete file copy"));
 	return error;
 }
 
@@ -1242,8 +1268,8 @@ select_only_file (const struct dirent *e)
         * and return the box. */
 GtkWidget*
 create_xpm_label_box( GtkWidget *parent,
-                                 gchar     *xpm_filename, gboolean gnome_pixmap,
-                                 gchar     *label_text )
+                                 const gchar     *xpm_filename, gboolean gnome_pixmap,
+                                 const gchar     *label_text )
        {
            GtkWidget *box1;
            GtkWidget *label;
@@ -1359,8 +1385,7 @@ gchar *WriteBufS( gchar* szDst, const gchar* szVal )
 			szSrc++ ;
 		}
 		*szDst++ = ',' ;
-		*szDst = '\0' ;
-	}
+		*szDst = '\0' ;	}
 	return szDst ;
 }
 
@@ -1375,8 +1400,7 @@ static int GetHexAs( const gchar c )
 }
 
 static gchar GetHexb( const gchar c1, const gchar c2 )
-{
-	return GetHexAs( c1 ) * 16 + GetHexAs( c2 ) ;
+{	return GetHexAs( c1 ) * 16 + GetHexAs( c2 ) ;
 }
 
 gchar* GetStrCod( const gchar *szIn )
