@@ -1,5 +1,4 @@
 /*
-*   $Id: c.c,v 1.1 2001/11/22 06:58:33 naba Exp $
 *
 *   Copyright (c) 1996-2001, Darren Hiebert
 *
@@ -192,6 +191,29 @@ typedef struct sStatementInfo {
 	tokenInfo* firstToken; /* First token in the statement */
 } statementInfo;
 
+/*  Describes the type of tag being generated.
+ */
+typedef enum eTagType {
+    TAG_UNDEFINED,
+    TAG_CLASS,			/* class name */
+    TAG_ENUM,			/* enumeration name */
+    TAG_ENUMERATOR,		/* enumerator (enumeration value) */
+    TAG_FIELD,			/* field (Java) */
+    TAG_FUNCTION,		/* function definition */
+    TAG_INTERFACE,		/* interface declaration */
+    TAG_MEMBER,			/* structure, class or interface member */
+    TAG_METHOD,			/* method declaration */
+    TAG_NAMESPACE,		/* namespace name */
+    TAG_PACKAGE,		/* package name */
+    TAG_PROTOTYPE,		/* function prototype or declaration */
+    TAG_STRUCT,			/* structure name */
+    TAG_TYPEDEF,		/* typedef name */
+    TAG_UNION,			/* union name */
+    TAG_VARIABLE,		/* variable definition */
+    TAG_EXTERN_VAR,		/* external variable declaration */
+	TAG_MACRO,			/* #define s */
+    TAG_COUNT			/* must be last */
+} tagType;
 
 typedef struct sParenInfo {
     boolean isPointer;
@@ -321,7 +343,7 @@ static void createTags (const unsigned int nestLevel, statementInfo *const paren
 */
 
 /* Debugging functions added by Biswa */
-#if DEBUG
+#if DEBUG_C
 static char *tokenTypeName[] = {
     "none", "args", "'}'", "'{'", "','", "'::'", "keyword", "name",
     "package", "paren-name", "';'",	"spec", "count"
@@ -856,7 +878,8 @@ static void addOtherFields (tagEntryInfo* const tag, const tagType type,
 	    }
 		if ((TRUE == st->gotArgs) && (TRUE == Option.extensionFields.argList) &&
 			((TAG_FUNCTION == type) || (TAG_METHOD == type) || (TAG_PROTOTYPE == type)))
-				tag->extensionFields.arglist = getArglistFromPos(tag->filePosition, tag->name, FALSE);
+				tag->extensionFields.arglist = getArglistFromPos(
+				  tag->filePosition, tag->name);
 	    break;
     }
 	
@@ -965,7 +988,7 @@ static void makeTag (const tokenInfo *const token,
 		     const statementInfo *const st,
 		     boolean isFileScope, const tagType type)
 {
-#ifdef DEBUG
+#ifdef DEBUG_C
 	printToken(token);
 	fprintf(stderr, "<<<<<<<<<<<<<<<<<>>>>>>>>>>>>>>>>\n");
 	printStatement(st);
@@ -992,7 +1015,7 @@ static void makeTag (const tokenInfo *const token,
 	findScopeHierarchy (scope, st);
 	addOtherFields (&e, type, st, scope);
 
-#ifdef DEBUG
+#ifdef DEBUG_C
 	printTagEntry(&e);
 #endif
 	makeTagEntry (&e);
@@ -2266,7 +2289,8 @@ static void tagCheck (statementInfo *const st)
 	    {
 		if (isContextualKeyword (prev2))
 		    st->scope = SCOPE_EXTERN;
-		qualifyVariableTag (st, prev);
+		else
+			qualifyVariableTag (st, prev);
 	    }
 	    else if (isType (prev, TOKEN_ARGS)  &&  isType (prev2, TOKEN_NAME))
 	    {
